; *************************************************************************
; *           Copyright (C) 2003 by Motorola.  All rights reserved.       *
; *************************************************************************
; *                                                                       *
; *   Motorola reserves the right to make changes without further notice  *
; *   to any product herein to improve reliability, function or design.   *
; *   Motorola does not assume any liability arising out of the           *
; *   application or use of any product, circuit, or software described   *
; *   herein; neither does it convey any license under its patent rights  *
; *   nor the rights of others.                                           *
; *                                                                       *
; *   Motorola products are not designed, intended, or authorized for     *
; *   use as components in systems intended for surgical implant into     *
; *   the body, or other applications intended to support life, or for    *
; *   any other application in which the failure of the Motorola product  *
; *   could create a situation where personal injury or death may occur.  *
; *                                                                       *
; *   Should Buyer purchase or use Motorola products for any such         *
; *   unintended or unauthorized application, Buyer shall indemnify and   *
; *   hold Motorola and its officers, employees, subsidiaries,            *
; *   affiliates, and distributors harmless against all claims costs,     *
; *   damages, and expenses, and reasonable attorney fees arising out     *
; *   of, directly or indirectly, any claim of personal injury or death   *
; *   associated with such unintended or unauthorized use, even if such   *
; *   claim alleges that Motorola was negligent regarding the design      *
; *   or manufacture of the part.                                         *
; *                                                                       *
; *   Motorola and the Motorola logo* are registered trademarks of        *
; *   Motorola Ltd.                                                       *
; *                                                                       *
; *************************************************************************

; *************************************************************************
; *                                                                       *
; *                 Standard Software SGF		 						  *
; *                    Driver for HC908			 						  *
; *                                                                       *
; * FILE NAME     :  FlashErase.asm                             	  	  *
; * VERSION:      :  1.0.0                                                *
; * DATE          :  Apr 07, 2003                                         *
; * AUTHOR        :  Flash Team, GSG China                                *
; * EMAIL		  :  flash@sc.mcel.mot.com								  *
; *************************************************************************

; ******************************* CHANGES *********************************
; 1.0.0   2003.04.07  Cloud Li    Initial Version
; *************************************************************************

	XDEF FlashErase
	INCLUDE "Parameters.inc"

FLASHERASECODE: SECTION

FlashErase:

		LDA	  	#ERASE						; set erase bit in flashCR
		BRCLR 	1,MODESEL,PageErase			; MODESEL bit1=0: page erase; bit1=1: mass erase
		ORA	  	#MASS						; for mass erase: set mass bit in flashCR too

PageErase:
		LDHX  	FLASHCR         			; get address of flashCR
        STA   	,X							; set flashCR

        LDHX  	FLASHPR         			; get address of flashPR
        LDA   	,X							; read flashPR

        LDHX  	STARTADDR       			; get erase start address
        STA   	,X							; write any data to the address range to be erased

        BSR		Delay						; wait for Tnvs >= 10 us (actual >= 29 us)

        LDHX  	FLASHCR         			; get address of flashCR
		LDA	  	,X							; read flashCR
		ORA	  	#HVEN						; set HVEN bit
        STA   	,X							; write back flashCR

		LDX   	#TERASE4					; loop count for 4 ms
		BRSET 	1,MODESEL,WaitErase			; mass erase wait 4 ms
		BRSET 	2,MODESEL,WaitErase			; page erase wait 4 ms
		LDX	  	#TERASE1					; loop count for 1 ms

WaitErase:
        BSR   	Delay 						; call delay for Terase or Tmerase (1 ms or 4 ms)
        DBNZX	WaitErase					;

        LDHX  	FLASHCR						; get address of flashCR
		LDA	  	#HVEN						; clear erase and mass bits in flashCR
        STA   	,X							; write back to flashCR

		LDX	  	#TNVH						; delay for Tnvh(l)
		BRCLR 	1,MODESEL,WaitTNVH			; page erase: wait for Tnvh >= 5 us
        LDX   	#TNVHL						; mass erase: wait for Tnvhl >= 100 us
WaitTNVH:
		BSR   	Delay 						; call delay subroutine
		DBNZX	WaitTNVH					; loop for delay
											; actual delay is
											; Tnvh = 32 * 1 = 32 us
											; Tnvhl = 32 * 4 = 128 us

        LDHX  	FLASHCR						; get address of flashCR
        CLR   	,X							; clear HVEN bit

        BRCLR 	0,MODESEL,FEraseReturn		; if bit0 of MODESEL is 0 then normal return
        SWI          	 					; else execute "swi" to enter monitor mode.

FEraseReturn:
		RTS									; return to the calling function

;----------------------------------------------------------------------------------------------
;Subroutine for delay (maximum delay time about 32us * 255 = 8160us
;actual cycles = 8 + 4 * (8 * cpu speed - 4) + 5
;			   = 32 * cpu speed - 3
;the actual cycles include the calling delay, i.e. BSR
;for example, the total delay for 3200us will be like:
;		LDX		#100			; load loop count 100 to X			2 cycles
;LOOP:
;		BSR		Delay			; call delay function				32 * cpu speed - 3 cycles
;		DBNZX	LOOP			; check the loop condition			3 cycles
;so total delay cycles are [2 + (32 * cpu speed - 3 + 3) * 100]
; the final delay time is (2 + 3200 * cpu speed) / (cpu speed) = 3200 us + 2/(cpu speed)
;for small delay, i.e. 10us, then do not use the outer loop,
;for example, the delay for 10us:
;		BSR		Delay
;total cycles are (32 * cpu speed - 3), then delay time will be
; (32us - 3/cpu speed), if cpu speed equal to 1MHz then the time will be 29us
;----------------------------------------------------------------------------------------------
Delay:
		LDA		CLOCKSCALAR					; load the clock scaling factor to A	3 cycles
		SUB		#4							; substract the factor by 4 to balance the
											; software overhead						2 cycles
DelayLoop:
		NOP									; no use, only take one cycle		    1 cycle
		DBNZA	DelayLoop					; loop until A equal to 0				3 cycles
		RTS									; return to the calling function 		4 cycles
