; *************************************************************************
; *           Copyright (C) 2003 by Motorola.  All rights reserved.       *
; *************************************************************************
; *                                                                       *
; *   Motorola reserves the right to make changes without further notice  *
; *   to any product herein to improve reliability, function or design.   *
; *   Motorola does not assume any liability arising out of the           *
; *   application or use of any product, circuit, or software described   *
; *   herein; neither does it convey any license under its patent rights  *
; *   nor the rights of others.                                           *
; *                                                                       *
; *   Motorola products are not designed, intended, or authorized for     *
; *   use as components in systems intended for surgical implant into     *
; *   the body, or other applications intended to support life, or for    *
; *   any other application in which the failure of the Motorola product  *
; *   could create a situation where personal injury or death may occur.  *
; *                                                                       *
; *   Should Buyer purchase or use Motorola products for any such         *
; *   unintended or unauthorized application, Buyer shall indemnify and   *
; *   hold Motorola and its officers, employees, subsidiaries,            *
; *   affiliates, and distributors harmless against all claims costs,     *
; *   damages, and expenses, and reasonable attorney fees arising out     *
; *   of, directly or indirectly, any claim of personal injury or death   *
; *   associated with such unintended or unauthorized use, even if such   *
; *   claim alleges that Motorola was negligent regarding the design      *
; *   or manufacture of the part.                                         *
; *                                                                       *
; *   Motorola and the Motorola logo* are registered trademarks of        *
; *   Motorola Ltd.                                                       *
; *                                                                       *
; *************************************************************************

; *************************************************************************
; *                                                                       *
; *                 Standard Software SGF		 						  *
; *                    Driver for HC908			 						  *
; *                                                                       *
; * FILE NAME     :  FlashProgram.asm                                     *
; * VERSION:      :  1.0.0                                                *
; * DATE          :  Apr 07, 2003                                         *
; * AUTHOR        :  Flash Team, GSG China                                *
; * EMAIL		  :  flash@sc.mcel.mot.com								  *
; *************************************************************************

; ******************************* CHANGES *********************************
; 1.0.0   2003.04.07  Cloud Li    Initial Version
; *************************************************************************

	XDEF FlashProgram
	INCLUDE "Parameters.inc"

;-------------------------------------------------------------
;Macro for delay 30-40uS
;note: software overhead is 31 cycles,
;	   but for last byte is 29 cycles.
; for last byte:
;  actual cycles = 29 + 5 + 4 * (8 * cpu speed - 7)
;			   = 32 * cpu speed + 6
;  actual time = 32 + (6 / cpu speed)
; for other bytes:
;  actual cycles = 31 + 5 + 4 * (8 * cpu speed - 7)
;			   = 32 * cpu speed + 8
;  actual time = 32 + (8 / cpu speed)
;-------------------------------------------------------------
WAIT_TPROG: MACRO
			LDA   CLOCKSCALAR			; load delay counter to A			3 cycles
			SUB   #$7					; substract the counter by 7		2 cycles
\@L1:		NOP							; no use, only take one cycle		1 cycle
			DBNZA \@L1					; loop until counter decreases to 0	3 cycles
			ENDM

FLASHPROGRAMCODE: SECTION

FlashProgram:
        LDA   #PGM						; set PGM of Flash control register and clear other bits.
        LDHX  FLASHCR					; get the flashCR address
        STA   ,X						; store the value

        LDHX  FLASHPR					; get the protection register address
        LDX   ,X						; read flash protection register

        LDHX  STARTADDR					; get the destination address
        STA   ,X						; write any data to the address range to be programmed.

		BSR   Delay						; wait Tnvs >= 10 us (actual >= 29 us)

        LDA   #9						; set HVEN bit (with PGM bit not changed).
        LDHX  FLASHCR					; in the flash control register
        STA   ,X						; store the value to flashCR

		BSR   Delay						; wait Tpgs >= 5us (actual >= 29 us)

StartProgram:
		LDHX  BUFFER					; get buffer address 				4 cycles
        LDA   ,X						; get data from the buffer.			2 cycles
        AIX   #1						; update buffer for next byte. 		2 cycles
        STHX  BUFFER					; save the updated buffer address	4 cycles

        LDHX  STARTADDR					; get start address					4 cycles

        STA   ,X						; write data to dest. 				2 cycles

		WAIT_TPROG						; wait for Tprog (>=30 us and <=40 us)

        AIX   #1						; update dest for next byte 		2 cycles
        STHX  STARTADDR					; write back next addr				4 cycles
	    CPHX  ENDADDR					; check if dest <= end address	 	4 cycles
		BLS	  StartProgram				; loop until finish					3 cycles

		LDA   #$2						; delay for last byte				2 cycles
		DBNZA *							; 2 + 3 * 2 = 8						3 cycles

		LDA   #8						; clear PGM bit of the flash CR		2 cycles
        LDHX  FLASHCR					; get the address of flashCR		4 cycles
        STA   ,X						; save the value into flashCR		2 cycles

		BSR   Delay						; wait Tnvh >= 5 us (actual >= 29 us)

        LDHX  FLASHCR					; get address of flash CR
        CLR   ,X						; clear HVEN bit of the flash CR

        BRCLR 0,MODESEL,FProgramReturn	; if bit0 of MODESEL is 0 then normal return
        SWI          	 				; else execute "swi" to enter monitor mode.

FProgramReturn:
		RTS								; return to the calling function

;----------------------------------------------------------------------------------------------
;Subroutine for delay (maximum delay time about 32us * 255 = 8160us
;actual cycles = 8 + 4 * (8 * cpu speed - 4) + 5
;			   = 32 * cpu speed - 3
;the actual cycles include the calling delay, i.e. BSR
;for example, the total delay for 3200us will be like:
;		LDX		#100			; load loop count 100 to X			2 cycles
;LOOP:
;		BSR		Delay			; call delay function				32 * cpu speed - 3 cycles
;		DBNZX	LOOP			; check the loop condition			3 cycles
;so total delay cycles are [2 + (32 * cpu speed - 3 + 3) * 100]
; the final delay time is (2 + 3200 * cpu speed) / (cpu speed) = 3200 us + 2/(cpu speed)
;for small delay, i.e. 10us, then do not use the outer loop,
;for example, the delay for 10us:
;		BSR		Delay
;total cycles are (32 * cpu speed - 3), then delay time will be
; (32us - 3/cpu speed), if cpu speed equal to 1MHz then the time will be 29us
;----------------------------------------------------------------------------------------------
Delay:
		LDA		CLOCKSCALAR				; load the clock scaling factor to A	3 cycles
		SUB		#4						; substract the factor by 4 to balance the
										; software overhead						2 cycles
DelayLoop:
		NOP								; no use, only take one cycle		    1 cycle
		DBNZA	DelayLoop				; loop until A equal to 0				3 cycles
		RTS								; return to the calling function 		4 cycles
