/*************************************************************************
 *                                                                       *
 *                CodeWarrior For HC08 Source File                       *
 *                                                                       *
 * FILE NAME     :  MC68HC908AP64.h                                      *
 * DATE          :  February 20 2003                                     *
 *                                                                       *
 * AUTHOR        :  Douwa yu                                             *
 *                                                                       *
 *************************************************************************/

/******************************* CHANGES *********************************
 1.00   2003.02.20      Douwa yu        Initial Version
 *************************************************************************/
 
#ifndef _MC68HC908AP64_H
#define _MC68HC908AP64_H

/*Types definition*/
typedef unsigned char byte;
typedef unsigned int word;
typedef unsigned long dword;
typedef unsigned long dlong[2];

#ifdef _lint
  #define __RESET_WATCHDOG() /* empty */
#else
  #define __RESET_WATCHDOG() {asm sta COPCTL;} /* just write a byte to feed the dog */
#endif

#pragma MESSAGE DISABLE C1106 /* WARNING C1106: Non-standard bitfield type */

/*** PTA - Port A Data Register ***/
typedef union {
  byte Byte;
  struct {
    byte PTA0    :1;           /* Port A Data Bit 0, Analog-to-Digital Input Bit 0,LED0 */
    byte PTA1    :1;           /* Port A Data Bit 1, Analog-to-Digital Input Bit 1,LED1 */
    byte PTA2    :1;           /* Port A Data Bit 2, Analog-to-Digital Input Bit 2,LED2 */
    byte PTA3    :1;           /* Port A Data Bit 3, Analog-to-Digital Input Bit 3,LED3 */
    byte PTA4    :1;           /* Port A Data Bit 4, Analog-to-Digital Input Bit 4,LED4 */
    byte PTA5    :1;           /* Port A Data Bit 5, Analog-to-Digital Input Bit 5,LED5 */
    byte PTA6    :1;           /* Port A Data Bit 6, Analog-to-Digital Input Bit 6,LED6 */
    byte PTA7    :1;           /* Port A Data Bit 7, Analog-to-Digital Input Bit 7,LED7 */
  } Bits;
  struct {
    byte PTA     :8;
  } MergedBits;
} PTASTR;
extern volatile PTASTR _PTA @0x0000;
#define PTA _PTA.Byte
#define PTA_PTA0 _PTA.Bits.PTA0
#define PTA_PTA1 _PTA.Bits.PTA1
#define PTA_PTA2 _PTA.Bits.PTA2
#define PTA_PTA3 _PTA.Bits.PTA3
#define PTA_PTA4 _PTA.Bits.PTA4
#define PTA_PTA5 _PTA.Bits.PTA5
#define PTA_PTA6 _PTA.Bits.PTA6
#define PTA_PTA7 _PTA.Bits.PTA7
#define PTA_PTA  _PTA.MergedBits.PTA

/*** PTB - Port B Data Register ***/
typedef union {
  byte Byte;
  struct {
    byte PTB0    :1;           /* Port B Data Bit 0, Multi-Master IIC Data Pin*/
    byte PTB1    :1;           /* Port B Data Bit 1, Multi-Master IIC Clock Pin */
    byte PTB2    :1;           /* Port B Data Bit 2, SCI Trammit Data Pin */
    byte PTB3    :1;           /* Port B Data Bit 3, SCI Receive Data Pin */
    byte PTB4    :1;           /* Port B Data Bit 4, Timer 1 Channel I/O Bit 0 */
    byte PTB5    :1;           /* Port B Data Bit 5, Timer 1 Channel I/O Bit 1 */
    byte PTB6    :1;           /* Port B Data Bit 6, Timer 2 Channel I/O Bit 0 */
    byte PTB7    :1;           /* Port B Data Bit 7, Timer 2 Channel I/O Bit 1 */
  } Bits;
  struct {
    byte PTB     :8;
  } MergedBits;
} PTBSTR;
extern volatile PTBSTR _PTB @0x0001;
#define PTB _PTB.Byte
#define PTB_PTB0 _PTB.Bits.PTB0
#define PTB_PTB1 _PTB.Bits.PTB1
#define PTB_PTB2 _PTB.Bits.PTB2
#define PTB_PTB3 _PTB.Bits.PTB3
#define PTB_PTB4 _PTB.Bits.PTB4
#define PTB_PTB5 _PTB.Bits.PTB5
#define PTB_PTB6 _PTB.Bits.PTB6
#define PTB_PTB7 _PTB.Bits.PTB7
#define PTB_PTB _PTB.MergedBits.PTB

/*** PTC - Port C Data Register ***/
typedef union {
  byte Byte;
  struct {
    byte PTC0    :1;           /* Port C Data Bit 0, IRQ2 Input Pin */
    byte PTC1    :1;           /* Port C Data Bit 1 */
    byte PTC2    :1;           /* Port C Data Bit 2, Master In/Slave Out */
    byte PTC3    :1;           /* Port C Data Bit 3, Master Out/Slave In */
    byte PTC4    :1;           /* Port C Data Bit 4, Slave Select */
    byte PTC5    :1;           /* Port C Data Bit 5, SPI Clock */
    byte PTC6    :1;           /* Port C Data Bit 6, IrSCI Trammit Data Pin */
    byte PTC7    :1;           /* Port C Data Bit 7, IrSCI Receive Data Pin */
  } Bits;
  struct {
    byte PTC     :8;
  } MergedBits;
} PTCSTR;
extern volatile PTCSTR _PTC @0x0002;
#define PTC _PTC.Byte
#define PTC_PTC0 _PTC.Bits.PTC0
#define PTC_PTC1 _PTC.Bits.PTC1
#define PTC_PTC2 _PTC.Bits.PTC2
#define PTC_PTC3 _PTC.Bits.PTC3
#define PTC_PTC4 _PTC.Bits.PTC4
#define PTC_PTC5 _PTC.Bits.PTC5
#define PTC_PTC6 _PTC.Bits.PTC6
#define PTC_PTC7 _PTC.Bits.PTC7
#define PTC_PTC _PTC.MergedBits.PTC

/*** PTD - Port D Data Register ***/
typedef union {
  byte Byte;
  struct {
    byte PTD0    :1;           /* Port D Data Bit 0, Keyboard Input Pin 0 */
    byte PTD1    :1;           /* Port D Data Bit 1, Keyboard Input Pin 1 */
    byte PTD2    :1;           /* Port D Data Bit 2, Keyboard Input Pin 2 */
    byte PTD3    :1;           /* Port D Data Bit 3, Keyboard Input Pin 3 */
    byte PTD4    :1;           /* Port D Data Bit 4, Keyboard Input Pin 4 */
    byte PTD5    :1;           /* Port D Data Bit 5, Keyboard Input Pin 5 */
    byte PTD6    :1;           /* Port D Data Bit 6, Keyboard Input Pin 6 */
    byte PTD7    :1;           /* Port D Data Bit 7, Keyboard Input Pin 7 */
  } Bits;
  struct {
    byte PTD     :8;
  } MergedBits;
} PTDSTR;
extern volatile PTDSTR _PTD @0x0003;
#define PTD _PTD.Byte
#define PTD_PTD0 _PTD.Bits.PTD0
#define PTD_PTD1 _PTD.Bits.PTD1
#define PTD_PTD2 _PTD.Bits.PTD2
#define PTD_PTD3 _PTD.Bits.PTD3
#define PTD_PTD4 _PTD.Bits.PTD4
#define PTD_PTD5 _PTD.Bits.PTD5
#define PTD_PTD6 _PTD.Bits.PTD6
#define PTD_PTD7 _PTD.Bits.PTD7
#define PTD_PTD _PTD.MergedBits.PTD

/*** DDRA - Data Direction Register A ***/
typedef union {
  byte Byte;
  struct {
    byte DDRA0   :1;           /* Data Direction Register A Bit 0 */
    byte DDRA1   :1;           /* Data Direction Register A Bit 1 */
    byte DDRA2   :1;           /* Data Direction Register A Bit 2 */
    byte DDRA3   :1;           /* Data Direction Register A Bit 3 */
    byte DDRA4   :1;           /* Data Direction Register A Bit 4 */
    byte DDRA5   :1;           /* Data Direction Register A Bit 5 */
    byte DDRA6   :1;           /* Data Direction Register A Bit 6 */
    byte DDRA7   :1;           /* Data Direction Register A Bit 7 */
  } Bits;
  struct {
    byte DDRA    :8;
  } MergedBits;
} DDRASTR;
extern volatile DDRASTR _DDRA @0x0004;
#define DDRA _DDRA.Byte
#define DDRA_DDRA0 _DDRA.Bits.DDRA0
#define DDRA_DDRA1 _DDRA.Bits.DDRA1
#define DDRA_DDRA2 _DDRA.Bits.DDRA2
#define DDRA_DDRA3 _DDRA.Bits.DDRA3
#define DDRA_DDRA4 _DDRA.Bits.DDRA4
#define DDRA_DDRA5 _DDRA.Bits.DDRA5
#define DDRA_DDRA6 _DDRA.Bits.DDRA6
#define DDRA_DDRA7 _DDRA.Bits.DDRA7
#define DDRA_DDRA _DDRA.MergedBits.DDRA

/*** DDRB - Data Direction Register B ***/
typedef union {
  byte Byte;
  struct {
    byte DDRB0   :1;           /* Data Direction Register B Bit 0 */
    byte DDRB1   :1;           /* Data Direction Register B Bit 1 */
    byte DDRB2   :1;           /* Data Direction Register B Bit 2 */
    byte DDRB3   :1;           /* Data Direction Register B Bit 3 */
    byte DDRB4   :1;           /* Data Direction Register B Bit 4 */
    byte DDRB5   :1;           /* Data Direction Register B Bit 5 */
    byte DDRB6   :1;           /* Data Direction Register B Bit 6 */
    byte DDRB7   :1;           /* Data Direction Register B Bit 7 */
  } Bits;
  struct {
    byte DDRB    :8;
  } MergedBits;
} DDRBSTR;
extern volatile DDRBSTR _DDRB @0x0005;
#define DDRB _DDRB.Byte
#define DDRB_DDRB0 _DDRB.Bits.DDRB0
#define DDRB_DDRB1 _DDRB.Bits.DDRB1
#define DDRB_DDRB2 _DDRB.Bits.DDRB2
#define DDRB_DDRB3 _DDRB.Bits.DDRB3
#define DDRB_DDRB4 _DDRB.Bits.DDRB4
#define DDRB_DDRB5 _DDRB.Bits.DDRB5
#define DDRB_DDRB6 _DDRB.Bits.DDRB6
#define DDRB_DDRB7 _DDRB.Bits.DDRB7
#define DDRB_DDRB _DDRB.MergedBits.DDRB

/*** DDRC - Data Direction Register C ***/
typedef union {
  byte Byte;
  struct {
    byte DDRC0   :1;           /* Data Direction Register C Bit 0 */
    byte DDRC1   :1;           /* Data Direction Register C Bit 1 */
    byte DDRC2   :1;           /* Data Direction Register C Bit 2 */
    byte DDRC3   :1;           /* Data Direction Register C Bit 3 */
    byte DDRC4   :1;           /* Data Direction Register C Bit 4 */
    byte DDRC5   :1;           /* Data Direction Register C Bit 5 */
    byte DDRC6   :1;           /* Data Direction Register C Bit 6 */
    byte DDRC7   :1;           /* Data Direction Register C Bit 7 */
  } Bits;
  struct {
    byte DDRC    :8;
  } MergedBits;
} DDRCSTR;
extern volatile DDRCSTR _DDRC @0x0006;
#define DDRC _DDRC.Byte
#define DDRC_DDRC0 _DDRC.Bits.DDRC0
#define DDRC_DDRC1 _DDRC.Bits.DDRC1
#define DDRC_DDRC2 _DDRC.Bits.DDRC2
#define DDRC_DDRC3 _DDRC.Bits.DDRC3
#define DDRC_DDRC4 _DDRC.Bits.DDRC4
#define DDRC_DDRC5 _DDRC.Bits.DDRC5
#define DDRC_DDRC6 _DDRC.Bits.DDRC6
#define DDRC_DDRC7 _DDRC.Bits.DDRC7
#define DDRC_DDRC  _DDRC.MergedBits.DDRC

/*** DDRD - Data Direction Register D ***/
typedef union {
  byte Byte;
  struct {
    byte DDRD0   :1;           /* Data Direction Register D Bit 0 */
    byte DDRD1   :1;           /* Data Direction Register D Bit 1 */
    byte DDRD2   :1;           /* Data Direction Register D Bit 2 */
    byte DDRD3   :1;           /* Data Direction Register D Bit 3 */
    byte DDRD4   :1;           /* Data Direction Register D Bit 4 */
    byte DDRD5   :1;           /* Data Direction Register D Bit 5 */
    byte DDRD6   :1;           /* Data Direction Register D Bit 6 */
    byte DDRD7   :1;           /* Data Direction Register D Bit 7 */
  } Bits;
  struct {
    byte DDRD    :8;
  } MergedBits;
} DDRDSTR;
extern volatile DDRDSTR _DDRD @0x0007;
#define DDRD _DDRD.Byte
#define DDRD_DDRD0 _DDRD.Bits.DDRD0
#define DDRD_DDRD1 _DDRD.Bits.DDRD1
#define DDRD_DDRD2 _DDRD.Bits.DDRD2
#define DDRD_DDRD3 _DDRD.Bits.DDRD3
#define DDRD_DDRD4 _DDRD.Bits.DDRD4
#define DDRD_DDRD5 _DDRD.Bits.DDRD5
#define DDRD_DDRD6 _DDRD.Bits.DDRD6
#define DDRD_DDRD7 _DDRD.Bits.DDRD7
#define DDRD_DDRD _DDRD.MergedBits.DDRD

/*** LEDA - Port-A LED Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte LEDA0   :1;           /* Port A LED Drive Enable Bit 0 */
    byte LEDA1   :1;           /* Port A LED Drive Enable Bit 1 */
    byte LEDA2   :1;           /* Port A LED Drive Enable Bit 2 */
    byte LEDA3   :1;           /* Port A LED Drive Enable Bit 3 */
    byte LEDA4   :1;           /* Port A LED Drive Enable Bit 4 */
    byte LEDA5   :1;           /* Port A LED Drive Enable Bit 5 */
    byte LEDA6   :1;           /* Port A LED Drive Enable Bit 6 */
    byte LEDA7   :1;           /* Port A LED Drive Enable Bit 7 */
  } Bits;
  struct {
    byte LEDA    :8;
  } MergedBits;
} LEDASTR;
extern volatile LEDASTR _LEDA @0x000C;
#define LEDA _LEDA.Byte
#define LEDA_LEDA0 _LEDA.Bits.LEDA0
#define LEDA_LEDA1 _LEDA.Bits.LEDA1
#define LEDA_LEDA2 _LEDA.Bits.LEDA2
#define LEDA_LEDA3 _LEDA.Bits.LEDA3
#define LEDA_LEDA4 _LEDA.Bits.LEDA4
#define LEDA_LEDA5 _LEDA.Bits.LEDA5
#define LEDA_LEDA6 _LEDA.Bits.LEDA6
#define LEDA_LEDA7 _LEDA.Bits.LEDA7
#define LEDA_LEDA _LEDA.MergedBits.LEDA

/*** SPCR - SPI Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte SPTIE    :1;           /* SPI Transmit Interrupt Enable */
    byte SPE      :1;           /* SPI Enable */
    byte SPWOM    :1;           /* SPI Wired OR Mode Bit */
    byte CPHA     :1;           /* Clock Phase Bit */
    byte CPOL     :1;           /* Clock Polarity bit */
    byte SPMSTR   :1;           /* SPI Master bit */
    byte DMAS     :1;           /* DMA Select Bit */
    byte SPRIE    :1;           /* SPI Receiver Interrupt Enable Bit */
  } Bits;
} SPCRSTR;
extern volatile SPCRSTR _SPCR @0x0010;
#define SPCR _SPCR.Byte
#define SPCR_SPTIE _SPCR.Bits.SPTIE
#define SPCR_SPE _SPCR.Bits.SPE
#define SPCR_SPWOM _SPCR.Bits.SPWOM
#define SPCR_CPHA _SPCR.Bits.CPHA
#define SPCR_CPOL _SPCR.Bits.CPOL
#define SPCR_SPMSTR _SPCR.Bits.SPMSTR
#define SPCR_DMAS _SPCR.Bits.DMAS
#define SPCR_SPRIE _SPCR.Bits.SPRIE

/*** SPSCR - SPI Status and Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte SPR0      :1;           /* SPI Baud Rate Select Bit */
    byte SPR1      :1;           /* SPI Baud Rate Select Bit */
    byte MODFEN    :1;           /* Mode Fault Enable Bit */
    byte SPTE      :1;           /* SPI Transmitter Empty Bit */
    byte MODF      :1;           /* Mode Fault bit */
    byte OVRF      :1;           /* Overflow bit */
    byte ERRIE     :1;           /* Error Interrupt Enable Bit*/
    byte SPRF      :1;           /* SPI Receiver Full Bit */
  } Bits;
  struct {
    byte SPR       :2;
    byte MODFEN    :1;
    byte SPTE      :1;
    byte MODF      :1;
    byte OVRF      :1;
    byte ERRIE     :1;
    byte SPRF      :1;
  } MergedBits;
} SPSCRSTR;
extern volatile SPSCRSTR _SPSCR @0x0011;
#define SPSCR _SPSCR.Byte
#define SPSCR_SPR0 _SPSCR.Bits.SPR0
#define SPSCR_SPR1 _SPSCR.Bits.SPR1
#define SPSCR_MODFEN _SPSCR.Bits.MODFEN
#define SPSCR_SPTE _SPSCR.Bits.SPTE
#define SPSCR_MODF _SPSCR.Bits.MODF
#define SPSCR_OVRF _SPSCR.Bits.OVRF
#define SPSCR_ERRIE _SPSCR.Bits.ERRIE
#define SPSCR_SPRF _SPSCR.Bits.SPRF
#define SPSCR_SPR  _SPSCR.MergedBits.SPR

/*** SPDR - SPI Data Register ***/
typedef union {
  byte Byte;
  struct {
    byte R0_T0    :1;           /* Receive/Transmit Data Bit 0 */
    byte R1_T1    :1;           /* Receive/Transmit Data Bit 1 */
    byte R2_T2    :1;           /* Receive/Transmit Data Bit 2 */
    byte R3_T3    :1;           /* Receive/Transmit Data Bit 3 */
    byte R4_T4    :1;           /* Receive/Transmit Data Bit 4 */
    byte R5_T5    :1;           /* Receive/Transmit Data Bit 5 */
    byte R6_T6    :1;           /* Receive/Transmit Data Bit 6 */
    byte R7_T7    :1;           /* Receive/Transmit Data Bit 7 */
  } Bits;
  struct {
    byte R_T      :8;
  } MergedBits;
} SPDRSTR;
extern volatile SPDRSTR _SPDR @0x0012;
#define SPDR _SPDR.Byte
#define SPDR_R0_T0 _SPDR.Bits.R0_T0
#define SPDR_R1_T1 _SPDR.Bits.R1_T1
#define SPDR_R2_T2 _SPDR.Bits.R2_T2
#define SPDR_R3_T3 _SPDR.Bits.R3_T3
#define SPDR_R4_T4 _SPDR.Bits.R4_T4
#define SPDR_R5_T5 _SPDR.Bits.R5_T5
#define SPDR_R6_T6 _SPDR.Bits.R6_T6
#define SPDR_R7_T7 _SPDR.Bits.R7_T7
#define SPDR_R_T _SPDR.MergedBits.R_T

/*** SCC1 - SCI1 Control Register 1 ***/
typedef union {
  byte Byte;
  struct {
    byte PTY     :1;           /* Parity Bit */
    byte PEN     :1;           /* Parity Enable Bit */
    byte ILTY    :1;           /* Idle Line Type Bit */
    byte WAKE    :1;           /* Wakeup Condition Bit */
    byte M       :1;           /* Mode (Character Length) Bit */
    byte TXINV   :1;           /* Transmit Inversion Bit */
    byte ENSCI   :1;           /* Enable SCI Bit */
    byte LOOPS   :1;           /* Loop Mode Select Bit */
  } Bits;
} SCC1STR;
extern volatile SCC1STR _SCC1 @0x0013;
#define SCC1 _SCC1.Byte
#define SCC1_PTY _SCC1.Bits.PTY
#define SCC1_PEN _SCC1.Bits.PEN
#define SCC1_ILTY _SCC1.Bits.ILTY
#define SCC1_WAKE _SCC1.Bits.WAKE
#define SCC1_M _SCC1.Bits.M
#define SCC1_TXINV _SCC1.Bits.TXINV
#define SCC1_ENSCI _SCC1.Bits.ENSCI
#define SCC1_LOOPS _SCC1.Bits.LOOPS

/*** SCC2 - SCI1 Control Register 2 ***/
typedef union {
  byte Byte;
  struct {
    byte SBK     :1;           /* Send Break Bit */
    byte RWU     :1;           /* Receiver Wakeup Bit */
    byte RE      :1;           /* Receiver Enable Bit */
    byte TE      :1;           /* Transmitter Enable Bit */
    byte ILIE    :1;           /* Idle Line Interrupt Enable Bit */
    byte SCRIE   :1;           /* SCI Receive Interrupt Enable Bit */
    byte TCIE    :1;           /* Transmission Complete Interrupt Enable Bit */
    byte SCTIE   :1;           /* SCI Transmit Interrupt Enable Bit */
  } Bits;
} SCC2STR;
extern volatile SCC2STR _SCC2 @0x0014;
#define SCC2 _SCC2.Byte
#define SCC2_SBK _SCC2.Bits.SBK
#define SCC2_RWU _SCC2.Bits.RWU
#define SCC2_RE _SCC2.Bits.RE
#define SCC2_TE _SCC2.Bits.TE
#define SCC2_ILIE _SCC2.Bits.ILIE
#define SCC2_SCRIE _SCC2.Bits.SCRIE
#define SCC2_TCIE _SCC2.Bits.TCIE
#define SCC2_SCTIE _SCC2.Bits.SCTIE

/*** SCC3 - SCI1 Control Register 3 ***/
typedef union {
  byte Byte;
  struct {
    byte PEIE    :1;           /* Receiver Parity Error Interrupt Enable Bit */
    byte FEIE    :1;           /* Receiver Framing Error Interrupt Enable Bit */
    byte NEIE    :1;           /* Receiver Noise Error Interrupt Enable Bit */
    byte ORIE    :1;           /* Receiver Overrun Interrupt Enable Bit */
    byte DMATE   :1;           /* DMA Transfer Enable Bit */
    byte DMARE   :1;           /* DMA Receive Enable Bit */
    byte T8      :1;           /* Transmitted Bit 8 */
    byte R8      :1;           /* Received Bit 8 */
  } Bits;
} SCC3STR;
extern volatile SCC3STR _SCC3 @0x0015;
#define SCC3 _SCC3.Byte
#define SCC3_PEIE _SCC3.Bits.PEIE
#define SCC3_FEIE _SCC3.Bits.FEIE
#define SCC3_NEIE _SCC3.Bits.NEIE
#define SCC3_ORIE _SCC3.Bits.ORIE
#define SCC3_DMATE _SCC3.Bits.DMATE
#define SCC3_DMARE _SCC3.Bits.DMARE
#define SCC3_T8 _SCC3.Bits.T8
#define SCC3_R8 _SCC3.Bits.R8

/*** SCS1 - SCI1 Status Register 1 ***/
typedef union {
  byte Byte;
  struct {
    byte PE      :1;           /* Receiver Parity Error Bit */
    byte FE      :1;           /* Receiver Framing Error Bit */
    byte NF      :1;           /* Receiver Noise Flag Bit */
    byte OR      :1;           /* Receiver Overrun Bit */
    byte IDLE    :1;           /* Receiver Idle Bit */
    byte SCRF    :1;           /* SCI Receiver Full Bit */
    byte TC      :1;           /* Transmission Complete Bit */
    byte SCTE    :1;           /* SCI Transmitter Empty Bit */
  } Bits;
} SCS1STR;
extern volatile SCS1STR _SCS1 @0x0016;
#define SCS1 _SCS1.Byte
#define SCS1_PE _SCS1.Bits.PE
#define SCS1_FE _SCS1.Bits.FE
#define SCS1_NF _SCS1.Bits.NF
#define SCS1_OR _SCS1.Bits.OR
#define SCS1_IDLE _SCS1.Bits.IDLE
#define SCS1_SCRF _SCS1.Bits.SCRF
#define SCS1_TC _SCS1.Bits.TC
#define SCS1_SCTE _SCS1.Bits.SCTE

/*** SCS2 - SCI1 Status Register 2 ***/
typedef union {
  byte Byte;
  struct {
    byte RPF     :1;           /* Reception in Progress Flag Bit */
    byte BKF     :1;           /* Break Flag Bit */
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
  } Bits;
} SCS2STR;
extern volatile SCS2STR _SCS2 @0x0017;
#define SCS2 _SCS2.Byte
#define SCS2_RPF _SCS2.Bits.RPF
#define SCS2_BKF _SCS2.Bits.BKF

/*** SCDR - SCI1 Data Register ***/
typedef union {
  byte Byte;
  struct {
    byte R0_T0   :1;           /* Receive/Transmit Data Bit 0 */
    byte R1_T1   :1;           /* Receive/Transmit Data Bit 1 */
    byte R2_T2   :1;           /* Receive/Transmit Data Bit 2 */
    byte R3_T3   :1;           /* Receive/Transmit Data Bit 3 */
    byte R4_T4   :1;           /* Receive/Transmit Data Bit 4 */
    byte R5_T5   :1;           /* Receive/Transmit Data Bit 5 */
    byte R6_T6   :1;           /* Receive/Transmit Data Bit 6 */
    byte R7_T7   :1;           /* Receive/Transmit Data Bit 7 */
  } Bits;
  struct {
    byte R_T     :8;
  } MergedBits;
} SCDRSTR;
extern volatile SCDRSTR _SCDR @0x0018;
#define SCDR _SCDR.Byte
#define SCDR_R0_T0 _SCDR.Bits.R0_T0
#define SCDR_R1_T1 _SCDR.Bits.R1_T1
#define SCDR_R2_T2 _SCDR.Bits.R2_T2
#define SCDR_R3_T3 _SCDR.Bits.R3_T3
#define SCDR_R4_T4 _SCDR.Bits.R4_T4
#define SCDR_R5_T5 _SCDR.Bits.R5_T5
#define SCDR_R6_T6 _SCDR.Bits.R6_T6
#define SCDR_R7_T7 _SCDR.Bits.R7_T7
#define SCDR_R_T _SCDR.MergedBits.R_T

/*** SCBR - SCI1 Baud Rate Register ***/
typedef union {
  byte Byte;
  struct {
    byte SCR0    :1;           /* SCI Baud Rate Select Bit 0 */
    byte SCR1    :1;           /* SCI Baud Rate Select Bit 1 */
    byte SCR2    :1;           /* SCI Baud Rate Select Bit 2 */
    byte         :1;
    byte SCP0    :1;           /* SCI Baud Rate Prescaler Bit 0 */
    byte SCP1    :1;           /* SCI Baud Rate Prescaler Bit 1 */
    byte         :1;
    byte         :1;
  } Bits;
  struct {
    byte SCR     :3;
    byte         :1;
    byte SCP     :2;
    byte         :1;
    byte         :1;
  } MergedBits;
} SCBRSTR;
extern volatile SCBRSTR _SCBR @0x0019;
#define SCBR _SCBR.Byte
#define SCBR_SCR0 _SCBR.Bits.SCR0
#define SCBR_SCR1 _SCBR.Bits.SCR1
#define SCBR_SCR2 _SCBR.Bits.SCR2
#define SCBR_SCP0 _SCBR.Bits.SCP0
#define SCBR_SCP1 _SCBR.Bits.SCP1
#define SCBR_SCR _SCBR.MergedBits.SCR
#define SCBR_SCP _SCBR.MergedBits.SCP

/*** KBSCR - Keyboard Status and Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte MODE   :1;            /* Port-D Keyborad Triggering Sensitivity Bit */
    byte IMASK  :1;            /* Port-D Keyborad Interrupt Mask Bit */
    byte ACK    :1;            /* Port-D Keyborad Acknowledge Bit */
    byte KEYF   :1;            /* Port-D Keyborad Flag Bit */
    byte        :1;
    byte        :1;
    byte        :1;
    byte        :1;
  }Bit;
}KBSCRSTR;
extern  volatile  KBSCRSTR  _KBSCR  @0x001A;
#define KBSCR _KBSCR.Byte
#define KBSCR_MODE _KBSCR.Bits.MODE
#define KBSCR_IMASK _KBSCR.Bits.IMASK
#define KBSCR_ACK _KBSCR.Bits.ACK
#define KBSCR_KEYF _KBSCR.Bits.KEYF

/*** KBIER - Keyboard Interrrupt Enable Register KBIER ***/
typedef union {
  byte Byte;
  struct {
    byte KBIE0   :1;           /* Keyboard Interrupt Enable Bit 0 */
    byte KBIE1   :1;           /* Keyboard Interrupt Enable Bit 1 */
    byte KBIE2   :1;           /* Keyboard Interrupt Enable Bit 2 */
    byte KBIE3   :1;           /* Keyboard Interrupt Enable Bit 3 */
    byte KBIE4   :1;           /* Keyboard Interrupt Enable Bit 4 */
    byte KBIE5   :1;           /* Keyboard Interrupt Enable Bit 5 */
    byte KBIE6   :1;           /* Keyboard Interrupt Enable Bit 6 */
    byte KBIE7   :1;           /* Keyboard Interrupt Enable Bit 6 */
  } Bits;
  struct {
    byte KBIE    :8;
  } MergedBits;
} KBIERSTR;
extern volatile KBIERSTR _KBIER @0x001B;
#define KBIER _KBIER.Byte
#define KBIER_KBIE0 _KBIER.Bits.KBIE0
#define KBIER_KBIE1 _KBIER.Bits.KBIE1
#define KBIER_KBIE2 _KBIER.Bits.KBIE2
#define KBIER_KBIE3 _KBIER.Bits.KBIE3
#define KBIER_KBIE4 _KBIER.Bits.KBIE4
#define KBIER_KBIE5 _KBIER.Bits.KBIE5
#define KBIER_KBIE6 _KBIER.Bits.KBIE6
#define KBIER_KBIE7 _KBIER.Bits.KBIE7
#define KBIER_KBIE _KBIER.MergedBits.KBIE

/*** INTSCR2 - IRQ2 Status and Control Register INTSCR2 ***/
typedef union {
  byte Byte;
  struct {
    byte MODE2   :1;           /* IRQ2 Edge/Level Select Bit */
    byte IMASK2  :1;           /* IRQ2 Interrupt Mask Bit */
    byte ACK2    :1;           /* IRQ2 Interrupt Request Acknowledge Bit */
    byte IRQ2F   :1;           /* IRQ2 Flag */
    byte         :1;
    byte         :1;
    byte PUC0ENB :1;           /* Port-C Pull-up Enable Bit */
    byte         :1;
  } Bits;
} INTSCR2STR;
extern volatile INTSCR2STR _INTSCR2 @0x001C;
#define INTSCR2 _INTSCR2.Byte
#define INTSCR2_MODE2 _INTSCR2.Bits.MODE2
#define INTSCR2_IMASK2 _INTSCR2.Bits.IMASK2
#define INTSCR2_ACK2 _INTSCR2.Bits.ACK2
#define INTSCR2_IRQ2F _INTSCR2.Bits.IRQ2F
#define INTSCR2_PUC0ENB _INTSCR2.Bits.PUC0ENB

/*** CONFIG2 - Configuration Register 2 ***/
typedef union {
  byte Byte;
  struct {
    byte SCIBDSRC      :1;      /* SCI1 Baud Rate Clock Source Bit */
    byte               :1;
    byte               :1;
    byte OSCCLK0       :1;      /* Oscillator Output Control Bit */
    byte OSCCLK1       :1;      /* Oscillator Output Control Bit */
    byte STOP_XCLKEN   :1;      /* X-tal Oscillator Stop Mode Enable Bit */
    byte STOP_RCLKEN   :1;      /* RC Oscillator Stop Mode Enable Bit */
    byte STOP_ICLKDIS  :1;      /* Internal Oscillator Stop Mode Disable Bit */
  } Bits;
  struct {
    byte SCIBDSRC      :1;
    byte               :1;
    byte               :1;
    byte OSCCLK        :2;
    byte STOP_XCLKEN   :1;
    byte STOP_RCLKEN   :1;
    byte STOP_ICLKDIS  :1;
  } MergedBits;
} CONFIG2STR;
extern volatile CONFIG2STR _CONFIG2 @0x001D;
#define CONFIG2 _CONFIG2.Byte
#define CONFIG2_SCIBDSRC _CONFIG2.Bits.SCIBDSRC
#define CONFIG2_OSCCLK0 _CONFIG2.Bits.OSCCLK0
#define CONFIG2_OSCCLK1 _CONFIG2.Bits.OSCCLK1
#define CONFIG2_STOP_XCLKEN _CONFIG2.Bits.STOP_XCLKEN
#define CONFIG2_STOP_RCLKEN _CONFIG2.Bits.STOP_RCLKEN
#define CONFIG2_STOP_ICLKDIS _CONFIG2.Bits.STOP_ICLKDIS
#define CONFIG2_OSCCLK _CONFIG2.MergedBits.OSCCLK

/*** INTSCR1 - IRQ1 Status and Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte MODE1   :1;           /* IRQ1 Edge/Level Select Bit */
    byte IMASK1  :1;           /* IRQ1 Interrupt Mask Bit */
    byte ACK1    :1;           /* IRQ1 Interrupt Request Acknowledge Bit */
    byte IRQ1F   :1;           /* IRQ1 Flag */
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
  } Bits;
} INTSCR1STR;
extern volatile INTSCR1STR _INTSCR1 @0x001E;
#define INTSCR1 _INTSCR1.Byte
#define INTSCR1_MODE1 _INTSCR1.Bits.MODE1
#define INTSCR1_IMASK1 _INTSCR1.Bits.IMASK1
#define INTSCR1_ACK1 _INTSCR1.Bits.ACK1
#define INTSCR1_IRQ1F _INTSCR1.Bits.IRQ1F

/*** CONFIG1 - Configuration Register 1 ***/
typedef union {
  byte Byte;
  struct {
    byte COPD    :1;           /* COP Disable Bit */
    byte STOP    :1;           /* STOP Instruction Enable Bit */
    byte SSREC   :1;           /* Short Stop Recovery Bit */
    byte LVIREGD :1;           /* LVI Regulator Disable Bit */
    byte LVIPWRD :1;           /* LVI Power Disable Bit */
    byte LVIRSTD :1;           /* LVI Reset Disable Bit */
    byte LVISTOP :1;           /* LVI Enable in Stop Mode */
    byte COPRS   :1;           /* COP Rate Select Bit */
  } Bits;
} CONFIG1STR;
extern volatile CONFIG1STR _CONFIG1 @0x001F;
#define CONFIG1 _CONFIG1.Byte
#define CONFIG1_COPD _CONFIG1.Bits.COPD
#define CONFIG1_STOP _CONFIG1.Bits.STOP
#define CONFIG1_SSREC _CONFIG1.Bits.SSREC
#define CONFIG1_LVIREGD _CONFIG1.Bits.LVIREGD
#define CONFIG1_LVIPWRD _CONFIG1.Bits.LVIPWRD
#define CONFIG1_LVIRSTD _CONFIG1.Bits.LVIRSTD
#define CONFIG1_LVISTOP _CONFIG1.Bits.LVISTOP
#define CONFIG1_COPRS _CONFIG1.Bits.COPRS

/*** T1SC - TIM1 Status and Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte PS0     :1;           /* Prescaler Select Bit 0 */
    byte PS1     :1;           /* Prescaler Select Bit 1 */
    byte PS2     :1;           /* Prescaler Select Bit 2 */
    byte         :1;
    byte TRST    :1;           /* TIM1 Reset Bit */
    byte TSTOP   :1;           /* TIM1 Stop Bit */
    byte TOIE    :1;           /* TIM1 Overflow Interrupt Enable Bit */
    byte TOF     :1;           /* TIM1 Overflow Flag Bit */
  } Bits;
  struct {
    byte PS      :3;
    byte         :1;
    byte TRST    :1;
    byte TSTOP   :1;
    byte TOIE    :1;
    byte TOF     :1;
  } MergedBits;
} T1SCSTR;
extern volatile T1SCSTR _T1SC @0x0020;
#define T1SC _T1SC.Byte
#define T1SC_PS0 _T1SC.Bits.PS0
#define T1SC_PS1 _T1SC.Bits.PS1
#define T1SC_PS2 _T1SC.Bits.PS2
#define T1SC_TRST _T1SC.Bits.TRST
#define T1SC_TSTOP _T1SC.Bits.TSTOP
#define T1SC_TOIE _T1SC.Bits.TOIE
#define T1SC_TOF _T1SC.Bits.TOF
#define T1SC_PS _T1SC.MergedBits.PS

/*** T1CNTH - TIM1 Counter Register High ***/
typedef union {
  byte Byte;
  struct {
    byte BIT8    :1;           /* TIM1 Counter Register BIT 8 */
    byte BIT9    :1;           /* TIM1 Counter Register BIT 9 */
    byte BIT10   :1;           /* TIM1 Counter Register BIT 10 */
    byte BIT11   :1;           /* TIM1 Counter Register BIT 11 */
    byte BIT12   :1;           /* TIM1 Counter Register BIT 12 */
    byte BIT13   :1;           /* TIM1 Counter Register BIT 13 */
    byte BIT14   :1;           /* TIM1 Counter Register BIT 14 */
    byte BIT15   :1;           /* TIM1 Counter Register BIT 15 */
  } Bits;
  struct {
    byte BIT_8   :8;
  } MergedBits;
} T1CNTHSTR;
extern volatile T1CNTHSTR _T1CNTH @0x0021;
#define T1CNTH _T1CNTH.Byte
#define T1CNTH_BIT8 _T1CNTH.Bits.BIT8
#define T1CNTH_BIT9 _T1CNTH.Bits.BIT9
#define T1CNTH_BIT10 _T1CNTH.Bits.BIT10
#define T1CNTH_BIT11 _T1CNTH.Bits.BIT11
#define T1CNTH_BIT12 _T1CNTH.Bits.BIT12
#define T1CNTH_BIT13 _T1CNTH.Bits.BIT13
#define T1CNTH_BIT14 _T1CNTH.Bits.BIT14
#define T1CNTH_BIT15 _T1CNTH.Bits.BIT15
#define T1CNTH_BIT_8 _T1CNTH.MergedBits.BIT_8

/*** T1CNTL - TIM1 Counter Register Low ***/
typedef union {
  byte Byte;
  struct {
    byte BIT0    :1;           /* TIM1 Counter Register BIT 0 */
    byte BIT1    :1;           /* TIM1 Counter Register BIT 1 */
    byte BIT2    :1;           /* TIM1 Counter Register BIT 2 */
    byte BIT3    :1;           /* TIM1 Counter Register BIT 3 */
    byte BIT4    :1;           /* TIM1 Counter Register BIT 4 */
    byte BIT5    :1;           /* TIM1 Counter Register BIT 5 */
    byte BIT6    :1;           /* TIM1 Counter Register BIT 6 */
    byte BIT7    :1;           /* TIM1 Counter Register BIT 7 */
  } Bits;
  struct {
    byte BIT     :8;
  } MergedBits;
} T1CNTLSTR;
extern volatile T1CNTLSTR _T1CNTL @0x0022;
#define T1CNTL _T1CNTL.Byte
#define T1CNTL_BIT0 _T1CNTL.Bits.BIT0
#define T1CNTL_BIT1 _T1CNTL.Bits.BIT1
#define T1CNTL_BIT2 _T1CNTL.Bits.BIT2
#define T1CNTL_BIT3 _T1CNTL.Bits.BIT3
#define T1CNTL_BIT4 _T1CNTL.Bits.BIT4
#define T1CNTL_BIT5 _T1CNTL.Bits.BIT5
#define T1CNTL_BIT6 _T1CNTL.Bits.BIT6
#define T1CNTL_BIT7 _T1CNTL.Bits.BIT7
#define T1CNTL_BIT _T1CNTL.MergedBits.BIT

/*** T1MODH - TIM1 Counter Modulo Register ***/
typedef union {
  byte Byte;
  struct {
    byte BIT8    :1;           /* TIM1 Counter Modulo Bit 8 */
    byte BIT9    :1;           /* TIM1 Counter Modulo Bit 9 */
    byte BIT10   :1;           /* TIM1 Counter Modulo Bit 10 */
    byte BIT11   :1;           /* TIM1 Counter Modulo Bit 11 */
    byte BIT12   :1;           /* TIM1 Counter Modulo Bit 12 */
    byte BIT13   :1;           /* TIM1 Counter Modulo Bit 13 */
    byte BIT14   :1;           /* TIM1 Counter Modulo Bit 14 */
    byte BIT15   :1;           /* TIM1 Counter Modulo Bit 15 */
  } Bits;
  struct {
    byte BIT_8   :8;
  } MergedBits;
} T1MODHSTR;
extern volatile T1MODHSTR _T1MODH @0x0023;
#define T1MODH _T1MODH.Byte
#define T1MODH_BIT8 _T1MODH.Bits.BIT8
#define T1MODH_BIT9 _T1MODH.Bits.BIT9
#define T1MODH_BIT10 _T1MODH.Bits.BIT10
#define T1MODH_BIT11 _T1MODH.Bits.BIT11
#define T1MODH_BIT12 _T1MODH.Bits.BIT12
#define T1MODH_BIT13 _T1MODH.Bits.BIT13
#define T1MODH_BIT14 _T1MODH.Bits.BIT14
#define T1MODH_BIT15 _T1MODH.Bits.BIT15
#define T1MODH_BIT_8 _T1MODH.MergedBits.BIT_8

/*** T1MODL - TIM1 Counter Modulo Register ***/
typedef union {
  byte Byte;
  struct {
    byte BIT0    :1;           /* TIM1 Counter Modulo Bit 0 */
    byte BIT1    :1;           /* TIM1 Counter Modulo Bit 1 */
    byte BIT2    :1;           /* TIM1 Counter Modulo Bit 2 */
    byte BIT3    :1;           /* TIM1 Counter Modulo Bit 3 */
    byte BIT4    :1;           /* TIM1 Counter Modulo Bit 4 */
    byte BIT5    :1;           /* TIM1 Counter Modulo Bit 5 */
    byte BIT6    :1;           /* TIM1 Counter Modulo Bit 6 */
    byte BIT7    :1;           /* TIM1 Counter Modulo Bit 7 */
  } Bits;
  struct {
    byte BIT     :8;
  } MergedBits;
} T1MODLSTR;
extern volatile T1MODLSTR _T1MODL @0x0024;
#define T1MODL _T1MODL.Byte
#define T1MODL_BIT0 _T1MODL.Bits.BIT0
#define T1MODL_BIT1 _T1MODL.Bits.BIT1
#define T1MODL_BIT2 _T1MODL.Bits.BIT2
#define T1MODL_BIT3 _T1MODL.Bits.BIT3
#define T1MODL_BIT4 _T1MODL.Bits.BIT4
#define T1MODL_BIT5 _T1MODL.Bits.BIT5
#define T1MODL_BIT6 _T1MODL.Bits.BIT6
#define T1MODL_BIT7 _T1MODL.Bits.BIT7
#define T1MODL_BIT _T1MODL.MergedBits.BIT

/*** T1SC0 - TIM1 Channel 0 Status and Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte CH0MAX  :1;           /* Channel 0 Maximum Duty Cycle Bit */
    byte TOV0    :1;           /* Toggle-On-Overflow Bit */
    byte ELS0A   :1;           /* Edge/Level Select Bit */
    byte ELS0B   :1;           /* Edge/Level Select Bit */
    byte MS0A    :1;           /* Mode Select Bit A */
    byte MS0B    :1;           /* Mode Select Bit B */
    byte CH0IE   :1;           /* Channel 0 Interrupt Enable Bit */
    byte CH0F    :1;           /* Channel 0 Flag Bit */
  } Bits;
} T1SC0STR;
extern volatile T1SC0STR _T1SC0 @0x0025;
#define T1SC0 _T1SC0.Byte
#define T1SC0_CH0MAX _T1SC0.Bits.CH0MAX
#define T1SC0_TOV0 _T1SC0.Bits.TOV0
#define T1SC0_ELS0A _T1SC0.Bits.ELS0A
#define T1SC0_ELS0B _T1SC0.Bits.ELS0B
#define T1SC0_MS0A _T1SC0.Bits.MS0A
#define T1SC0_MS0B _T1SC0.Bits.MS0B
#define T1SC0_CH0IE _T1SC0.Bits.CH0IE
#define T1SC0_CH0F _T1SC0.Bits.CH0F

/*** T1CH0H - TIM1 Channel 0 Register High ***/
typedef union {
  byte Byte;
  struct {
    byte BIT8    :1;           /* TIM1 Channel 0 Register BIT 8 */
    byte BIT9    :1;           /* TIM1 Channel 0 Register BIT 9 */
    byte BIT10   :1;           /* TIM1 Channel 0 Register BIT 10 */
    byte BIT11   :1;           /* TIM1 Channel 0 Register BIT 11 */
    byte BIT12   :1;           /* TIM1 Channel 0 Register BIT 12 */
    byte BIT13   :1;           /* TIM1 Channel 0 Register BIT 13 */
    byte BIT14   :1;           /* TIM1 Channel 0 Register BIT 14 */
    byte BIT15   :1;           /* TIM1 Channel 0 Register BIT 15 */
  } Bits;
  struct {
    byte BIT_8   :8;
  } MergedBits;
} T1CH0HSTR;
extern volatile T1CH0HSTR _T1CH0H @0x0026;
#define T1CH0H _T1CH0H.Byte
#define T1CH0H_BIT8 _T1CH0H.Bits.BIT8
#define T1CH0H_BIT9 _T1CH0H.Bits.BIT9
#define T1CH0H_BIT10 _T1CH0H.Bits.BIT10
#define T1CH0H_BIT11 _T1CH0H.Bits.BIT11
#define T1CH0H_BIT12 _T1CH0H.Bits.BIT12
#define T1CH0H_BIT13 _T1CH0H.Bits.BIT13
#define T1CH0H_BIT14 _T1CH0H.Bits.BIT14
#define T1CH0H_BIT15 _T1CH0H.Bits.BIT15
#define T1CH0H_BIT_8 _T1CH0H.MergedBits.BIT_8

/*** T1CH0L - TIM1 Channel 0 Register Low ***/
typedef union {
  byte Byte;
  struct {
    byte BIT0    :1;           /* TIM1 Channel 0 Register BIT 0 */
    byte BIT1    :1;           /* TIM1 Channel 0 Register BIT 1 */
    byte BIT2    :1;           /* TIM1 Channel 0 Register BIT 2 */
    byte BIT3    :1;           /* TIM1 Channel 0 Register BIT 3 */
    byte BIT4    :1;           /* TIM1 Channel 0 Register BIT 4 */
    byte BIT5    :1;           /* TIM1 Channel 0 Register BIT 5 */
    byte BIT6    :1;           /* TIM1 Channel 0 Register BIT 6 */
    byte BIT7    :1;           /* TIM1 Channel 0 Register BIT 7 */
  } Bits;
  struct {
    byte BIT     :8;
  } MergedBits;
} T1CH0LSTR;
extern volatile T1CH0LSTR _T1CH0L @0x0027;
#define T1CH0L _T1CH0L.Byte
#define T1CH0L_BIT0 _T1CH0L.Bits.BIT0
#define T1CH0L_BIT1 _T1CH0L.Bits.BIT1
#define T1CH0L_BIT2 _T1CH0L.Bits.BIT2
#define T1CH0L_BIT3 _T1CH0L.Bits.BIT3
#define T1CH0L_BIT4 _T1CH0L.Bits.BIT4
#define T1CH0L_BIT5 _T1CH0L.Bits.BIT5
#define T1CH0L_BIT6 _T1CH0L.Bits.BIT6
#define T1CH0L_BIT7 _T1CH0L.Bits.BIT7
#define T1CH0L_BIT _T1CH0L.MergedBits.BIT

/*** T1SC1 - TIM1 Channel 1 Status and Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte CH1MAX  :1;           /* Channel 1 Maximum Duty Cycle Bit */
    byte TOV1    :1;           /* Toggle-On-Overflow Bit */
    byte ELS1A   :1;           /* Edge/Level Select Bit */
    byte ELS1B   :1;           /* Edge/Level Select Bit */
    byte MS1A    :1;           /* Mode Select Bit A */
    byte         :1;
    byte CH1IE   :1;           /* Channel 1 Interrupt Enable Bit */
    byte CH1F    :1;           /* Channel 1 Flag Bit */
  } Bits;
} T1SC1STR;
extern volatile T1SC1STR _T1SC1 @0x0028;
#define T1SC1 _T1SC1.Byte
#define T1SC1_CH1MAX _T1SC1.Bits.CH1MAX
#define T1SC1_TOV1 _T1SC1.Bits.TOV1
#define T1SC1_ELS1A _T1SC1.Bits.ELS1A
#define T1SC1_ELS1B _T1SC1.Bits.ELS1B
#define T1SC1_MS1A _T1SC1.Bits.MS1A
#define T1SC1_CH1IE _T1SC1.Bits.CH1IE
#define T1SC1_CH1F _T1SC1.Bits.CH1F

/*** T1CH1H - TIM1 Channel 1 Register High ***/
typedef union {
  byte Byte;
  struct {
    byte BIT8    :1;           /* TIM1 Channel 1 Register BIT 8 */
    byte BIT9    :1;           /* TIM1 Channel 1 Register BIT 9 */
    byte BIT10   :1;           /* TIM1 Channel 1 Register BIT 10 */
    byte BIT11   :1;           /* TIM1 Channel 1 Register BIT 11 */
    byte BIT12   :1;           /* TIM1 Channel 1 Register BIT 12 */
    byte BIT13   :1;           /* TIM1 Channel 1 Register BIT 13 */
    byte BIT14   :1;           /* TIM1 Channel 1 Register BIT 14 */
    byte BIT15   :1;           /* TIM1 Channel 1 Register BIT 15 */
  } Bits;
  struct {
    byte BIT_8   :8;
  } MergedBits;
} T1CH1HSTR;
extern volatile T1CH1HSTR _T1CH1H @0x0029;
#define T1CH1H _T1CH1H.Byte
#define T1CH1H_BIT8 _T1CH1H.Bits.BIT8
#define T1CH1H_BIT9 _T1CH1H.Bits.BIT9
#define T1CH1H_BIT10 _T1CH1H.Bits.BIT10
#define T1CH1H_BIT11 _T1CH1H.Bits.BIT11
#define T1CH1H_BIT12 _T1CH1H.Bits.BIT12
#define T1CH1H_BIT13 _T1CH1H.Bits.BIT13
#define T1CH1H_BIT14 _T1CH1H.Bits.BIT14
#define T1CH1H_BIT15 _T1CH1H.Bits.BIT15
#define T1CH1H_BIT_8 _T1CH1H.MergedBits.BIT_8

/*** T1CH1L - TIM1 Channel 1 Register Low ***/
typedef union {
  byte Byte;
  struct {
    byte BIT0    :1;           /* TIM1 Channel 1 Register BIT 0 */
    byte BIT1    :1;           /* TIM1 Channel 1 Register BIT 1 */
    byte BIT2    :1;           /* TIM1 Channel 1 Register BIT 2 */
    byte BIT3    :1;           /* TIM1 Channel 1 Register BIT 3 */
    byte BIT4    :1;           /* TIM1 Channel 1 Register BIT 4 */
    byte BIT5    :1;           /* TIM1 Channel 1 Register BIT 5 */
    byte BIT6    :1;           /* TIM1 Channel 1 Register BIT 6 */
    byte BIT7    :1;           /* TIM1 Channel 1 Register BIT 7 */
  } Bits;
  struct {
    byte BIT     :8;
  } MergedBits;
} T1CH1LSTR;
extern volatile T1CH1LSTR _T1CH1L @0x002A;
#define T1CH1L _T1CH1L.Byte
#define T1CH1L_BIT0 _T1CH1L.Bits.BIT0
#define T1CH1L_BIT1 _T1CH1L.Bits.BIT1
#define T1CH1L_BIT2 _T1CH1L.Bits.BIT2
#define T1CH1L_BIT3 _T1CH1L.Bits.BIT3
#define T1CH1L_BIT4 _T1CH1L.Bits.BIT4
#define T1CH1L_BIT5 _T1CH1L.Bits.BIT5
#define T1CH1L_BIT6 _T1CH1L.Bits.BIT6
#define T1CH1L_BIT7 _T1CH1L.Bits.BIT7
#define T1CH1L_BIT _T1CH1L.MergedBits.BIT

/*** T2SC - TIM2 Status and Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte PS0     :1;           /* Prescaler Select Bit 0 */
    byte PS1     :1;           /* Prescaler Select Bit 1 */
    byte PS2     :1;           /* Prescaler Select Bit 2 */
    byte         :1;
    byte TRST    :1;           /* TIM2 Reset Bit */
    byte TSTOP   :1;           /* TIM2 Stop Bit */
    byte TOIE    :1;           /* TIM2 Overflow Interrupt Enable Bit */
    byte TOF     :1;           /* TIM2 Overflow Flag Bit */
  } Bits;
  struct {
    byte PS      :3;
    byte         :1;
    byte TRST    :1;
    byte TSTOP   :1;
    byte TOIE    :1;
    byte TOF     :1;
  } MergedBits;
} T2SCSTR;
extern volatile T2SCSTR _T2SC @0x002B;
#define T2SC _T2SC.Byte
#define T2SC_PS0 _T2SC.Bits.PS0
#define T2SC_PS1 _T2SC.Bits.PS1
#define T2SC_PS2 _T2SC.Bits.PS2
#define T2SC_TRST _T2SC.Bits.TRST
#define T2SC_TSTOP _T2SC.Bits.TSTOP
#define T2SC_TOIE _T2SC.Bits.TOIE
#define T2SC_TOF _T2SC.Bits.TOF
#define T2SC_PS _T2SC.MergedBits.PS

/*** T2CNTH - TIM2 Counter Register High ***/
typedef union {
  byte Byte;
  struct {
    byte BIT8    :1;           /* TIM2 Counter Register Bit 8 */
    byte BIT9    :1;           /* TIM2 Counter Register Bit 9 */
    byte BIT10   :1;           /* TIM2 Counter Register Bit 10 */
    byte BIT11   :1;           /* TIM2 Counter Register Bit 11 */
    byte BIT12   :1;           /* TIM2 Counter Register Bit 12 */
    byte BIT13   :1;           /* TIM2 Counter Register Bit 13 */
    byte BIT14   :1;           /* TIM2 Counter Register Bit 14 */
    byte BIT15   :1;           /* TIM2 Counter Register Bit 15 */
  } Bits;
  struct {
    byte BIT_8   :8;
  } MergedBits;
} T2CNTHSTR;
extern volatile T2CNTHSTR _T2CNTH @0x002C;
#define T2CNTH _T2CNTH.Byte
#define T2CNTH_BIT8 _T2CNTH.Bits.BIT8
#define T2CNTH_BIT9 _T2CNTH.Bits.BIT9
#define T2CNTH_BIT10 _T2CNTH.Bits.BIT10
#define T2CNTH_BIT11 _T2CNTH.Bits.BIT11
#define T2CNTH_BIT12 _T2CNTH.Bits.BIT12
#define T2CNTH_BIT13 _T2CNTH.Bits.BIT13
#define T2CNTH_BIT14 _T2CNTH.Bits.BIT14
#define T2CNTH_BIT15 _T2CNTH.Bits.BIT15
#define T2CNTH_BIT_8 _T2CNTH.MergedBits.BIT_8

/*** T2CNTL - TIM2 Counter Register Low ***/
typedef union {
  byte Byte;
  struct {
    byte BIT0    :1;           /* TIM2 Counter Register Bit 0 */
    byte BIT1    :1;           /* TIM2 Counter Register Bit 1 */
    byte BIT2    :1;           /* TIM2 Counter Register Bit 2 */
    byte BIT3    :1;           /* TIM2 Counter Register Bit 3 */
    byte BIT4    :1;           /* TIM2 Counter Register Bit 4 */
    byte BIT5    :1;           /* TIM2 Counter Register Bit 5 */
    byte BIT6    :1;           /* TIM2 Counter Register Bit 6 */
    byte BIT7    :1;           /* TIM2 Counter Register Bit 7 */
  } Bits;
  struct {
    byte BIT     :8;
  } MergedBits;
} T2CNTLSTR;
extern volatile T2CNTLSTR _T2CNTL @0x002D;
#define T2CNTL _T2CNTL.Byte
#define T2CNTL_BIT0 _T2CNTL.Bits.BIT0
#define T2CNTL_BIT1 _T2CNTL.Bits.BIT1
#define T2CNTL_BIT2 _T2CNTL.Bits.BIT2
#define T2CNTL_BIT3 _T2CNTL.Bits.BIT3
#define T2CNTL_BIT4 _T2CNTL.Bits.BIT4
#define T2CNTL_BIT5 _T2CNTL.Bits.BIT5
#define T2CNTL_BIT6 _T2CNTL.Bits.BIT6
#define T2CNTL_BIT7 _T2CNTL.Bits.BIT7
#define T2CNTL_BIT _T2CNTL.MergedBits.BIT

/*** T2MODH - TIM2 Counter Modulo Register High ***/
typedef union {
  byte Byte;
  struct {
    byte BIT8    :1;           /* TIM2 Counter Modulo Bit 8 */
    byte BIT9    :1;           /* TIM2 Counter Modulo Bit 9 */
    byte BIT10   :1;           /* TIM2 Counter Modulo Bit 10 */
    byte BIT11   :1;           /* TIM2 Counter Modulo Bit 11 */
    byte BIT12   :1;           /* TIM2 Counter Modulo Bit 12 */
    byte BIT13   :1;           /* TIM2 Counter Modulo Bit 13 */
    byte BIT14   :1;           /* TIM2 Counter Modulo Bit 14 */
    byte BIT15   :1;           /* TIM2 Counter Modulo Bit 15 */
  } Bits;
  struct {
    byte BIT_8   :8;
  } MergedBits;
} T2MODHSTR;
extern volatile T2MODHSTR _T2MODH @0x002E;
#define T2MODH _T2MODH.Byte
#define T2MODH_BIT8 _T2MODH.Bits.BIT8
#define T2MODH_BIT9 _T2MODH.Bits.BIT9
#define T2MODH_BIT10 _T2MODH.Bits.BIT10
#define T2MODH_BIT11 _T2MODH.Bits.BIT11
#define T2MODH_BIT12 _T2MODH.Bits.BIT12
#define T2MODH_BIT13 _T2MODH.Bits.BIT13
#define T2MODH_BIT14 _T2MODH.Bits.BIT14
#define T2MODH_BIT15 _T2MODH.Bits.BIT15
#define T2MODH_BIT_8 _T2MODH.MergedBits.BIT_8

/*** T2MODL - TIM2 Counter Modulo Register Low ***/
typedef union {
  byte Byte;
  struct {
    byte BIT0    :1;           /* TIM2 Counter Modulo Bit 0 */
    byte BIT1    :1;           /* TIM2 Counter Modulo Bit 1 */
    byte BIT2    :1;           /* TIM2 Counter Modulo Bit 2 */
    byte BIT3    :1;           /* TIM2 Counter Modulo Bit 3 */
    byte BIT4    :1;           /* TIM2 Counter Modulo Bit 4 */
    byte BIT5    :1;           /* TIM2 Counter Modulo Bit 5 */
    byte BIT6    :1;           /* TIM2 Counter Modulo Bit 6 */
    byte BIT7    :1;           /* TIM2 Counter Modulo Bit 7 */
  } Bits;
  struct {
    byte BIT     :8;
  } MergedBits;
} T2MODLSTR;
extern volatile T2MODLSTR _T2MODL @0x002F;
#define T2MODL _T2MODL.Byte
#define T2MODL_BIT0 _T2MODL.Bits.BIT0
#define T2MODL_BIT1 _T2MODL.Bits.BIT1
#define T2MODL_BIT2 _T2MODL.Bits.BIT2
#define T2MODL_BIT3 _T2MODL.Bits.BIT3
#define T2MODL_BIT4 _T2MODL.Bits.BIT4
#define T2MODL_BIT5 _T2MODL.Bits.BIT5
#define T2MODL_BIT6 _T2MODL.Bits.BIT6
#define T2MODL_BIT7 _T2MODL.Bits.BIT7
#define T2MODL_BIT _T2MODL.MergedBits.BIT

/*** T2SC0 - TIM2 Channel 0 Status and Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte CH0MAX  :1;           /* Channel 0 Maximum Duty Cycle Bit */
    byte TOV0    :1;           /* Toggle-On-Overflow Bit */
    byte ELS0A   :1;           /* Edge/Level Select Bit */
    byte ELS0B   :1;           /* Edge/Level Select Bit */
    byte MS0A    :1;           /* Mode Select Bit A */
    byte MS0B    :1;           /* Mode Select Bit B */
    byte CH0IE   :1;           /* Channel 0 Interrupt Enable Bit */
    byte CH0F    :1;           /* Channel 0 Flag Bit */
  } Bits;
} T2SC0STR;
extern volatile T2SC0STR _T2SC0 @0x0030;
#define T2SC0 _T2SC0.Byte
#define T2SC0_CH0MAX _T2SC0.Bits.CH0MAX
#define T2SC0_TOV0 _T2SC0.Bits.TOV0
#define T2SC0_ELS0A _T2SC0.Bits.ELS0A
#define T2SC0_ELS0B _T2SC0.Bits.ELS0B
#define T2SC0_MS0A _T2SC0.Bits.MS0A
#define T2SC0_MS0B _T2SC0.Bits.MS0B
#define T2SC0_CH0IE _T2SC0.Bits.CH0IE
#define T2SC0_CH0F _T2SC0.Bits.CH0F

/*** T2CH0H - TIM2 Channel 0 Register High ***/
typedef union {
  byte Byte;
  struct {
    byte BIT8    :1;           /* TIM2 Channel 0 Register BIT 8 */
    byte BIT9    :1;           /* TIM2 Channel 0 Register BIT 9 */
    byte BIT10   :1;           /* TIM2 Channel 0 Register BIT 10 */
    byte BIT11   :1;           /* TIM2 Channel 0 Register BIT 11 */
    byte BIT12   :1;           /* TIM2 Channel 0 Register BIT 12 */
    byte BIT13   :1;           /* TIM2 Channel 0 Register BIT 13 */
    byte BIT14   :1;           /* TIM2 Channel 0 Register BIT 14 */
    byte BIT15   :1;           /* TIM2 Channel 0 Register BIT 15 */
  } Bits;
  struct {
    byte BIT_8   :8;
  } MergedBits;
} T2CH0HSTR;
extern volatile T2CH0HSTR _T2CH0H @0x0031;
#define T2CH0H _T2CH0H.Byte
#define T2CH0H_BIT8 _T2CH0H.Bits.BIT8
#define T2CH0H_BIT9 _T2CH0H.Bits.BIT9
#define T2CH0H_BIT10 _T2CH0H.Bits.BIT10
#define T2CH0H_BIT11 _T2CH0H.Bits.BIT11
#define T2CH0H_BIT12 _T2CH0H.Bits.BIT12
#define T2CH0H_BIT13 _T2CH0H.Bits.BIT13
#define T2CH0H_BIT14 _T2CH0H.Bits.BIT14
#define T2CH0H_BIT15 _T2CH0H.Bits.BIT15
#define T2CH0H_BIT_8 _T2CH0H.MergedBits.BIT_8

/*** T2CH0L - TIM2 Channel 0 Register Low ***/
typedef union {
  byte Byte;
  struct {
    byte BIT0    :1;           /* TIM2 Channel 0 Register BIT 0 */
    byte BIT1    :1;           /* TIM2 Channel 0 Register BIT 1 */
    byte BIT2    :1;           /* TIM2 Channel 0 Register BIT 2 */
    byte BIT3    :1;           /* TIM2 Channel 0 Register BIT 3 */
    byte BIT4    :1;           /* TIM2 Channel 0 Register BIT 4 */
    byte BIT5    :1;           /* TIM2 Channel 0 Register BIT 5 */
    byte BIT6    :1;           /* TIM2 Channel 0 Register BIT 6 */
    byte BIT7    :1;           /* TIM2 Channel 0 Register BIT 7 */
  } Bits;
  struct {
    byte BIT     :8;
  } MergedBits;
} T2CH0LSTR;
extern volatile T2CH0LSTR _T2CH0L @0x0032;
#define T2CH0L _T2CH0L.Byte
#define T2CH0L_BIT0 _T2CH0L.Bits.BIT0
#define T2CH0L_BIT1 _T2CH0L.Bits.BIT1
#define T2CH0L_BIT2 _T2CH0L.Bits.BIT2
#define T2CH0L_BIT3 _T2CH0L.Bits.BIT3
#define T2CH0L_BIT4 _T2CH0L.Bits.BIT4
#define T2CH0L_BIT5 _T2CH0L.Bits.BIT5
#define T2CH0L_BIT6 _T2CH0L.Bits.BIT6
#define T2CH0L_BIT7 _T2CH0L.Bits.BIT7
#define T2CH0L_BIT _T2CH0L.MergedBits.BIT

/*** T2SC1 - TIM2 Channel 1 Status and Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte CH1MAX  :1;           /* Channel 1 Maximum Duty Cycle Bit */
    byte TOV1    :1;           /* Toggle-On-Overflow Bit */
    byte ELS1A   :1;           /* Edge/Level Select Bit */
    byte ELS1B   :1;           /* Edge/Level Select Bit */
    byte MS1A    :1;           /* Mode Select Bit A */
    byte         :1;
    byte CH1IE   :1;           /* Channel 1 Interrupt Enable Bit */
    byte CH1F    :1;           /* Channel 1 Flag Bit */
  } Bits;
} T2SC1STR;
extern volatile T2SC1STR _T2SC1 @0x0033;
#define T2SC1 _T2SC1.Byte
#define T2SC1_CH1MAX _T2SC1.Bits.CH1MAX
#define T2SC1_TOV1 _T2SC1.Bits.TOV1
#define T2SC1_ELS1A _T2SC1.Bits.ELS1A
#define T2SC1_ELS1B _T2SC1.Bits.ELS1B
#define T2SC1_MS1A _T2SC1.Bits.MS1A
#define T2SC1_CH1IE _T2SC1.Bits.CH1IE
#define T2SC1_CH1F _T2SC1.Bits.CH1F

/*** T2CH1H - TIM2 Channel 1 Register High ***/
typedef union {
  byte Byte;
  struct {
    byte BIT8    :1;           /* TIM2 Channel 1 Register BIT 8 */
    byte BIT9    :1;           /* TIM2 Channel 1 Register BIT 9 */
    byte BIT10   :1;           /* TIM2 Channel 1 Register BIT 10 */
    byte BIT11   :1;           /* TIM2 Channel 1 Register BIT 11 */
    byte BIT12   :1;           /* TIM2 Channel 1 Register BIT 12 */
    byte BIT13   :1;           /* TIM2 Channel 1 Register BIT 13 */
    byte BIT14   :1;           /* TIM2 Channel 1 Register BIT 14 */
    byte BIT15   :1;           /* TIM2 Channel 1 Register BIT 15 */
  } Bits;
  struct {
    byte BIT_8   :8;
  } MergedBits;
} T2CH1HSTR;
extern volatile T2CH1HSTR _T2CH1H @0x0034;
#define T2CH1H _T2CH1H.Byte
#define T2CH1H_BIT8 _T2CH1H.Bits.BIT8
#define T2CH1H_BIT9 _T2CH1H.Bits.BIT9
#define T2CH1H_BIT10 _T2CH1H.Bits.BIT10
#define T2CH1H_BIT11 _T2CH1H.Bits.BIT11
#define T2CH1H_BIT12 _T2CH1H.Bits.BIT12
#define T2CH1H_BIT13 _T2CH1H.Bits.BIT13
#define T2CH1H_BIT14 _T2CH1H.Bits.BIT14
#define T2CH1H_BIT15 _T2CH1H.Bits.BIT15
#define T2CH1H_BIT_8 _T2CH1H.MergedBits.BIT_8

/*** T2CH1L - TIM2 Channel 1 Register Low ***/
typedef union {
  byte Byte;
  struct {
    byte BIT0    :1;           /* TIM2 Channel 1 Register BIT 0 */
    byte BIT1    :1;           /* TIM2 Channel 1 Register BIT 1 */
    byte BIT2    :1;           /* TIM2 Channel 1 Register BIT 2 */
    byte BIT3    :1;           /* TIM2 Channel 1 Register BIT 3 */
    byte BIT4    :1;           /* TIM2 Channel 1 Register BIT 4 */
    byte BIT5    :1;           /* TIM2 Channel 1 Register BIT 5 */
    byte BIT6    :1;           /* TIM2 Channel 1 Register BIT 6 */
    byte BIT7    :1;           /* TIM2 Channel 1 Register BIT 7 */
  } Bits;
  struct {
    byte BIT     :8;
  } MergedBits;
} T2CH1LSTR;
extern volatile T2CH1LSTR _T2CH1L @0x0035;
#define T2CH1L _T2CH1L.Byte
#define T2CH1L_BIT0 _T2CH1L.Bits.BIT0
#define T2CH1L_BIT1 _T2CH1L.Bits.BIT1
#define T2CH1L_BIT2 _T2CH1L.Bits.BIT2
#define T2CH1L_BIT3 _T2CH1L.Bits.BIT3
#define T2CH1L_BIT4 _T2CH1L.Bits.BIT4
#define T2CH1L_BIT5 _T2CH1L.Bits.BIT5
#define T2CH1L_BIT6 _T2CH1L.Bits.BIT6
#define T2CH1L_BIT7 _T2CH1L.Bits.BIT7
#define T2CH1L_BIT _T2CH1L.MergedBits.BIT

/*** PCTL - PLL Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte VPR0   :1;           /* VCO Power-of-Tow Range Select Bit 0 */
    byte VPR1   :1;           /* VCO Power-of-Tow Range Select Bit 1 */
    byte PRE0   :1;           /* Prescaler Program Bit 0 */
    byte PRE1   :1;           /* Prescaler Program Bit 1 */
    byte BCS    :1;           /* Base Clock Select Bit */
    byte PLLON  :1;           /* PLL On Bit */
    byte PLLF   :1;           /* PLL Interrupt Flag Bit */
    byte PLLIE  :1;           /* PLL Interrupt Enable Bit */
  } Bits;
  struct {
    byte VPR    :2;
    byte PRE    :2;
    byte BCS    :1;
    byte PLLON  :1;
    byte PLLF   :1;
    byte PLLIE  :1;
  } MergedBits;
} PCTLSTR;
extern volatile PCTLSTR _PCTL @0x0036;
#define PCTL _PCTL.Byte
#define PCTL_VPR0 _PCTL.Bits.VPR0
#define PCTL_VPR1 _PCTL.Bits.VPR1
#define PCTL_PRE0 _PCTL.Bits.PRE0
#define PCTL_PRE1 _PCTL.Bits.PRE1
#define PCTL_BCS _PCTL.Bits.BCS
#define PCTL_PLLON _PCTL.Bits.PLLON
#define PCTL_PLLF _PCTL.Bits.PLLF
#define PCTL_PLLIE _PCTL.Bits.PLLIE
#define PCTL_VPR _PCTL.MergedBits.VPR
#define PCTL_PRE _PCTL.MergedBits.PRE

/*** PBWC - PLL Bandwith Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte ACQ     :1;           /* Acquisition Mode Bit */
    byte LOCK    :1;           /* Lock Indicator Bit */
    byte AUTO    :1;           /* Automatic Bandwith Control Bit */
  } Bits;
} PBWCSTR;
extern volatile PBWCSTR _PBWC @0x0037;
#define PBWC _PBWC.Byte
#define PBWC_ACQ _PBWC.Bits.ACQ
#define PBWC_LOCK _PBWC.Bits.LOCK
#define PBWC_AUTO _PBWC.Bits.AUTO

/*** PMSH - PLL Multiplier Select Register High ***/
typedef union {
  byte Byte;
  struct {
    byte MUL8    :1;           /* PLL Multiplier Select Bit 8 */
    byte MUL9    :1;           /* PLL Multiplier Select Bit 9 */
    byte MUL10   :1;           /* PLL Multiplier Select Bit 10 */
    byte MUL11   :1;           /* PLL Multiplier Select Bit 11 */
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
  } Bits;
  struct {
    byte MUL_8   :4;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
  } MergedBits;
} PMSHSTR;
extern volatile PMSHSTR _PMSH @0x0038;
#define PMSH _PMSH.Byte
#define PMSH_MUL8 _PMSH.Bits.MUL8
#define PMSH_MUL9 _PMSH.Bits.MUL9
#define PMSH_MUL10 _PMSH.Bits.MUL10
#define PMSH_MUL11 _PMSH.Bits.MUL11
#define PMSH_MUL_8 _PMSH.MergedBits.MUL_8

/*** PMSL - PLL Multiplier Select Register Low ***/
typedef union {
  byte Byte;
  struct {
    byte MUL0    :1;           /* PLL Multiplier Select Bit 0 */
    byte MUL1    :1;           /* PLL Multiplier Select Bit 1 */
    byte MUL2    :1;           /* PLL Multiplier Select Bit 2 */
    byte MUL3    :1;           /* PLL Multiplier Select Bit 3 */
    byte MUL4    :1;           /* PLL Multiplier Select Bit 4 */
    byte MUL5    :1;           /* PLL Multiplier Select Bit 5 */
    byte MUL6    :1;           /* PLL Multiplier Select Bit 6 */
    byte MUL7    :1;           /* PLL Multiplier Select Bit 7 */
  } Bits;
  struct {
    byte MUL     :8;
  } MergedBits;
} PMSLSTR;
extern volatile PMSLSTR _PMSL @0x0039;
#define PMSL _PMSL.Byte
#define PMSL_MUL0 _PMSL.Bits.MUL0
#define PMSL_MUL1 _PMSL.Bits.MUL1
#define PMSL_MUL2 _PMSL.Bits.MUL2
#define PMSL_MUL3 _PMSL.Bits.MUL3
#define PMSL_MUL4 _PMSL.Bits.MUL4
#define PMSL_MUL5 _PMSL.Bits.MUL5
#define PMSL_MUL6 _PMSL.Bits.MUL6
#define PMSL_MUL7 _PMSL.Bits.MUL7
#define PMSL_MUL _PMSL.MergedBits.MUL

/*** PMRS - PLL VCO Range Select ***/
typedef union {
  byte Byte;
  struct {
    byte VRS0    :1;           /* VCO Range Select Bit 0 */
    byte VRS1    :1;           /* VCO Range Select Bit 1 */
    byte VRS2    :1;           /* VCO Range Select Bit 2 */
    byte VRS3    :1;           /* VCO Range Select Bit 3 */
    byte VRS4    :1;           /* VCO Range Select Bit 4 */
    byte VRS5    :1;           /* VCO Range Select Bit 5 */
    byte VRS6    :1;           /* VCO Range Select Bit 6 */
    byte VRS7    :1;           /* VCO Range Select Bit 7 */
  } Bits;
  struct {
    byte VRS     :8;
  } MergedBits;
} PMRSSTR;
extern volatile PMRSSTR _PMRS @0x003A;
#define PMRS _PMRS.Byte
#define PMRS_VRS0 _PMRS.Bits.VRS0
#define PMRS_VRS1 _PMRS.Bits.VRS1
#define PMRS_VRS2 _PMRS.Bits.VRS2
#define PMRS_VRS3 _PMRS.Bits.VRS3
#define PMRS_VRS4 _PMRS.Bits.VRS4
#define PMRS_VRS5 _PMRS.Bits.VRS5
#define PMRS_VRS6 _PMRS.Bits.VRS6
#define PMRS_VRS7 _PMRS.Bits.VRS7
#define PMRS_VRS _PMRS.MergedBits.VRS

/*** PMDS - PLL Reference Divider Select Register ***/
typedef union {
  byte Byte;
  struct {
    byte RDS0    :1;           /* Reference Divider Select Bit 0 */
    byte RDS1    :1;           /* Reference Divider Select Bit 1 */
    byte RDS2    :1;           /* Reference Divider Select Bit 2 */
    byte RDS3    :1;           /* Reference Divider Select Bit 3 */
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
  } Bits;
  struct {
    byte RDS     :4;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
  } MergedBits;
} PMDSSTR;
extern volatile PMDSSTR _PMDS @0x003B;
#define PMDS _PMDS.Byte
#define PMDS_RDS0 _PMDS.Bits.RDS0
#define PMDS_RDS1 _PMDS.Bits.RDS1
#define PMDS_RDS2 _PMDS.Bits.RDS2
#define PMDS_RDS3 _PMDS.Bits.RDS3
#define PMDS_RDS _PMDS.MergedBits.RDS

/*** IRSCI_SCC1 - IRSCI Control Register 1 ***/
typedef union {
  byte Byte;
  struct {
    byte PTY     :1;           /* Parity Bit */
    byte PEN     :1;           /* Parity Enable Bit */
    byte ILTY    :1;           /* Idle Line Type Bit */
    byte WAKE    :1;           /* Wakeup Condition Bit */
    byte M       :1;           /* Mode (Character Length) Bit */
    byte         :1;          
    byte ENSCI   :1;           /* Enable SCI Bit */
    byte LOOPS   :1;           /* Loop Mode Select Bit */
  } Bits;
} IRSCI_SCC1STR;
extern volatile IRSCI_SCC1STR _IRSCI_SCC1 @0x0040;
#define IRSCI_SCC1 _IRSCI_SCC1.Byte
#define IRSCI_SCC1_PTY _IRSCI_SCC1.Bits.PTY
#define IRSCI_SCC1_PEN _IRSCI_SCC1.Bits.PEN
#define IRSCI_SCC1_ILTY _IRSCI_SCC1.Bits.ILTY
#define IRSCI_SCC1_WAKE _IRSCI_SCC1.Bits.WAKE
#define IRSCI_SCC1_M _IRSCI_SCC1.Bits.M
#define IRSCI_SCC1_ENSCI _IRSCI_SCC1.Bits.ENSCI
#define IRSCI_SCC1_LOOPS _IRSCI_SCC1.Bits.LOOPS

/*** IRSCI_SCC2 - IRSCI Control Register 2 ***/
typedef union {
  byte Byte;
  struct {
    byte SBK     :1;           /* Send Break Bit */
    byte RWU     :1;           /* Receiver Wakeup Bit */
    byte RE      :1;           /* Receiver Enable Bit */
    byte TE      :1;           /* Transmitter Enable Bit */
    byte ILIE    :1;           /* Idle Line Interrupt Enable Bit */
    byte SCRIE   :1;           /* SCI Receive Interrupt Enable Bit */
    byte TCIE    :1;           /* Transmission Complete Interrupt Enable Bit */
    byte SCTIE   :1;           /* SCI Transmit Interrupt Enable Bit */
  } Bits;
} IRSCI_SCC2STR;
extern volatile IRSCI_SCC2STR _IRSCI_SCC2 @0x0041;
#define IRSCI_SCC2 _IRSCI_SCC2.Byte
#define IRSCI_SCC2_SBK _IRSCI_SCC2.Bits.SBK
#define IRSCI_SCC2_RWU _IRSCI_SCC2.Bits.RWU
#define IRSCI_SCC2_RE _IRSCI_SCC2.Bits.RE
#define IRSCI_SCC2_TE _IRSCI_SCC2.Bits.TE
#define IRSCI_SCC2_ILIE _IRSCI_SCC2.Bits.ILIE
#define IRSCI_SCC2_SCRIE _IRSCI_SCC2.Bits.SCRIE
#define IRSCI_SCC2_TCIE _IRSCI_SCC2.Bits.TCIE
#define IRSCI_SCC2_SCTIE _IRSCI_SCC2.Bits.SCTIE

/*** IRSCI_SCC3 - IRSCI Control Register 3 ***/
typedef union {
  byte Byte;
  struct {
    byte PEIE    :1;           /* Receiver Parity Error Interrupt Enable Bit */
    byte FEIE    :1;           /* Receiver Framing Error Interrupt Enable Bit */
    byte NEIE    :1;           /* Receiver Noise Error Interrupt Enable Bit */
    byte ORIE    :1;           /* Receiver Overrun Interrupt Enable Bit */
    byte DMATE   :1;           /* DMA Transfer Enable Bit */
    byte DMARE   :1;           /* DMA Receive Enable Bit */
    byte T8      :1;           /* Transmitted Bit 8 */
    byte R8      :1;           /* Received Bit 8 */
  } Bits;
} IRSCI_SCC3STR;
extern volatile IRSCI_SCC3STR _IRSCI_SCC3 @0x0042;
#define IRSCI_SCC3 _IRSCI_SCC3.Byte
#define IRSCI_SCC3_PEIE _IRSCI_SCC3.Bits.PEIE
#define IRSCI_SCC3_FEIE _IRSCI_SCC3.Bits.FEIE
#define IRSCI_SCC3_NEIE _IRSCI_SCC3.Bits.NEIE
#define IRSCI_SCC3_ORIE _IRSCI_SCC3.Bits.ORIE
#define IRSCI_SCC3_DMATE _IRSCI_SCC3.Bits.DMATE
#define IRSCI_SCC3_DMARE _IRSCI_SCC3.Bits.DMARE
#define IRSCI_SCC3_T8 _IRSCI_SCC3.Bits.T8
#define IRSCI_SCC3_R8 _IRSCI_SCC3.Bits.R8

/*** IRSCI_SCS1 - IRSCI Status Register 1 ***/
typedef union {
  byte Byte;
  struct {
    byte PE      :1;           /* Receiver Parity Error Bit */
    byte FE      :1;           /* Receiver Framing Error Bit */
    byte NF      :1;           /* Receiver Noise Flag Bit */
    byte OR      :1;           /* Receiver Overrun Bit */
    byte IDLE    :1;           /* Receiver Idle Bit */
    byte SCRF    :1;           /* SCI Receiver Full Bit */
    byte TC      :1;           /* Transmission Complete Bit */
    byte SCTE    :1;           /* SCI Transmitter Empty Bit */
  } Bits;
} IRSCI_SCS1STR;
extern volatile IRSCI_SCS1STR _IRSCI_SCS1 @0x0043;
#define IRSCI_SCS1 _IRSCI_SCS1.Byte
#define IRSCI_SCS1_PE _IRSCI_SCS1.Bits.PE
#define IRSCI_SCS1_FE _IRSCI_SCS1.Bits.FE
#define IRSCI_SCS1_NF _IRSCI_SCS1.Bits.NF
#define IRSCI_SCS1_OR _IRSCI_SCS1.Bits.OR
#define IRSCI_SCS1_IDLE _IRSCI_SCS1.Bits.IDLE
#define IRSCI_SCS1_SCRF _IRSCI_SCS1.Bits.SCRF
#define IRSCI_SCS1_TC _IRSCI_SCS1.Bits.TC
#define IRSCI_SCS1_SCTE _IRSCI_SCS1.Bits.SCTE

/*** IRSCI_SCIRSCI_ - IRSCI Status Register 2 ***/
typedef union {
  byte Byte;
  struct {
    byte RPF     :1;           /* Reception in Progress Flag Bit */
    byte BKF     :1;           /* Break Flag Bit */
    byte         :1; 
    byte         :1; 
    byte         :1; 
    byte         :1; 
    byte         :1; 
    byte         :1; 
  } Bits;
} IRSCI_SCS2STR;
extern volatile IRSCI_SCS2STR _IRSCI_SCS2 @0x0044;
#define IRSCI_SCS2 _IRSCI_SCS2.Byte
#define IRSCI_SCS2__RPF _IRSCI_SCS2.Bits.RPF
#define IRSCI_SCS2__BKF _IRSCI_SCS2.Bits.BKF

/*** IRSCI_SCDR - IRSCI Data Register ***/
typedef union {
  byte Byte;
  struct {
    byte R0_T0   :1;           /* Receive/Transmit Data Bit 0 */
    byte R1_T1   :1;           /* Receive/Transmit Data Bit 1 */
    byte R2_T2   :1;           /* Receive/Transmit Data Bit 2 */
    byte R3_T3   :1;           /* Receive/Transmit Data Bit 3 */
    byte R4_T4   :1;           /* Receive/Transmit Data Bit 4 */
    byte R5_T5   :1;           /* Receive/Transmit Data Bit 5 */
    byte R6_T6   :1;           /* Receive/Transmit Data Bit 6 */
    byte R7_T7   :1;           /* Receive/Transmit Data Bit 7 */
  } Bits;
  struct {
    byte R_T     :8;
  } MergedBits;
} IRSCI_SCDRSTR;
extern volatile IRSCI_SCDRSTR _IRSCI_SCDR @0x0045;
#define IRSCI_SCDR _IRSCI_SCDR.Byte
#define IRSCI_SCDR_R0_T0 _IRSCI_SCDR.Bits.R0_T0
#define IRSCI_SCDR_R1_T1 _IRSCI_SCDR.Bits.R1_T1
#define IRSCI_SCDR_R2_T2 _IRSCI_SCDR.Bits.R2_T2
#define IRSCI_SCDR_R3_T3 _IRSCI_SCDR.Bits.R3_T3
#define IRSCI_SCDR_R4_T4 _IRSCI_SCDR.Bits.R4_T4
#define IRSCI_SCDR_R5_T5 _IRSCI_SCDR.Bits.R5_T5
#define IRSCI_SCDR_R6_T6 _IRSCI_SCDR.Bits.R6_T6
#define IRSCI_SCDR_R7_T7 _IRSCI_SCDR.Bits.R7_T7
#define IRSCI_SCDR_R_T _IRSCI_SCDR.MergedBits.R_T

/*** IRSCI_SCBR - IRSCI Baud Rate Register ***/
typedef union {
  byte Byte;
  struct {
    byte SCR0    :1;           /* SCI Baud Rate Select Bit 0 */
    byte SCR1    :1;           /* SCI Baud Rate Select Bit 1 */
    byte SCR2    :1;           /* SCI Baud Rate Select Bit 2 */
    byte         :1;
    byte SCP0    :1;           /* SCI Baud Rate Prescaler Bit 0 */
    byte SCP1    :1;           /* SCI Baud Rate Prescaler Bit 1 */
    byte         :1;
    byte CKS     :1;           /* Baud Clock Input Select */
  } Bits;
  struct {
    byte SCR     :3;
    byte         :1;
    byte SCP     :2;
    byte         :1;
    byte CKS     :1;
  } MergedBits;
} IRSCI_SCBRSTR;
extern volatile IRSCI_SCBRSTR _IRSCI_SCBR @0x0046;
#define IRSCI_SCBR _IRSCI_SCBR.Byte
#define IRSCI_SCBR_SCR0 _IRSCI_SCBR.Bits.SCR0
#define IRSCI_SCBR_SCR1 _IRSCI_SCBR.Bits.SCR1
#define IRSCI_SCBR_SCR2 _IRSCI_SCBR.Bits.SCR2
#define IRSCI_SCBR_SCP0 _IRSCI_SCBR.Bits.SCP0
#define IRSCI_SCBR_SCP1 _IRSCI_SCBR.Bits.SCP1
#define IRSCI_SCBR_CKS _IRSCI_SCBR.Bits.CKS
#define IRSCI_SCBR_SCR _IRSCI_SCBR.MergedBits.SCR
#define IRSCI_SCBR_SCP _IRSCI_SCBR.MergedBits.SCP

/*** IRSCI_SCIRCR - IRSCI infra-ref Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte IREN        :1;       /* IR Enable Bit */                 
    byte TNP0        :1;       /* Transmitter Narrow Pulse Bit 0 */    
    byte TNP1        :1;       /* Transmitter Narrow Pulse Bit 1 */    
    byte CKTST       :1;       /* CGMXCLK Clock Output for Test */     
    byte             :1;
    byte             :1;
    byte             :1;
    byte             :1;
  } Bits;
  struct {
    byte IREN        :1;
    byte TNP         :2;
    byte CKTST       :1;
    byte             :1;
    byte             :1;
    byte             :1;
    byte             :1;
  } MergedBits;
} IRSCI_SCIRCRSTR;
extern volatile IRSCI_SCIRCRSTR _IRSCI_SCIRCR @0x0047;
#define IRSCI_SCIRCR _IRSCI_SCIRCR.Byte
#define IRSCI_SCIRCR_IREN _IRSCI_SCIRCR.Bits.IREN
#define IRSCI_SCIRCR_TNP0 _IRSCI_SCIRCR.Bits.TNP0
#define IRSCI_SCIRCR_TNP1 _IRSCI_SCIRCR.Bits.TNP1
#define IRSCI_SCIRCR_CKTST _IRSCI_SCIRCR.Bits.CKTST
#define IRSCI_SCIRCR_TNP _IRSCI_SCIRCR.MergedBits.TNP

/*** MMADR - MMIIC Address Register ***/
typedef union {
  byte Byte;
  struct {
    byte MMEXTAD :1;           /* Muti-Master Expend Adress */
    byte MMAD1   :1;           /* Multi-Master Address 1 */
    byte MMAD2   :1;           /* Multi-Master Address 2 */
    byte MMAD3   :1;           /* Multi-Master Address 3 */
    byte MMAD4   :1;           /* Multi-Master Address 4 */
    byte MMAD5   :1;           /* Multi-Master Address 5 */
    byte MMAD6   :1;           /* Multi-Master Address 6 */
    byte MMAD7   :1;           /* Multi-Master Address 7 */
  } Bits;
  struct {
    byte MMEXTAD :1;
    byte MMAD_1  :7;
  } MergedBits;
} MMADRSTR;
extern volatile MMADRSTR _MMADR @0x0048;
#define MMADR _MMADR.Byte
#define MMADR_MMEXTAD _MMADR.Bits.MMEXTAD
#define MMADR_MMAD1 _MMADR.Bits.MMAD1
#define MMADR_MMAD2 _MMADR.Bits.MMAD2
#define MMADR_MMAD3 _MMADR.Bits.MMAD3
#define MMADR_MMAD4 _MMADR.Bits.MMAD4
#define MMADR_MMAD5 _MMADR.Bits.MMAD5
#define MMADR_MMAD6 _MMADR.Bits.MMAD6
#define MMADR_MMAD7 _MMADR.Bits.MMAD7
#define MMADR_MMAD_1 _MMADR.MergedBits.MMAD_1

/*** MMCR1 - MMIIC Control Register 1 ***/
typedef union {
  byte Byte;
  struct {
    byte              :1;
    byte MMCRCBYTE    :1;           /* MMIIC CRC bit */
    byte REPSEN       :1;           /* Repeat Start Enable */
    byte MMTXAK       :1;           /* MMIIC Transmit Acknowledge Enable */
    byte              :1;
    byte MMCLRBB      :1;           /* MMIIC Clear Busy Flag */
    byte MMIEN        :1;           /* MMIIC Interrupt Enable */
    byte MMEN         :1;           /* MMIIC Enable */
  } Bits;
} MMCR1STR;
extern volatile MMCR1STR _MMCR1 @0x0049;
#define MMCR1 _MMCR1.Byte
#define MMCR1_MMCRCBYTE _MMCR1.Bits.MMCRCBYTE
#define MMCR1_REPSEN _MMCR1.Bits.REPSEN
#define MMCR1_MMTXAK _MMCR1.Bits.MMTXAK
#define MMCR1_MMCLRBB _MMCR1.Bits.MMCLRBB
#define MMCR1_MMIEN _MMCR1.Bits.MMIEN
#define MMCR1_MMEN _MMCR1.Bits.MMEN

/*** MMCR2 - MMIIC Control Register 2 ***/
typedef union {
  byte Byte;
  struct {
    byte MMCRCEF   :1;           /* MMIIC CRC Error Flag */
    byte           :1;
    byte           :1;
    byte MMRW      :1;           /* MMIIC Master Read/Write */
    byte MMAST     :1;           /* MMIIC Master Control  */
    byte MMBB      :1;           /* MMIIC Bus Busy Flag  */
    byte MMNAKIF   :1;           /* No Acknowledge Interrupt Flag (Master Mode) */
    byte MMALIF    :1;           /* Arbitration Loss Interrupt Flag */
  } Bits;
} MMCR2STR;
extern volatile MMCR2STR _MMCR2 @0x004A;
#define MMCR2 _MMCR2.Byte
#define MMCR2_MMCRCEF _MMCR2.Bits.MMCRCEF
#define MMCR2_MMRW _MMCR2.Bits.MMRW
#define MMCR2_MMAST _MMCR2.Bits.MMAST
#define MMCR2_MMBB _MMCR2.Bits.MMBB
#define MMCR2_MMNAKIF _MMCR2.Bits.MMNAKIF
#define MMCR2_MMALIF _MMCR2.Bits.MMALIF

/*** MMSR - MMIIC Status Register ***/
typedef union {
  byte Byte;
  struct {
    byte MMRXBF   :1;            /* MMIIC Receive Buffer Full */
    byte MMTXBE   :1;            /* MMIIC Transmit Buffer Empty */
    byte MMCRCBF  :1;            /* CRC Data Buffer Full Flag */
    byte MMRXAK   :1;            /* MMIIC Recieve Acknowledge */
    byte MMSRW    :1;            /* MMIIC Slave Read/Write Select */
    byte MMATCH   :1;            /* MMIIC Adress Match Flag */
    byte MMTXIF   :1;            /* MMIIC Transmit Interrupt Flag */
    byte MMRXIF   :1;            /* MMIIC Recieve Interrupt Flag */
  } Bits;
} MMSRSTR;
extern volatile MMSRSTR _MMSR @0x004B;
#define MMSR _MMSR.Byte
#define MMSR_MMRXBF _MMSR.Bits.MMRXBF
#define MMSR_MMTXBE _MMSR.Bits.MMTXBE
#define MMSR_MMCRCBF _MMSR.Bits.MMCRCBF
#define MMSR_MMRXAK _MMSR.Bits.MMRXAK
#define MMSR_MMSRW _MMSR.Bits.MMSRW
#define MMSR_MMATCH _MMSR.Bits.MMATCH
#define MMSR_MMTXIF _MMSR.Bits.MMTXIF
#define MMSR_MMRXIF _MMSR.Bits.MMRXIF

/*** MMDTR - MMIIC Data Transmit Register ***/
typedef union {
  byte Byte;
  struct {
    byte MMTD0   :1;           /* Multi-Master IIC Transmit Data Bit 0 */
    byte MMTD1   :1;           /* Multi-Master IIC Transmit Data Bit 1 */
    byte MMTD2   :1;           /* Multi-Master IIC Transmit Data Bit 2 */
    byte MMTD3   :1;           /* Multi-Master IIC Transmit Data Bit 3 */
    byte MMTD4   :1;           /* Multi-Master IIC Transmit Data Bit 4 */
    byte MMTD5   :1;           /* Multi-Master IIC Transmit Data Bit 5 */
    byte MMTD6   :1;           /* Multi-Master IIC Transmit Data Bit 6 */
    byte MMTD7   :1;           /* Multi-Master IIC Transmit Data Bit 7 */
  } Bits;
  struct {
    byte MMTD    :8;
  } MergedBits;
} MMDTRSTR;
extern volatile MMDTRSTR _MMDTR @0x004C;
#define MMDTR _MMDTR.Byte
#define MMDTR_MMTD0 _MMDTR.Bits.MMTD0
#define MMDTR_MMTD1 _MMDTR.Bits.MMTD1
#define MMDTR_MMTD2 _MMDTR.Bits.MMTD2
#define MMDTR_MMTD3 _MMDTR.Bits.MMTD3
#define MMDTR_MMTD4 _MMDTR.Bits.MMTD4
#define MMDTR_MMTD5 _MMDTR.Bits.MMTD5
#define MMDTR_MMTD6 _MMDTR.Bits.MMTD6
#define MMDTR_MMTD7 _MMDTR.Bits.MMTD7
#define MMDTR_MMTD _MMDTR.MergedBits.MMTD

/*** MMDRR - MMIIC Data Recieve Register ***/
typedef union {
  byte Byte;
  struct {
    byte MMRD0   :1;           /* Multi-Master IIC Receive Data Bit 0 */
    byte MMRD1   :1;           /* Multi-Master IIC Receive Data Bit 1 */
    byte MMRD2   :1;           /* Multi-Master IIC Receive Data Bit 2 */
    byte MMRD3   :1;           /* Multi-Master IIC Receive Data Bit 3 */
    byte MMRD4   :1;           /* Multi-Master IIC Receive Data Bit 4 */
    byte MMRD5   :1;           /* Multi-Master IIC Receive Data Bit 5 */
    byte MMRD6   :1;           /* Multi-Master IIC Receive Data Bit 6 */
    byte MMRD7   :1;           /* Multi-Master IIC Receive Data Bit 7 */
  } Bits;
  struct {
    byte MMRD    :8;
  } MergedBits;
} MMDRRSTR;
extern volatile MMDRRSTR _MMDRR @0x004D;
#define MMDRR _MMDRR.Byte
#define MMDRR_MMRD0 _MMDRR.Bits.MMRD0
#define MMDRR_MMRD1 _MMDRR.Bits.MMRD1
#define MMDRR_MMRD2 _MMDRR.Bits.MMRD2
#define MMDRR_MMRD3 _MMDRR.Bits.MMRD3
#define MMDRR_MMRD4 _MMDRR.Bits.MMRD4
#define MMDRR_MMRD5 _MMDRR.Bits.MMRD5
#define MMDRR_MMRD6 _MMDRR.Bits.MMRD6
#define MMDRR_MMRD7 _MMDRR.Bits.MMRD7
#define MMDRR_MMRD _MMDRR.MergedBits.MMRD

/*** MMCRDR - MMIIC CRC Data Register ***/
typedef union {
  byte Byte;
  struct {
    byte MMCRCD0   :1;           /* Multi-Master IIC CRC Data Bit 0 */
    byte MMCRCD1   :1;           /* Multi-Master IIC CRC Data Bit 1 */
    byte MMCRCD2   :1;           /* Multi-Master IIC CRC Data Bit 2 */
    byte MMCRCD3   :1;           /* Multi-Master IIC CRC Data Bit 3 */
    byte MMCRCD4   :1;           /* Multi-Master IIC CRC Data Bit 4 */
    byte MMCRCD5   :1;           /* Multi-Master IIC CRC Data Bit 5 */
    byte MMCRCD6   :1;           /* Multi-Master IIC CRC Data Bit 6 */
    byte MMCRCD7   :1;           /* Multi-Master IIC CRC Data Bit 7 */
  } Bits;
  struct {
    byte MMCRCD    :8;
  } MergedBits;
} MMCRDRSTR;
extern volatile MMCRDRSTR _MMCRDR @0x004E;
#define MMCRDR _MMCRDR.Byte
#define MMCRDR_MMCRCD0 _MMCRDR.Bits.MMCRCD0
#define MMCRDR_MMCRCD1 _MMCRDR.Bits.MMCRCD1
#define MMCRDR_MMCRCD2 _MMCRDR.Bits.MMCRCD2
#define MMCRDR_MMCRCD3 _MMCRDR.Bits.MMCRCD3
#define MMCRDR_MMCRCD4 _MMCRDR.Bits.MMCRCD4
#define MMCRDR_MMCRCD5 _MMCRDR.Bits.MMCRCD5
#define MMCRDR_MMCRCD6 _MMCRDR.Bits.MMCRCD6
#define MMCRDR_MMCRCD7 _MMCRDR.Bits.MMCRCD7
#define MMCRDR_MMCRCD _MMCRDR.MergedBits.MMCRCD

/*** MMFDR - MMIIC Frequency Divider Register ***/
typedef union {
  byte Byte;
  struct {
    byte MMBR0   :1;           /* IIC Rate Select 0 */
    byte MMBR1   :1;           /* IIC Rate Select 1 */
    byte MMBR2   :1;           /* IIC Rate Select 2 */
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
  } Bits;
  struct {
    byte MMBR    :3;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
  } MergedBits;
} MMFDRSTR;
extern volatile MMFDRSTR _MMFDR @0x004F;
#define MMFDR _MMFDR.Byte
#define MMFDR_MMBR0 _MMFDR.Bits.MMBR0
#define MMFDR_MMBR1 _MMFDR.Bits.MMBR1
#define MMFDR_MMBR2 _MMFDR.Bits.MMBR2
#define MMFDR_MMBR _MMFDR.MergedBits.MMBR

/*** TBCR - Timebase Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte         :1;
    byte TBON    :1;           /* Timebase Enabled */
    byte TBIE    :1;           /* Timebase Interrupt Enable */
    byte TACK    :1;           /* Timebase ACKnowledge */
    byte TBR0    :1;           /* Timebase Rate Selection */
    byte TBR1    :1;           /* Timebase Rate Selection */
    byte TBR2    :1;           /* Timebase Rate Selection */
    byte TBIF    :1;           /* Timebase Interrupt Flag */
  } Bits;
  struct {
    byte         :1;
    byte TBON    :1;
    byte TBIE    :1;
    byte TACK    :1;
    byte TBR     :3;
    byte TBIF    :1;
  } MergedBits;
} TBCRSTR;
extern volatile TBCRSTR _TBCR @0x0051;
#define TBCR _TBCR.Byte
#define TBCR_TBON _TBCR.Bits.TBON
#define TBCR_TBIE _TBCR.Bits.TBIE
#define TBCR_TACK _TBCR.Bits.TACK
#define TBCR_TBR0 _TBCR.Bits.TBR0
#define TBCR_TBR1 _TBCR.Bits.TBR1
#define TBCR_TBR2 _TBCR.Bits.TBR2
#define TBCR_TBIF _TBCR.Bits.TBIF
#define TBCR_TBR _TBCR.MergedBits.TBR

/*** ADSCR - ADC Status and Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte ADCH0   :1;           /* ADC Channel Select Bit 0 */
    byte ADCH1   :1;           /* ADC Channel Select Bit 1 */
    byte ADCH2   :1;           /* ADC Channel Select Bit 2 */
    byte ADCH3   :1;           /* ADC Channel Select Bit 3 */
    byte ADCH4   :1;           /* ADC Channel Select Bit 4 */
    byte ADCO    :1;           /* ADC Continuous Conversion Bit */
    byte AIEN    :1;           /* ADC Interrupt Enable Bit */
    byte COCO    :1;           /* Conversions Complete Bit */
  } Bits;
  struct {
    byte ADCH    :5;
    byte ADCO    :1;
    byte AIEN    :1;
    byte COCO    :1;
  } MergedBits;
} ADSCRSTR;
extern volatile ADSCRSTR _ADSCR @0x0057;
#define ADSCR _ADSCR.Byte
#define ADSCR_ADCH0 _ADSCR.Bits.ADCH0
#define ADSCR_ADCH1 _ADSCR.Bits.ADCH1
#define ADSCR_ADCH2 _ADSCR.Bits.ADCH2
#define ADSCR_ADCH3 _ADSCR.Bits.ADCH3
#define ADSCR_ADCH4 _ADSCR.Bits.ADCH4
#define ADSCR_ADCO _ADSCR.Bits.ADCO
#define ADSCR_AIEN _ADSCR.Bits.AIEN
#define ADSCR_COCO _ADSCR.Bits.COCO
#define ADSCR_ADCH _ADSCR.MergedBits.ADCH

/*** ADICLK - ADC Input Clock Register ***/
typedef union {
  byte Byte;
  struct {
    byte         :1;
    byte         :1;
    byte MODE0   :1;           /* Modes of Result Justification 0 */
    byte MODE1   :1;           /* Modes of Result Justification 1 */
    byte ADICLK  :1;           /* ADC Input Clock Select Bit */
    byte ADIV0   :1;           /* ADC Clock Prescaler Bit 0 */
    byte ADIV1   :1;           /* ADC Clock Prescaler Bit 1 */
    byte ADIV2   :1;           /* ADC Clock Prescaler Bit 2 */
  } Bits;
  struct {
    byte         :1;
    byte         :1;
    byte MODE    :2;
    byte ADICLK  :1;
    byte ADIV    :3;
  } MergedBits;
} ADICLKSTR;
extern volatile ADICLKSTR _ADICLK @0x0058;
#define ADICLK _ADICLK.Byte
#define ADICLK_MODE0 _ADICLK.Bits.MODE0
#define ADICLK_MODE1 _ADICLK.Bits.MODE1
#define ADICLK_ADICLK _ADICLK.Bits.ADICLK
#define ADICLK_ADIV0 _ADICLK.Bits.ADIV0
#define ADICLK_ADIV1 _ADICLK.Bits.ADIV1
#define ADICLK_ADIV2 _ADICLK.Bits.ADIV2
#define ADICLK_MODE _ADICLK.MergedBits.MODE
#define ADICLK_ADIV _ADICLK.MergedBits.ADIV

/*** ADRH0 - ADC Data Register High 0 ~ Right Justified Mode ***/
typedef union {
  byte Byte;
  struct {
    byte  AD8  :1;             /* ADRH0 Data Bit 8 */
    byte  AD9  :1;             /* ADRH0 Data Bit 9 */
    byte       :1;
    byte       :1;
    byte       :1;
    byte       :1;
    byte       :1;
    byte       :1;
  } Bits;
  struct {
    byte AD_8  :8;
  } MergedBits;
} ADRH0STR;
extern volatile ADRH0STR _ADRH0 @0x0059;
#define ADRH0 _ADRH0.Byte
#define ADRH0_AD8 _ADRH0.Bits.AD8
#define ADRH0_AD9 _ADRH0.Bits.AD9
#define ADRH0_AD_8 _ADRH0.MergedBits.AD_8

/*** ADRL0 - ADC Data Register Low 0 ~ Right Justified Mode ***/
typedef union {
  byte Byte;
  struct {
    byte  AD0  :1;             /* ADRL0 Data Bit 0 */
    byte  AD1  :1;             /* ADRL0 Data Bit 1 */
    byte  AD2  :1;             /* ADRL0 Data Bit 2 */
    byte  AD3  :1;             /* ADRL0 Data Bit 3 */
    byte  AD4  :1;             /* ADRL0 Data Bit 4 */
    byte  AD5  :1;             /* ADRL0 Data Bit 5 */
    byte  AD6  :1;             /* ADRL0 Data Bit 6 */
    byte  AD7  :1;             /* ADRL0 Data Bit 7 */
  } Bits;
  struct {
    byte AD    :8;
  } MergedBits;
} ADRL0STR;
extern volatile ADRL0STR _ADRL0 @0x005A;
#define ADRL0 _ADRL0.Byte
#define ADRL0_AD0 _ADRL0.Bits.AD0
#define ADRL0_AD1 _ADRL0.Bits.AD1
#define ADRL0_AD2 _ADRL0.Bits.AD2
#define ADRL0_AD3 _ADRL0.Bits.AD3
#define ADRL0_AD4 _ADRL0.Bits.AD4
#define ADRL0_AD5 _ADRL0.Bits.AD5
#define ADRL0_AD6 _ADRL0.Bits.AD6
#define ADRL0_AD7 _ADRL0.Bits.AD7
#define ADRL0_AD _ADRL0.MergedBits.AD

/*** ADRL1 - ADC Data Register Low 1 ~ Truncation Mode ***/
typedef union {
  byte Byte;
  struct {
    byte AD2   :1;             /* ADC DATA Bit 2 */
    byte AD3   :1;             /* ADC DATA Bit 3 */
    byte AD4   :1;             /* ADC DATA Bit 4 */
    byte AD5   :1;             /* ADC DATA Bit 5 */
    byte AD6   :1;             /* ADC DATA Bit 6 */
    byte AD7   :1;             /* ADC DATA Bit 7 */
    byte AD8   :1;             /* ADC DATA Bit 8 */
    byte AD9   :1;             /* ADC DATA Bit 9 */
  } Bits;
  struct {
    byte AD_2  :8;
  } MergedBits;
} ADRL1STR;
extern volatile ADRL1STR _ADRL1 @0x005B;
#define ADRL1 _ADRL1.Byte
#define ADRL1_AD2 _ADRL1.Bits.AD2
#define ADRL1_AD3 _ADRL1.Bits.AD3
#define ADRL1_AD4 _ADRL1.Bits.AD4
#define ADRL1_AD5 _ADRL1.Bits.AD5
#define ADRL1_AD6 _ADRL1.Bits.AD6
#define ADRL1_AD7 _ADRL1.Bits.AD7
#define ADRL1_AD8 _ADRL1.Bits.AD8
#define ADRL1_AD9 _ADRL1.Bits.AD9
#define ADRL1_AD_2 _ADRL1.MergedBits.AD_2

/*** ADRL2 - ADC Data Register Low 2 ~ Truncation Mode ***/
typedef union {
  byte Byte;
  struct {
    byte AD2   :1;             /* ADC DATA Bit 2 */
    byte AD3   :1;             /* ADC DATA Bit 3 */
    byte AD4   :1;             /* ADC DATA Bit 4 */
    byte AD5   :1;             /* ADC DATA Bit 5 */
    byte AD6   :1;             /* ADC DATA Bit 6 */
    byte AD7   :1;             /* ADC DATA Bit 7 */
    byte AD8   :1;             /* ADC DATA Bit 8 */
    byte AD9   :1;             /* ADC DATA Bit 9 */
  } Bits;
  struct {
    byte AD_2  :8;
  } MergedBits;
} ADRL2STR;
extern volatile ADRL2STR _ADRL2 @0x005C;
#define ADRL2 _ADRL2.Byte
#define ADRL2_AD2 _ADRL2.Bits.AD2
#define ADRL2_AD3 _ADRL2.Bits.AD3
#define ADRL2_AD4 _ADRL2.Bits.AD4
#define ADRL2_AD5 _ADRL2.Bits.AD5
#define ADRL2_AD6 _ADRL2.Bits.AD6
#define ADRL2_AD7 _ADRL2.Bits.AD7
#define ADRL2_AD8 _ADRL2.Bits.AD8
#define ADRL2_AD9 _ADRL2.Bits.AD9
#define ADRL2_AD_2 _ADRL2.MergedBits.AD_2

/*** ADRL3 - ADC Data Register Low 3 ~ Truncation Mode ***/
typedef union {
  byte Byte;
  struct {
    byte AD2   :1;             /* ADC DATA Bit 2 */
    byte AD3   :1;             /* ADC DATA Bit 3 */
    byte AD4   :1;             /* ADC DATA Bit 4 */
    byte AD5   :1;             /* ADC DATA Bit 5 */
    byte AD6   :1;             /* ADC DATA Bit 6 */
    byte AD7   :1;             /* ADC DATA Bit 7 */
    byte AD8   :1;             /* ADC DATA Bit 8 */
    byte AD9   :1;             /* ADC DATA Bit 9 */
  } Bits;
  struct {
    byte AD_2  :8;
  } MergedBits;
} ADRL3STR;
extern volatile ADRL3STR _ADRL3 @0x005D;
#define ADRL3 _ADRL3.Byte
#define ADRL3_AD2 _ADRL3.Bits.AD2
#define ADRL3_AD3 _ADRL3.Bits.AD3
#define ADRL3_AD4 _ADRL3.Bits.AD4
#define ADRL3_AD5 _ADRL3.Bits.AD5
#define ADRL3_AD6 _ADRL3.Bits.AD6
#define ADRL3_AD7 _ADRL3.Bits.AD7
#define ADRL3_AD8 _ADRL3.Bits.AD8
#define ADRL3_AD9 _ADRL3.Bits.AD9
#define ADRL3_AD_2 _ADRL3.MergedBits.AD_2

/*** ADASCR - ADC Auto-scan Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte ASCAN   :1;           /* Auto-scan Mode Enable Bit */
    byte AUTO0   :1;           /* Auto-scan Mode Channel Select Bit */
    byte AUTO1   :1;           /* Auto-scan Mode Channel Select Bit */
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
  } Bits;
  struct {
    byte ASCAN   :1;
    byte AUTO    :2;
    byte         :5;
  } MergedBits;
} ADASCRSTR;
extern volatile ADASCRSTR _ADASCR @0x005E;
#define ADASCR _ADASCR.Byte
#define ADASCR_ASCAN _ADASCR.Bits.ASCAN
#define ADASCR_AUTO0 _ADASCR.Bits.AUTO0
#define ADASCR_AUTO1 _ADASCR.Bits.AUTO1
#define ADASCR_AUTO _ADASCR.MergedBits.AUTO

/*** SBSR - SIM Break Status Register ***/
typedef union {
  byte Byte;
  struct {
    byte         :1;
    byte SBSW    :1;           /* SIM Break Stop/Wait */
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
  } Bits;
} SBSRSTR;
extern volatile SBSRSTR _SBSR @0xFE00;
#define SBSR _SBSR.Byte
#define SBSR_SBSW _SBSR.Bits.SBSW

/*** SRSR - SIM Reset Status Register ***/
typedef union {
  byte Byte;
  struct {
    byte         :1;
    byte LVI     :1;           /* Low-Voltage Inhibit Reset Bit */
    byte MODRST  :1;           /* Monitor Mode Entry Module Reset Bit */
    byte ILAD    :1;           /* Illegal Address Reset Bit */
    byte ILOP    :1;           /* Illegal Opcode Reset Bit */
    byte COP     :1;           /* Computer Operating Properly Reset Bit */
    byte PIN     :1;           /* External Reset Bit */
    byte POR     :1;           /* Power-On Reset Bit */
  } Bits;
} SRSRSTR;
extern volatile SRSRSTR _SRSR @0xFE01;
#define SRSR _SRSR.Byte
#define SRSR_LVI _SRSR.Bits.LVI
#define SRSR_MODRST _SRSR.Bits.MODRST
#define SRSR_ILAD _SRSR.Bits.ILAD
#define SRSR_ILOP _SRSR.Bits.ILOP
#define SRSR_COP _SRSR.Bits.COP
#define SRSR_PIN _SRSR.Bits.PIN
#define SRSR_POR _SRSR.Bits.POR

/*** SUBAR - SIM Upper Byte Address Register ***/
typedef union {
  byte Byte;
  struct {
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
  } Bits;
} SUBARSTR;
extern volatile SUBARSTR _SUBAR @0xFE02;
#define SUBAR _SUBAR.Byte

/*** SBFCR - SIM Break Flag Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte BCFE    :1;           /* Break Clear Flag Enable Bit */
  } Bits;
} SBFCRSTR;
extern volatile SBFCRSTR _SBFCR @0xFE03;
#define SBFCR _SBFCR.Byte
#define SBFCR_BCFE _SBFCR.Bits.BCFE

/*** INT1 - Interrupt Status Register 1 ***/
typedef union {
  byte Byte;
  struct {
    byte         :1;
    byte         :1;
    byte IF1     :1;           /* Interrupt Flag 1 */
    byte IF2     :1;           /* Interrupt Flag 2 */
    byte IF3     :1;           /* Interrupt Flag 3 */
    byte IF4     :1;           /* Interrupt Flag 4 */
    byte IF5     :1;           /* Interrupt Flag 5 */
    byte IF6     :1;           /* Interrupt Flag 6 */
  } Bits;
  struct {
    byte         :1;
    byte         :1;
    byte IF_1    :6;
  } MergedBits;
} INT1STR;
extern volatile INT1STR _INT1 @0xFE04;
#define INT1 _INT1.Byte
#define INT1_IF1 _INT1.Bits.IF1
#define INT1_IF2 _INT1.Bits.IF2
#define INT1_IF3 _INT1.Bits.IF3
#define INT1_IF4 _INT1.Bits.IF4
#define INT1_IF5 _INT1.Bits.IF5
#define INT1_IF6 _INT1.Bits.IF6
#define INT1_IF_1 _INT1.MergedBits.IF_1

/*** INT2 - Interrupt Status Register 2 ***/
typedef union {
  byte Byte;
  struct {
    byte IF7     :1;           /* Interrupt Flag 7 */
    byte IF8     :1;           /* Interrupt Flag 8 */
    byte IF9     :1;           /* Interrupt Flag 9 */
    byte IF10    :1;           /* Interrupt Flag 10 */
    byte IF11    :1;           /* Interrupt Flag 11 */
    byte IF12    :1;           /* Interrupt Flag 12 */
    byte IF13    :1;           /* Interrupt Flag 13 */
    byte IF14    :1;           /* Interrupt Flag 14 */
  } Bits;
  struct {
    byte IF_7    :8;
  } MergedBits;
} INT2STR;
extern volatile INT2STR _INT2 @0xFE05;
#define INT2 _INT2.Byte
#define INT2_IF7 _INT2.Bits.IF7
#define INT2_IF8 _INT2.Bits.IF8
#define INT2_IF9 _INT2.Bits.IF9
#define INT2_IF10 _INT2.Bits.IF10
#define INT2_IF11 _INT2.Bits.IF11
#define INT2_IF12 _INT2.Bits.IF12
#define INT2_IF13 _INT2.Bits.IF13
#define INT2_IF14 _INT2.Bits.IF14
#define INT2_IF_7 _INT2.MergedBits.IF_7

/*** INT3 - Interrupt Status Register 3 ***/
typedef union {
  byte Byte;
  struct {
    byte IF15    :1;           /* Interrupt Flag 15 */
    byte IF16    :1;           /* Interrupt Flag 16 */
    byte IF17    :1;           /* Interrupt Flag 17 */
    byte IF18    :1;           /* Interrupt Flag 18 */
    byte IF19    :1;           /* Interrupt Flag 19 */
    byte IF20    :1;           /* Interrupt Flag 20 */
    byte IF21    :1;           /* Interrupt Flag 21 */
    byte         :1;
  } Bits;
  struct {
    byte IF_15   :7;
    byte         :1;
  } MergedBits;
} INT3STR;

extern volatile INT3STR _INT3 @0xFE06;
#define INT3 _INT3.Byte
#define INT3_IF15 _INT3.Bits.IF15
#define INT3_IF16 _INT3.Bits.IF16
#define INT3_IF17 _INT3.Bits.IF17
#define INT3_IF18 _INT3.Bits.IF18
#define INT3_IF19 _INT3.Bits.IF19
#define INT3_IF20 _INT3.Bits.IF20
#define INT3_IF21 _INT3.Bits.IF21
#define INT3_IF_15 _INT3.MergedBits.IF_15

/*** FLCR - FLASH Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte PGM     :1;           /* Program Control Bit */
    byte ERASE   :1;           /* Erase Control Bit */
    byte MASS    :1;           /* MASS Erase Control Bit */
    byte HVEN    :1;           /* High-Voltage Enable Bit */
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
  } Bits;
} FLCRSTR;
extern volatile FLCRSTR _FLCR @0xFE08;
#define FLCR _FLCR.Byte
#define FLCR_PGM _FLCR.Bits.PGM
#define FLCR_ERASE _FLCR.Bits.ERASE
#define FLCR_MASS _FLCR.Bits.MASS
#define FLCR_HVEN _FLCR.Bits.HVEN

/*** FLBPR - FLASH Block Protect Register ***/
typedef union {
  byte Byte;
  struct {
    byte BPR0    :1;           /* Block Protect Register Bit 0 */
    byte BPR1    :1;           /* Block Protect Register Bit 1 */
    byte BPR2    :1;           /* Block Protect Register Bit 2 */
    byte BPR3    :1;           /* Block Protect Register Bit 3 */
    byte BPR4    :1;           /* Block Protect Register Bit 4 */
    byte BPR5    :1;           /* Block Protect Register Bit 5 */
    byte BPR6    :1;           /* Block Protect Register Bit 6 */
    byte BPR7    :1;           /* Block Protect Register Bit 7 */
  } Bits;
  struct {
    byte BPR     :8;
  } MergedBits;
} FLBPRSTR;
extern volatile FLBPRSTR _FLBPR @0xFE09;
#define FLBPR _FLBPR.Byte
#define FLBPR_BPR0 _FLBPR.Bits.BPR0
#define FLBPR_BPR1 _FLBPR.Bits.BPR1
#define FLBPR_BPR2 _FLBPR.Bits.BPR2
#define FLBPR_BPR3 _FLBPR.Bits.BPR3
#define FLBPR_BPR4 _FLBPR.Bits.BPR4
#define FLBPR_BPR5 _FLBPR.Bits.BPR5
#define FLBPR_BPR6 _FLBPR.Bits.BPR6
#define FLBPR_BPR7 _FLBPR.Bits.BPR7
#define FLBPR_BPR _FLBPR.MergedBits.BPR

/*** BRKH - Break Address Register High ***/
typedef union {
  byte Byte;
  struct {
    byte BIT8    :1;           /* Break Address Register Bit 8 */
    byte BIT9    :1;           /* Break Address Register Bit 9 */
    byte BIT10   :1;           /* Break Address Register Bit 10 */
    byte BIT11   :1;           /* Break Address Register Bit 11 */
    byte BIT12   :1;           /* Break Address Register Bit 12 */
    byte BIT13   :1;           /* Break Address Register Bit 13 */
    byte BIT14   :1;           /* Break Address Register Bit 14 */
    byte BIT15   :1;           /* Break Address Register Bit 15 */
  } Bits;
  struct {
    byte BIT_8   :8;
  } MergedBits;
} BRKHSTR;
extern volatile BRKHSTR _BRKH @0xFE0C;
#define BRKH _BRKH.Byte
#define BRKH_BIT8 _BRKH.Bits.BIT8
#define BRKH_BIT9 _BRKH.Bits.BIT9
#define BRKH_BIT10 _BRKH.Bits.BIT10
#define BRKH_BIT11 _BRKH.Bits.BIT11
#define BRKH_BIT12 _BRKH.Bits.BIT12
#define BRKH_BIT13 _BRKH.Bits.BIT13
#define BRKH_BIT14 _BRKH.Bits.BIT14
#define BRKH_BIT15 _BRKH.Bits.BIT15
#define BRKH_BIT_8 _BRKH.MergedBits.BIT_8

/*** BRKL - Break Address Register Low ***/
typedef union {
  byte Byte;
  struct {
    byte BIT0    :1;           /* Break Address Register Bit 0 */
    byte BIT1    :1;           /* Break Address Register Bit 1 */
    byte BIT2    :1;           /* Break Address Register Bit 2 */
    byte BIT3    :1;           /* Break Address Register Bit 3 */
    byte BIT4    :1;           /* Break Address Register Bit 4 */
    byte BIT5    :1;           /* Break Address Register Bit 5 */
    byte BIT6    :1;           /* Break Address Register Bit 6 */
    byte BIT7    :1;           /* Break Address Register Bit 7 */
  } Bits;
  struct {
    byte BIT     :8;
  } MergedBits;
} BRKLSTR;
extern volatile BRKLSTR _BRKL @0xFE0D;
#define BRKL _BRKL.Byte
#define BRKL_BIT0 _BRKL.Bits.BIT0
#define BRKL_BIT1 _BRKL.Bits.BIT1
#define BRKL_BIT2 _BRKL.Bits.BIT2
#define BRKL_BIT3 _BRKL.Bits.BIT3
#define BRKL_BIT4 _BRKL.Bits.BIT4
#define BRKL_BIT5 _BRKL.Bits.BIT5
#define BRKL_BIT6 _BRKL.Bits.BIT6
#define BRKL_BIT7 _BRKL.Bits.BIT7
#define BRKL_BIT _BRKL.MergedBits.BIT

/*** BRKSCR - Break Status and Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte BRKA    :1;           /* Break Active Bit */
    byte BRKE    :1;           /* Break Enable Bit */
  } Bits;
} BRKSCRSTR;
extern volatile BRKSCRSTR _BRKSCR @0xFE0E;
#define BRKSCR _BRKSCR.Byte
#define BRKSCR_BRKA _BRKSCR.Bits.BRKA
#define BRKSCR_BRKE _BRKSCR.Bits.BRKE

/*** LVISR - LVI Status Register ***/
typedef union {
  byte Byte;
  struct {
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte         :1;
    byte LVIOUT  :1;           /* LVI Output Bit */
  } Bits;
} LVISRSTR;
extern volatile LVISRSTR _LVISR @0xFE0F;
#define LVISR _LVISR.Byte
#define LVISR_LVIOUT _LVISR.Bits.LVIOUT

/*** MOR - Mask Option Register ***/
typedef union {
  byte Byte;
  struct {
    byte           :1;
    byte           :1;
    byte           :1;
    byte           :1;
    byte           :1;
    byte           :1;
    byte OSCSEL0   :1;           /* Oscillator Selection Bit */
    byte OSCSEL1   :1;           /* Oscillator Selection Bit */
  } Bits;
  struct {
    byte           :1;
    byte           :1;
    byte           :1;
    byte           :1;
    byte           :1;
    byte           :1;
    byte OSCSEL    :2;
  } MergedBits;
} MORSTR;
extern volatile MORSTR _MOR @0xFFCF;
#define MOR _MOR.Byte
#define MOR_OSCSEL0 _MOR.Bits.OSCSEL0
#define MOR_OSCSEL1 _MOR.Bits.OSCSEL1
#define MOR_OSCSEL _MOR.MergedBits.OSCSEL

/*** COPCTL - COP Control Register ***/
typedef union {
  byte Byte;
  struct {
    byte BIT0    :1;           /* Bit 0 */
    byte BIT1    :1;           /* Bit 1 */
    byte BIT2    :1;           /* Bit 2 */
    byte BIT3    :1;           /* Bit 3 */
    byte BIT4    :1;           /* Bit 4 */
    byte BIT5    :1;           /* Bit 5 */
    byte BIT6    :1;           /* Bit 6 */
    byte BIT7    :1;           /* Bit 7 */
  } Bits;
  struct {
    byte BIT     :8;
  } MergedBits;
} COPCTLSTR;
extern volatile COPCTLSTR _COPCTL @0xFFFF;
#define COPCTL _COPCTL.Byte
#define COPCTL_BIT0 _COPCTL.Bits.BIT0
#define COPCTL_BIT1 _COPCTL.Bits.BIT1
#define COPCTL_BIT2 _COPCTL.Bits.BIT2
#define COPCTL_BIT3 _COPCTL.Bits.BIT3
#define COPCTL_BIT4 _COPCTL.Bits.BIT4
#define COPCTL_BIT5 _COPCTL.Bits.BIT5
#define COPCTL_BIT6 _COPCTL.Bits.BIT6
#define COPCTL_BIT7 _COPCTL.Bits.BIT7
#define COPCTL_BIT _COPCTL.MergedBits.BIT

/*** T1CNT - TIM1 Counter Register ***/
typedef union {
  word Word;
  struct {
    word BIT0    :1;           /* TIM1 Counter Bit 0 */
    word BIT1    :1;           /* TIM1 Counter Bit 1 */
    word BIT2    :1;           /* TIM1 Counter Bit 2 */
    word BIT3    :1;           /* TIM1 Counter Bit 3 */
    word BIT4    :1;           /* TIM1 Counter Bit 4 */
    word BIT5    :1;           /* TIM1 Counter Bit 5 */
    word BIT6    :1;           /* TIM1 Counter Bit 6 */
    word BIT7    :1;           /* TIM1 Counter Bit 7 */
    word BIT8    :1;           /* TIM1 Counter Bit 8 */
    word BIT9    :1;           /* TIM1 Counter Bit 9 */
    word BIT10   :1;           /* TIM1 Counter Bit 10 */
    word BIT11   :1;           /* TIM1 Counter Bit 11 */
    word BIT12   :1;           /* TIM1 Counter Bit 12 */
    word BIT13   :1;           /* TIM1 Counter Bit 13 */
    word BIT14   :1;           /* TIM1 Counter Bit 14 */
    word BIT15   :1;           /* TIM1 Counter Bit 15 */
  } Bits;
  struct {
    word BIT     :16;
  } MergedBits;
} T1CNTSTR;
extern volatile T1CNTSTR _T1CNT @0x0021;
#define T1CNT _T1CNT.Word
#define T1CNT_BIT0 _T1CNT.Bits.BIT0
#define T1CNT_BIT1 _T1CNT.Bits.BIT1
#define T1CNT_BIT2 _T1CNT.Bits.BIT2
#define T1CNT_BIT3 _T1CNT.Bits.BIT3
#define T1CNT_BIT4 _T1CNT.Bits.BIT4
#define T1CNT_BIT5 _T1CNT.Bits.BIT5
#define T1CNT_BIT6 _T1CNT.Bits.BIT6
#define T1CNT_BIT7 _T1CNT.Bits.BIT7
#define T1CNT_BIT8 _T1CNT.Bits.BIT8
#define T1CNT_BIT9 _T1CNT.Bits.BIT9
#define T1CNT_BIT10 _T1CNT.Bits.BIT10
#define T1CNT_BIT11 _T1CNT.Bits.BIT11
#define T1CNT_BIT12 _T1CNT.Bits.BIT12
#define T1CNT_BIT13 _T1CNT.Bits.BIT13
#define T1CNT_BIT14 _T1CNT.Bits.BIT14
#define T1CNT_BIT15 _T1CNT.Bits.BIT15
#define T1CNT_BIT _T1CNT.MergedBits.BIT

/*** T1MOD - TIM1 Counter Modulo Register ***/
typedef union {
  word Word;
  struct {
    word BIT0    :1;           /* TIM1 Counter Modulo Bit 0 */ 
    word BIT1    :1;           /* TIM1 Counter Modulo Bit 1 */ 
    word BIT2    :1;           /* TIM1 Counter Modulo Bit 2 */ 
    word BIT3    :1;           /* TIM1 Counter Modulo Bit 3 */ 
    word BIT4    :1;           /* TIM1 Counter Modulo Bit 4 */ 
    word BIT5    :1;           /* TIM1 Counter Modulo Bit 5 */ 
    word BIT6    :1;           /* TIM1 Counter Modulo Bit 6 */ 
    word BIT7    :1;           /* TIM1 Counter Modulo Bit 7 */ 
    word BIT8    :1;           /* TIM1 Counter Modulo Bit 8 */ 
    word BIT9    :1;           /* TIM1 Counter Modulo Bit 9 */ 
    word BIT10   :1;           /* TIM1 Counter Modulo Bit 10 */
    word BIT11   :1;           /* TIM1 Counter Modulo Bit 11 */
    word BIT12   :1;           /* TIM1 Counter Modulo Bit 12 */
    word BIT13   :1;           /* TIM1 Counter Modulo Bit 13 */
    word BIT14   :1;           /* TIM1 Counter Modulo Bit 14 */
    word BIT15   :1;           /* TIM1 Counter Modulo Bit 15 */
  } Bits;
  struct {
    word BIT     :16;
  } MergedBits;
} T1MODSTR;
extern volatile T1MODSTR _T1MOD @0x0023;
#define T1MOD _T1MOD.Word
#define T1MOD_BIT0 _T1MOD.Bits.BIT0
#define T1MOD_BIT1 _T1MOD.Bits.BIT1
#define T1MOD_BIT2 _T1MOD.Bits.BIT2
#define T1MOD_BIT3 _T1MOD.Bits.BIT3
#define T1MOD_BIT4 _T1MOD.Bits.BIT4
#define T1MOD_BIT5 _T1MOD.Bits.BIT5
#define T1MOD_BIT6 _T1MOD.Bits.BIT6
#define T1MOD_BIT7 _T1MOD.Bits.BIT7
#define T1MOD_BIT8 _T1MOD.Bits.BIT8
#define T1MOD_BIT9 _T1MOD.Bits.BIT9
#define T1MOD_BIT10 _T1MOD.Bits.BIT10
#define T1MOD_BIT11 _T1MOD.Bits.BIT11
#define T1MOD_BIT12 _T1MOD.Bits.BIT12
#define T1MOD_BIT13 _T1MOD.Bits.BIT13
#define T1MOD_BIT14 _T1MOD.Bits.BIT14
#define T1MOD_BIT15 _T1MOD.Bits.BIT15
#define T1MOD_BIT _T1MOD.MergedBits.BIT

/*** T1CH0 - TIM1 Channel 0 Register ***/
typedef union {
  word Word;
  struct {
    word BIT0    :1;           /* TIM1 Channel 0 Register BIT 0 */
    word BIT1    :1;           /* TIM1 Channel 0 Register BIT 1 */
    word BIT2    :1;           /* TIM1 Channel 0 Register BIT 2 */
    word BIT3    :1;           /* TIM1 Channel 0 Register BIT 3 */
    word BIT4    :1;           /* TIM1 Channel 0 Register BIT 4 */
    word BIT5    :1;           /* TIM1 Channel 0 Register BIT 5 */
    word BIT6    :1;           /* TIM1 Channel 0 Register BIT 6 */
    word BIT7    :1;           /* TIM1 Channel 0 Register BIT 7 */
    word BIT8    :1;           /* TIM1 Channel 0 Register BIT 8 */
    word BIT9    :1;           /* TIM1 Channel 0 Register BIT 9 */
    word BIT10   :1;           /* TIM1 Channel 0 Register BIT 10 */
    word BIT11   :1;           /* TIM1 Channel 0 Register BIT 11 */
    word BIT12   :1;           /* TIM1 Channel 0 Register BIT 12 */
    word BIT13   :1;           /* TIM1 Channel 0 Register BIT 13 */
    word BIT14   :1;           /* TIM1 Channel 0 Register BIT 14 */
    word BIT15   :1;           /* TIM1 Channel 0 Register BIT 15 */
  } Bits;
  struct {
    word BIT     :16;
  } MergedBits;
} T1CH0STR;
extern volatile T1CH0STR _T1CH0 @0x0026;
#define T1CH0 _T1CH0.Word
#define T1CH0_BIT0 _T1CH0.Bits.BIT0
#define T1CH0_BIT1 _T1CH0.Bits.BIT1
#define T1CH0_BIT2 _T1CH0.Bits.BIT2
#define T1CH0_BIT3 _T1CH0.Bits.BIT3
#define T1CH0_BIT4 _T1CH0.Bits.BIT4
#define T1CH0_BIT5 _T1CH0.Bits.BIT5
#define T1CH0_BIT6 _T1CH0.Bits.BIT6
#define T1CH0_BIT7 _T1CH0.Bits.BIT7
#define T1CH0_BIT8 _T1CH0.Bits.BIT8
#define T1CH0_BIT9 _T1CH0.Bits.BIT9
#define T1CH0_BIT10 _T1CH0.Bits.BIT10
#define T1CH0_BIT11 _T1CH0.Bits.BIT11
#define T1CH0_BIT12 _T1CH0.Bits.BIT12
#define T1CH0_BIT13 _T1CH0.Bits.BIT13
#define T1CH0_BIT14 _T1CH0.Bits.BIT14
#define T1CH0_BIT15 _T1CH0.Bits.BIT15
#define T1CH0_BIT _T1CH0.MergedBits.BIT

/*** T1CH1 - TIM1 Channel 1 Register ***/
typedef union {
  word Word;
  struct {
    word BIT0    :1;           /* TIM1 Channel 1 Register BIT 0 */
    word BIT1    :1;           /* TIM1 Channel 1 Register BIT 1 */
    word BIT2    :1;           /* TIM1 Channel 1 Register BIT 2 */
    word BIT3    :1;           /* TIM1 Channel 1 Register BIT 3 */
    word BIT4    :1;           /* TIM1 Channel 1 Register BIT 4 */
    word BIT5    :1;           /* TIM1 Channel 1 Register BIT 5 */
    word BIT6    :1;           /* TIM1 Channel 1 Register BIT 6 */
    word BIT7    :1;           /* TIM1 Channel 1 Register BIT 7 */
    word BIT8    :1;           /* TIM1 Channel 1 Register BIT 8 */
    word BIT9    :1;           /* TIM1 Channel 1 Register BIT 9 */
    word BIT10   :1;           /* TIM1 Channel 1 Register BIT 10 */
    word BIT11   :1;           /* TIM1 Channel 1 Register BIT 11 */
    word BIT12   :1;           /* TIM1 Channel 1 Register BIT 12 */
    word BIT13   :1;           /* TIM1 Channel 1 Register BIT 13 */
    word BIT14   :1;           /* TIM1 Channel 1 Register BIT 14 */
    word BIT15   :1;           /* TIM1 Channel 1 Register BIT 15 */
  } Bits;
  struct {
    word BIT     :16;
  } MergedBits;
} T1CH1STR;
extern volatile T1CH1STR _T1CH1 @0x0029;
#define T1CH1 _T1CH1.Word
#define T1CH1_BIT0 _T1CH1.Bits.BIT0
#define T1CH1_BIT1 _T1CH1.Bits.BIT1
#define T1CH1_BIT2 _T1CH1.Bits.BIT2
#define T1CH1_BIT3 _T1CH1.Bits.BIT3
#define T1CH1_BIT4 _T1CH1.Bits.BIT4
#define T1CH1_BIT5 _T1CH1.Bits.BIT5
#define T1CH1_BIT6 _T1CH1.Bits.BIT6
#define T1CH1_BIT7 _T1CH1.Bits.BIT7
#define T1CH1_BIT8 _T1CH1.Bits.BIT8
#define T1CH1_BIT9 _T1CH1.Bits.BIT9
#define T1CH1_BIT10 _T1CH1.Bits.BIT10
#define T1CH1_BIT11 _T1CH1.Bits.BIT11
#define T1CH1_BIT12 _T1CH1.Bits.BIT12
#define T1CH1_BIT13 _T1CH1.Bits.BIT13
#define T1CH1_BIT14 _T1CH1.Bits.BIT14
#define T1CH1_BIT15 _T1CH1.Bits.BIT15
#define T1CH1_BIT _T1CH1.MergedBits.BIT

/*** T2CNT - TIM2 Counter Register ***/
typedef union {
  word Word;
  struct {
    word BIT0    :1;           /* TIM2 Counter Bit 0 */ 
    word BIT1    :1;           /* TIM2 Counter Bit 1 */ 
    word BIT2    :1;           /* TIM2 Counter Bit 2 */ 
    word BIT3    :1;           /* TIM2 Counter Bit 3 */ 
    word BIT4    :1;           /* TIM2 Counter Bit 4 */ 
    word BIT5    :1;           /* TIM2 Counter Bit 5 */ 
    word BIT6    :1;           /* TIM2 Counter Bit 6 */ 
    word BIT7    :1;           /* TIM2 Counter Bit 7 */ 
    word BIT8    :1;           /* TIM2 Counter Bit 8 */ 
    word BIT9    :1;           /* TIM2 Counter Bit 9 */ 
    word BIT10   :1;           /* TIM2 Counter Bit 10 */
    word BIT11   :1;           /* TIM2 Counter Bit 11 */
    word BIT12   :1;           /* TIM2 Counter Bit 12 */
    word BIT13   :1;           /* TIM2 Counter Bit 13 */
    word BIT14   :1;           /* TIM2 Counter Bit 14 */
    word BIT15   :1;           /* TIM2 Counter Bit 15 */
  } Bits;
  struct {
    word BIT     :16;
  } MergedBits;
} T2CNTSTR;
extern volatile T2CNTSTR _T2CNT @0x002C;
#define T2CNT _T2CNT.Word
#define T2CNT_BIT0 _T2CNT.Bits.BIT0
#define T2CNT_BIT1 _T2CNT.Bits.BIT1
#define T2CNT_BIT2 _T2CNT.Bits.BIT2
#define T2CNT_BIT3 _T2CNT.Bits.BIT3
#define T2CNT_BIT4 _T2CNT.Bits.BIT4
#define T2CNT_BIT5 _T2CNT.Bits.BIT5
#define T2CNT_BIT6 _T2CNT.Bits.BIT6
#define T2CNT_BIT7 _T2CNT.Bits.BIT7
#define T2CNT_BIT8 _T2CNT.Bits.BIT8
#define T2CNT_BIT9 _T2CNT.Bits.BIT9
#define T2CNT_BIT10 _T2CNT.Bits.BIT10
#define T2CNT_BIT11 _T2CNT.Bits.BIT11
#define T2CNT_BIT12 _T2CNT.Bits.BIT12
#define T2CNT_BIT13 _T2CNT.Bits.BIT13
#define T2CNT_BIT14 _T2CNT.Bits.BIT14
#define T2CNT_BIT15 _T2CNT.Bits.BIT15
#define T2CNT_BIT _T2CNT.MergedBits.BIT

/*** T2MOD - TIM2 Counter Modulo Register ***/
typedef union {
  word Word;
  struct {
    word BIT0    :1;           /* TIM2 Counter Modulo Bit 0 */ 
    word BIT1    :1;           /* TIM2 Counter Modulo Bit 1 */ 
    word BIT2    :1;           /* TIM2 Counter Modulo Bit 2 */ 
    word BIT3    :1;           /* TIM2 Counter Modulo Bit 3 */ 
    word BIT4    :1;           /* TIM2 Counter Modulo Bit 4 */ 
    word BIT5    :1;           /* TIM2 Counter Modulo Bit 5 */ 
    word BIT6    :1;           /* TIM2 Counter Modulo Bit 6 */ 
    word BIT7    :1;           /* TIM2 Counter Modulo Bit 7 */ 
    word BIT8    :1;           /* TIM2 Counter Modulo Bit 8 */ 
    word BIT9    :1;           /* TIM2 Counter Modulo Bit 9 */ 
    word BIT10   :1;           /* TIM2 Counter Modulo Bit 10 */
    word BIT11   :1;           /* TIM2 Counter Modulo Bit 11 */
    word BIT12   :1;           /* TIM2 Counter Modulo Bit 12 */
    word BIT13   :1;           /* TIM2 Counter Modulo Bit 13 */
    word BIT14   :1;           /* TIM2 Counter Modulo Bit 14 */
    word BIT15   :1;           /* TIM2 Counter Modulo Bit 15 */
  } Bits;
  struct {
    word BIT     :16;
  } MergedBits;
} T2MODSTR;
extern volatile T2MODSTR _T2MOD @0x002E;
#define T2MOD _T2MOD.Word
#define T2MOD_BIT0 _T2MOD.Bits.BIT0
#define T2MOD_BIT1 _T2MOD.Bits.BIT1
#define T2MOD_BIT2 _T2MOD.Bits.BIT2
#define T2MOD_BIT3 _T2MOD.Bits.BIT3
#define T2MOD_BIT4 _T2MOD.Bits.BIT4
#define T2MOD_BIT5 _T2MOD.Bits.BIT5
#define T2MOD_BIT6 _T2MOD.Bits.BIT6
#define T2MOD_BIT7 _T2MOD.Bits.BIT7
#define T2MOD_BIT8 _T2MOD.Bits.BIT8
#define T2MOD_BIT9 _T2MOD.Bits.BIT9
#define T2MOD_BIT10 _T2MOD.Bits.BIT10
#define T2MOD_BIT11 _T2MOD.Bits.BIT11
#define T2MOD_BIT12 _T2MOD.Bits.BIT12
#define T2MOD_BIT13 _T2MOD.Bits.BIT13
#define T2MOD_BIT14 _T2MOD.Bits.BIT14
#define T2MOD_BIT15 _T2MOD.Bits.BIT15
#define T2MOD_BIT _T2MOD.MergedBits.BIT

/*** T2CH0 - TIM2 Channel 0 Register ***/
typedef union {
  word Word;
  struct {
    word BIT0    :1;           /* TIM2 Channel 0 Register BIT 0 */
    word BIT1    :1;           /* TIM2 Channel 0 Register BIT 1 */
    word BIT2    :1;           /* TIM2 Channel 0 Register BIT 2 */
    word BIT3    :1;           /* TIM2 Channel 0 Register BIT 3 */
    word BIT4    :1;           /* TIM2 Channel 0 Register BIT 4 */
    word BIT5    :1;           /* TIM2 Channel 0 Register BIT 5 */
    word BIT6    :1;           /* TIM2 Channel 0 Register BIT 6 */
    word BIT7    :1;           /* TIM2 Channel 0 Register BIT 7 */
    word BIT8    :1;           /* TIM2 Channel 0 Register BIT 8 */
    word BIT9    :1;           /* TIM2 Channel 0 Register BIT 9 */
    word BIT10   :1;           /* TIM2 Channel 0 Register BIT 10 */
    word BIT11   :1;           /* TIM2 Channel 0 Register BIT 11 */
    word BIT12   :1;           /* TIM2 Channel 0 Register BIT 12 */
    word BIT13   :1;           /* TIM2 Channel 0 Register BIT 13 */
    word BIT14   :1;           /* TIM2 Channel 0 Register BIT 14 */
    word BIT15   :1;           /* TIM2 Channel 0 Register BIT 15 */
  } Bits;
  struct {
    word BIT     :16;
  } MergedBits;
} T2CH0STR;
extern volatile T2CH0STR _T2CH0 @0x0031;
#define T2CH0 _T2CH0.Word
#define T2CH0_BIT0 _T2CH0.Bits.BIT0
#define T2CH0_BIT1 _T2CH0.Bits.BIT1
#define T2CH0_BIT2 _T2CH0.Bits.BIT2
#define T2CH0_BIT3 _T2CH0.Bits.BIT3
#define T2CH0_BIT4 _T2CH0.Bits.BIT4
#define T2CH0_BIT5 _T2CH0.Bits.BIT5
#define T2CH0_BIT6 _T2CH0.Bits.BIT6
#define T2CH0_BIT7 _T2CH0.Bits.BIT7
#define T2CH0_BIT8 _T2CH0.Bits.BIT8
#define T2CH0_BIT9 _T2CH0.Bits.BIT9
#define T2CH0_BIT10 _T2CH0.Bits.BIT10
#define T2CH0_BIT11 _T2CH0.Bits.BIT11
#define T2CH0_BIT12 _T2CH0.Bits.BIT12
#define T2CH0_BIT13 _T2CH0.Bits.BIT13
#define T2CH0_BIT14 _T2CH0.Bits.BIT14
#define T2CH0_BIT15 _T2CH0.Bits.BIT15
#define T2CH0_BIT _T2CH0.MergedBits.BIT

/*** T2CH1 - TIM2 Channel 1 Register ***/
typedef union {
  word Word;
  struct {
    word BIT0    :1;           /* TIM2 Channel 1 Register BIT 0 */
    word BIT1    :1;           /* TIM2 Channel 1 Register BIT 1 */
    word BIT2    :1;           /* TIM2 Channel 1 Register BIT 2 */
    word BIT3    :1;           /* TIM2 Channel 1 Register BIT 3 */
    word BIT4    :1;           /* TIM2 Channel 1 Register BIT 4 */
    word BIT5    :1;           /* TIM2 Channel 1 Register BIT 5 */
    word BIT6    :1;           /* TIM2 Channel 1 Register BIT 6 */
    word BIT7    :1;           /* TIM2 Channel 1 Register BIT 7 */
    word BIT8    :1;           /* TIM2 Channel 1 Register BIT 8 */
    word BIT9    :1;           /* TIM2 Channel 1 Register BIT 9 */
    word BIT10   :1;           /* TIM2 Channel 1 Register BIT 10 */
    word BIT11   :1;           /* TIM2 Channel 1 Register BIT 11 */
    word BIT12   :1;           /* TIM2 Channel 1 Register BIT 12 */
    word BIT13   :1;           /* TIM2 Channel 1 Register BIT 13 */
    word BIT14   :1;           /* TIM2 Channel 1 Register BIT 14 */
    word BIT15   :1;           /* TIM2 Channel 1 Register BIT 15 */
  } Bits;
  struct {
    word BIT     :16;
  } MergedBits;
} T2CH1STR;
extern volatile T2CH1STR _T2CH1 @0x0034;
#define T2CH1 _T2CH1.Word
#define T2CH1_BIT0 _T2CH1.Bits.BIT0
#define T2CH1_BIT1 _T2CH1.Bits.BIT1
#define T2CH1_BIT2 _T2CH1.Bits.BIT2
#define T2CH1_BIT3 _T2CH1.Bits.BIT3
#define T2CH1_BIT4 _T2CH1.Bits.BIT4
#define T2CH1_BIT5 _T2CH1.Bits.BIT5
#define T2CH1_BIT6 _T2CH1.Bits.BIT6
#define T2CH1_BIT7 _T2CH1.Bits.BIT7
#define T2CH1_BIT8 _T2CH1.Bits.BIT8
#define T2CH1_BIT9 _T2CH1.Bits.BIT9
#define T2CH1_BIT10 _T2CH1.Bits.BIT10
#define T2CH1_BIT11 _T2CH1.Bits.BIT11
#define T2CH1_BIT12 _T2CH1.Bits.BIT12
#define T2CH1_BIT13 _T2CH1.Bits.BIT13
#define T2CH1_BIT14 _T2CH1.Bits.BIT14
#define T2CH1_BIT15 _T2CH1.Bits.BIT15
#define T2CH1_BIT _T2CH1.MergedBits.BIT

/*** PMS - PLL Multiplier Select Register ***/
typedef union {
  word Word;
  struct {
    word MUL0    :1;           /* PLL Multiplier Select Bit 0 */ 
    word MUL1    :1;           /* PLL Multiplier Select Bit 1 */ 
    word MUL2    :1;           /* PLL Multiplier Select Bit 2 */ 
    word MUL3    :1;           /* PLL Multiplier Select Bit 3 */ 
    word MUL4    :1;           /* PLL Multiplier Select Bit 4 */ 
    word MUL5    :1;           /* PLL Multiplier Select Bit 5 */ 
    word MUL6    :1;           /* PLL Multiplier Select Bit 6 */ 
    word MUL7    :1;           /* PLL Multiplier Select Bit 7 */ 
    word MUL8    :1;           /* PLL Multiplier Select Bit 8 */ 
    word MUL9    :1;           /* PLL Multiplier Select Bit 9 */ 
    word MUL10   :1;           /* PLL Multiplier Select Bit 10 */
    word MUL11   :1;           /* PLL Multiplier Select Bit 11 */
    word         :1;                                        
    word         :1;                                        
    word         :1;                                        
    word         :1;                                        
  } Bits;
  struct {
    word MUL     :12;
    word         :1;
    word         :1;
    word         :1;
    word         :1;
  } MergedBits;
} PMSSTR;
extern volatile PMSSTR _PMS @0x0038;
#define PMS _PMS.Word
#define PMS_MUL0 _PMS.Bits.MUL0
#define PMS_MUL1 _PMS.Bits.MUL1
#define PMS_MUL2 _PMS.Bits.MUL2
#define PMS_MUL3 _PMS.Bits.MUL3
#define PMS_MUL4 _PMS.Bits.MUL4
#define PMS_MUL5 _PMS.Bits.MUL5
#define PMS_MUL6 _PMS.Bits.MUL6
#define PMS_MUL7 _PMS.Bits.MUL7
#define PMS_MUL8 _PMS.Bits.MUL8
#define PMS_MUL9 _PMS.Bits.MUL9
#define PMS_MUL10 _PMS.Bits.MUL10
#define PMS_MUL11 _PMS.Bits.MUL11
#define PMS_MUL _PMS.MergedBits.MUL

/*** ADR - ADC Data Register ~ Right Justified Mode ***/
typedef union {
  word Word;
  struct {
    word AD0     :1;           /* ADC Data Bit 0 */
    word AD1     :1;           /* ADC Data Bit 1 */
    word AD2     :1;           /* ADC Data Bit 2 */
    word AD3     :1;           /* ADC Data Bit 3 */
    word AD4     :1;           /* ADC Data Bit 4 */
    word AD5     :1;           /* ADC Data Bit 5 */
    word AD6     :1;           /* ADC Data Bit 6 */
    word AD7     :1;           /* ADC Data Bit 7 */
    word AD8     :1;           /* ADC Data Bit 8 */
    word AD9     :1;           /* ADC Data Bit 9 */
    word         :1;
    word         :1;
    word         :1;
    word         :1;
    word         :1;
    word         :1;
  } Bits;
  struct {
    word AD      :10;
    word         :1;
    word         :1;
    word         :1;
    word         :1;
    word         :1;
    word         :1;
  } MergedBits;
} ADRSTR;
extern volatile ADRSTR _ADR @0x0059;
#define ADR _ADR.Word
#define ADR_AD0 _ADR.Bits.AD0
#define ADR_AD1 _ADR.Bits.AD1
#define ADR_AD2 _ADR.Bits.AD2
#define ADR_AD3 _ADR.Bits.AD3
#define ADR_AD4 _ADR.Bits.AD4
#define ADR_AD5 _ADR.Bits.AD5
#define ADR_AD6 _ADR.Bits.AD6
#define ADR_AD7 _ADR.Bits.AD7
#define ADR_AD8 _ADR.Bits.AD8
#define ADR_AD9 _ADR.Bits.AD9
#define ADR_AD _ADR.MergedBits.AD

/*** BRK - Break Address Register ***/
typedef union {
  word Word;
  struct {
    word BIT0    :1;           /* Break Address Register Bit 0 */ 
    word BIT1    :1;           /* Break Address Register Bit 1 */ 
    word BIT2    :1;           /* Break Address Register Bit 2 */ 
    word BIT3    :1;           /* Break Address Register Bit 3 */ 
    word BIT4    :1;           /* Break Address Register Bit 4 */ 
    word BIT5    :1;           /* Break Address Register Bit 5 */ 
    word BIT6    :1;           /* Break Address Register Bit 6 */ 
    word BIT7    :1;           /* Break Address Register Bit 7 */ 
    word BIT8    :1;           /* Break Address Register Bit 8 */ 
    word BIT9    :1;           /* Break Address Register Bit 9 */ 
    word BIT10   :1;           /* Break Address Register Bit 10 */
    word BIT11   :1;           /* Break Address Register Bit 11 */
    word BIT12   :1;           /* Break Address Register Bit 12 */
    word BIT13   :1;           /* Break Address Register Bit 13 */
    word BIT14   :1;           /* Break Address Register Bit 14 */
    word BIT15   :1;           /* Break Address Register Bit 15 */
  } Bits;
  struct {
    word BIT     :16;
  } MergedBits;
} BRKSTR;
extern volatile BRKSTR _BRK @0xFE0C;
#define BRK _BRK.Word
#define BRK_BIT0 _BRK.Bits.BIT0
#define BRK_BIT1 _BRK.Bits.BIT1
#define BRK_BIT2 _BRK.Bits.BIT2
#define BRK_BIT3 _BRK.Bits.BIT3
#define BRK_BIT4 _BRK.Bits.BIT4
#define BRK_BIT5 _BRK.Bits.BIT5
#define BRK_BIT6 _BRK.Bits.BIT6
#define BRK_BIT7 _BRK.Bits.BIT7
#define BRK_BIT8 _BRK.Bits.BIT8
#define BRK_BIT9 _BRK.Bits.BIT9
#define BRK_BIT10 _BRK.Bits.BIT10
#define BRK_BIT11 _BRK.Bits.BIT11
#define BRK_BIT12 _BRK.Bits.BIT12
#define BRK_BIT13 _BRK.Bits.BIT13
#define BRK_BIT14 _BRK.Bits.BIT14
#define BRK_BIT15 _BRK.Bits.BIT15
#define BRK_BIT _BRK.MergedBits.BIT

#endif
