; *************************************************************************
; *           Copyright (C) 2003 by Motorola.  All rights reserved.       *
; *************************************************************************
; *                                                                       *
; *   Motorola reserves the right to make changes without further notice  *
; *   to any product herein to improve reliability, function or design.   *
; *   Motorola does not assume any liability arising out of the           *
; *   application or use of any product, circuit, or software described   *
; *   herein; neither does it convey any license under its patent rights  *
; *   nor the rights of others.                                           *
; *                                                                       *
; *   Motorola products are not designed, intended, or authorized for     *
; *   use as components in systems intended for surgical implant into     *
; *   the body, or other applications intended to support life, or for    *
; *   any other application in which the failure of the Motorola product  *
; *   could create a situation where personal injury or death may occur.  *
; *                                                                       *
; *   Should Buyer purchase or use Motorola products for any such         *
; *   unintended or unauthorized application, Buyer shall indemnify and   *
; *   hold Motorola and its officers, employees, subsidiaries,            *
; *   affiliates, and distributors harmless against all claims costs,     *
; *   damages, and expenses, and reasonable attorney fees arising out     *
; *   of, directly or indirectly, any claim of personal injury or death   *
; *   associated with such unintended or unauthorized use, even if such   *
; *   claim alleges that Motorola was negligent regarding the design      *
; *   or manufacture of the part.                                         *
; *                                                                       *
; *   Motorola and the Motorola logo* are registered trademarks of        *
; *   Motorola Ltd.                                                       *
; *                                                                       *
; *************************************************************************

; *************************************************************************
; *                                                                       *
; *                 Standard Software SGF		 						  *
; *                    Driver for HC908			 						  *
; *                                                                       *
; * FILE NAME     :  Parameters.inc                                       *
; * VERSION:      :  1.0.0                                                *
; * DATE          :  Apr 07, 2003                                         *
; * AUTHOR        :  Flash Team, GSG China                                *
; * EMAIL		  :  flash@sc.mcel.mot.com								  *
; *************************************************************************

; ******************************* CHANGES *********************************
; 1.0.0   2003.04.07  Cloud Li    Initial Version
; *************************************************************************

	XREFB FLASHCR, FLASHPR, CLOCKSCALAR, MODESEL, STARTADDR, ENDADDR, BUFFER

BUS_CLOCK:  EQU 2000000

	IFDEF BUS_CLOCK
		IF (BUS_CLOCK > 8000000) || (BUS_CLOCK < 1000000)
			FAIL "Bus clock is out of range [1MHz ~ 8MHz]"
		ELSE
			NVM_CLOCK_SCALAR: EQU ((BUS_CLOCK * 8) / 1000000)
		ENDIF
	ELSE
		FAIL "Bus clock is not defined!"
	ENDIF

;flash control register bits
PGM						EQU $1
ERASE					EQU	$2
MASS					EQU $4
HVEN					EQU $8

;delay time constants
TNVHL					EQU	$4		;for flash mass erase Tnvhl >= 100 us
TNVH					EQU $1		;for flash page erase Tnvh >= 5 us
TERASE4					EQU	$8D		;count for 4 ms for flash mass or page erase
TERASE1					EQU	$24		;count for 1 ms for flash page erase

TCOPFMEC				EQU ((58000000 / BUS_CLOCK) - 5)
									;count for COP serivce period in mass erase for FlashEraseCOP only

TCOPFPEC				EQU ((58000000 / BUS_CLOCK) - 2)
									;count for COP service period in page erase for FlashEraseCOP only

TMERASE4COP				EQU	((140 / TCOPFMEC) + 1)
									;count for 4 ms for flash mass with COP enabled
TPERASE4COP				EQU	((140 / TCOPFPEC) + 1)
									;count for 4 ms for flash page erase with COP enabled
TPERASE1COP				EQU	((1125 / (TCOPFPEC * 32)) + 1)
									;count for 1 ms for flash page erase with COP enabled


;return code
SGF_OK			 		EQU	$0
SGF_ERROR_CLOCK_SETTING	EQU $20
SGF_ERROR_NOT_BLANK 	EQU $30
SGF_ERROR_VERIFY		EQU	$40


;COP register address
COP_REG_ADDR			EQU $FFFF	; the address of the COP register