#ifndef ROMEO_H
#define ROMEO_H
/******************************************************************************
*
*       Copyright (C) 2004 Motorola, Inc.
*       All Rights Reserved
*
* Filename:     $RCSfile: Romeo.h,v $
* Author:       $Author: r29541 $
* Locker:       $Locker: r29541 $
* State:        $State: Exp $
* Revision:     $Revision: 1.0 $
*
* Functions:   Romeo2 software driver header file for HC08 
*
* History:      
*
*
* Description: This is header file for Romeo2 software driver for HC08        
*       
*                           
*   
*
* Notes:        
*
******************************************************************************/

#define ROMEO_OOK  0
#define ROMEO_FSK  1

/*****************************************************************************************/
/*            THIS SECTION CONTAINS VALUES YOU MUST DEFINE!                              */
/*****************************************************************************************/
#include "MC68HC908AP64.h"                            /* include peripheral declarations */

/* Specify start adress of SPI registers                                                 */
#define ROMEO_SPI_ADDRESS   0x10                      /* Address varies from mcu to mcu  */

/* Set length of data field in receive data buffers                                      */
#define ROMEO_MAX_DATA_SIZE 8                         /* Max length of data field in msg */

/* Set Romeo reset pin                                                                   */   
#define ROMEO_RESET         PTD_PTD3                  /* Define pin used for Reset       */
#define ROMEO_RESET_DDR     DDRD_DDRD3        

/* Set Romeo mode 	                                                                     */
#define ROMEO_MODE_VALUE    ROMEO_OOK                /* ROMEO_OOK = OOK reception        */
                                                     /* ROMEO_FSK = FSK reception        */
/* Set Romeo band	                                                                     */
#define ROMEO_BAND_VALUE    1                        /* 0 = lower band (315MHz)          */
                                                     /* 1 = higher band (434MHz, 868MHz) */
/* Enable/disable Strobe osc                                                             */
#define ROMEO_SOE_VALUE     1                        /* 0 = strobe oscillator disabled	 */
                                                     /* 1 = strobe oscillator enabled	 */

/* Header word present select		                                                     */
#define ROMEO_HE_VALUE      1                        /* 0 = No header word used			 */
                                                     /* 1 = Header word present			 */

/* Define ID word value                                                                  */
#define ROMEO_ID_VALUE      0x55                      /* ID word recognised by Romeo      */

/* SPI clock speed                                                                       */
#define ROMEO_SPI_CLOCK_SPEED   9830400

/* Strobe Ratio value                                                                    */
#define ROMEO_SR_VALUE      1                       /* 0 = strobe ratio  3	             */
                                                    /* 1 = strobe ratio  7	             */
                                                    /* 2 = strobe ratio  15              */
                                                    /* 3 = strobe ratio  31              */
/* Data rate                                                                             */
#define ROMEO_DR_VALUE      1                       /* 0 = 1.0 - 1.4kbaud                */
                                                    /* 1 = 2.0 - 2.7kbaud                */
                                                    /* 2 = 4.0 - 5.3kbaud                */
                                                    /* 3 = 8.6 - 10.6kbaud               */
/* Mixer gain                                                                            */
#define ROMEO_MG_VALUE      0                       /* 0 = Normal                        */
                                                    /* 1 = -17dB (typical)               */
/* MS switch			                                                                 */
#define ROMEO_MS_VALUE      0                       /* 0 = to mixer output               */
                                                    /* 1 = to IF input                   */

/* Phase comparator gain                                                                 */
#define ROMEO_PG_VALUE      1                       /* 0 = high gain mode                */
                                                    /* 1 = low gain mode                 */

/*****************************************************************************************/
/*            These may be omitted depending on hardware setup                           */
/*****************************************************************************************/
#define ROMEO_STROBE		PTD_PTD1         /* #defines for STROBE pin                  */
#define ROMEO_STROBE_DDR	DDRD_DDRD1       /* If hardwired,delete #defines             */

#define	ROMEO_AGC			PTB_PTB4         /* #defines for AGC pin                     */
#define ROMEO_AGC_DDR		DDRB_DDRB4       /* If hardwired,delete #defines             */

#define ROMEO_AGC_VALUE     1               /* 1 -> slow, OOK                            */
                                            /* 0 -> fast, FSK                            */

/*These are required for use with Motorola's rf modules                                  */
#define ROMEO_ENABLELNA		PTD_PTD2         /* #defines for LNA pin                     */
#define ROMEO_ENABLELNA_DDR DDRD_DDRD2       /* If hardwired,delete #defines             */
/*****************************************************************************************/






















/****************************************************************************************/
/* This defines default values for  #defines in the Romeo.h , or prints errors if       */
/* missing or incorrect values have been chosen                                         */
/*                        DO NOT EDIT THIS SECTION!!                                     */

#ifndef ROMEO_SPI_ADDRESS
#error "You must #define symbol ROMEO_SPI_ADDRESS in Romeo.H header file"
#endif

#ifndef ROMEO_MAX_DATA_SIZE
#error "You must #define symbol ROMEO_MAX_DATA_SIZE in Romeo.H header file"
#endif

#ifndef ROMEO_RESET
#error "You must #define symbol ROMEO_RESET in Romeo.H header file"
#endif

#ifndef ROMEO_RESET_DDR
#error "You must #define symbol ROMEO_RESET_DDR in Romeo.H header file"
#endif

#ifndef ROMEO_MODE_VALUE
#error "You must #define symbol ROMEO_MODE_VALUE in Romeo.H header file"
#endif


#if ROMEO_MODE_VALUE ==ROMEO_OOK
        //If OK, do nuthin
#else
    #if ROMEO_MODE_VALUE ==ROMEO_FSK
        //If OK, do nuthin
    #else
        #error "You must set ROMEO_MODE_VALUE to ROMEO_OOK or ROMEOO_FSK in Romeo.H header file"
    #endif 
#endif 


#ifndef ROMEO_BAND_VALUE
#error "You must #define symbol ROMEO_BAND_VALUE in Romeo.H header file"
#endif

#ifndef ROMEO_SOE_VALUE
#error "You must #define symbol ROMEO_SOE_VALUE in Romeo.H header file"
#endif

#ifndef ROMEO_HE_VALUE
#error "You must #define symbol ROMEO_HE_VALUE in Romeo.H header file"
#endif

#ifndef ROMEO_ID_VALUE
#error "You must #define symbol ROMEO_ID_VALUE in Romeo.H header file"
#endif

#ifndef ROMEO_SPI_CLOCK_SPEED
#error "You must #define symbol ROMEO_SPI_CLOCK_SPEED in Romeo.H header file"
#endif

#ifndef ROMEO_SR_VALUE
#error "You must #define symbol ROMEO_SR_VALUE in Romeo.H header file"
#endif

#ifndef ROMEO_DR_VALUE
#error "You must #define symbol ROMEO_DR_VALUE in Romeo.H header file"
#endif

#ifndef ROMEO_MG_VALUE
#error "You must #define symbol ROMEO_MG_VALUE in Romeo.H header file"
#endif

#ifndef ROMEO_MS_VALUE
#error "You must #define symbol ROMEO_MS_VALUE in Romeo.H header file"
#endif






/********************************************************************************/
/* This section contains various values calculated from above data                       */
/*                        DO NOT EDIT THIS SECTION!!                                     */
/*                                                                                       */
/* Timer register offsets                                                                */
/* Register address offsets for normal HC08 SPI                                          */
#define ROMEO_SPCR  *(unsigned char *)(ROMEO_SPI_ADDRESS+0) /* SPI Control reg           */
#define ROMEO_SPSCR *(unsigned char *)(ROMEO_SPI_ADDRESS+1) /* SPI St/Ctrl reg           */
#define ROMEO_SPDR  *(unsigned char *)(ROMEO_SPI_ADDRESS+2) /* SPI Data reg              */



/*  CR1 byte                                                                             */
/* This macro constructs the CR1 byte using above definitions                            */
#define ROMEO_CR1_VALUE   ROMEO_HE_VALUE+(ROMEO_DME_VALUE*2)+(ROMEO_SR_VALUE*4)\
        +(ROMEO_SOE_VALUE*16)+(ROMEO_MODE_VALUE*32)+(ROMEO_BAND_VALUE*64)


/* CR3 byte                                                                              */	
/* This macro constructs the CR3 byte using above definitions                            */

#define ROMEO_CR3_VALUE   (ROMEO_PG_VALUE*8)+(ROMEO_MS_VALUE*16)\
        +(ROMEO_MG_VALUE*32)+(ROMEO_DR_VALUE*64)



/* SPI baud rate divider                                                                 */
/* Chooses appropriate baud rate divisor to provide max comms speed to Romeo             */
#if (ROMEO_SPI_CLOCK_SPEED/307000) <= 2
    #define ROMEO_SPI_BAUD_RATE_DIVISOR  0

#elif (ROMEO_SPI_CLOCK_SPEED/307000) <= 8
    #define ROMEO_SPI_BAUD_RATE_DIVISOR  1

#elif (ROMEO_SPI_CLOCK_SPEED/307000) <= 32
    #define ROMEO_SPI_BAUD_RATE_DIVISOR  2

#elif (ROMEO_SPI_CLOCK_SPEED/307000) <= 128
    #define ROMEO_SPI_BAUD_RATE_DIVISOR  3
#endif


/* Enable/disable Data Manager		                                                     */
#define ROMEO_DME_VALUE     1               /* 0 = Data manager disabled		         */
                                            /* 1 = Data manager enabled			         */
/* DATA MANAGER ALWAYS USD IN THIS VERSION !!                                            */   


typedef union 
{
	unsigned char Byte;
	struct
	{
        unsigned char overrunError  :1; /* Message buffer overrun,  last message lost ! */
        unsigned char checksumError :1; /* Last msg received had checksum error         */
		unsigned char disabled      :1; /* Driver disabled                              */
		unsigned char res		    :5; /* Unused                                       */
	}Bits;
}tROMEO_STATUS;



/** Driver Status **/
//#define ROMEO_READY           1       //Already defined above
#define ROMEO_DISABLED          2       /* Driver disabled                               */
#define ROMEO_OVERRUN           3       /* Data buffer overrun, last message lost        */
#define ROMEO_CHECKSUM_ERROR    4       /* Last message discarded with checksum error    */
#define ROMEO_MSG_READY         5       /* Msg ready                                     */
#define ROMEO_NO_MSG            6       /* Driver enabled, no msgs waiting               */




/* Function Prototypes                                                                   */
void RomeoInitialise(void);
unsigned char RomeoStatus(void);			//DEBUG version
void RomeoEnable(void);
void RomeoDisable(void);
void RomeoStrobeHigh(void);
void RomeoStrobeLow(void);
void RomeoStrobeTriState(void);             /* Useful if you want to override rc strobe  */
interrupt void RomeoSPIRxInt(void);
void RomeoChangeConfig(unsigned char cr1, unsigned char cr2, unsigned char cr3); 
                                              /*Useful if you want to change Romeo setup */
void RomeoCalcChecksum(unsigned char temp);

#endif /* ROMEO_H */

