/******************************************************************************
*
*       Copyright (C) 2004 Motorola, Inc.
*       All Rights Reserved
*
* Filename:     $RCSfile: main.c,v $
* Author:       $Author: r29541 $
* Locker:       $Locker: r29541 $
* State:        $State: Exp $
* Revision:     $Revision: 1.0 $
*
* Functions:    Romeo2 example, send msg with header
*
* History:      
*
*
* Description: Demo                                     
*               
*                       
*                                                                     
*
* Notes:      
*               
*
******************************************************************************/
#include "MC68HC908AP64.h"               /* Include peripheral declarations  */
#include "nvm_clock.h"

#include "romeo.h"                       /* Include Romeo driver header file */

extern unsigned char romeoReceiveBuffer[];	 /* Declare Romeo receive buffer */


/* Variables and #defines used by Flash programming routines  ****************/
extern unsigned int FLASHCR;
extern unsigned int FLASHPR;
extern unsigned char CLOCKSCALAR;
extern unsigned char MODESEL;
extern unsigned int STARTADDR;
extern unsigned int ENDADDR;
extern unsigned int BUFFER;

void FlashProgram(void);        /* declare the FlashProgram assembly function */
void FlashErase(void);            /* declare the FlashErase assembly function */

#define SRCBUF        0x0100 /* source buffer start address */
//#define FLCR          0xFE08 /* AP64 flash control register address */
//#define FLBPR         0xFE09 /* AP64 flash block protection register address */

/*This application links the flash programming driver into flash. For the high-voltage 
  operation like FlashProgram and FlashErase, it is necessary to copy them from flash 
  into RAM before executing them. The below macros are from the .prm file. If you want to
  change the function location or size, please update the below macros correspondingly. */
#define FP_START      FlashProgram /* the location of FlashProgram function in flash */
#define FP_SIZE       0x48         /*  FlashProgram size */
#define FE_START      FlashErase   /*  the location of FlashErase function in flash */
#define FE_SIZE       0x46         /* FlashErase size */

#define PAGEERASE_1MS 0x0    /* 1ms page erase mode */
#define PAGEERASE_4MS 0x4    /* 4ms page erase mode */

#define BUFF_SIZE     0x01   /* source buffer size */
#define SSD_BASE      0x008C /* SSD driver base address in RAM */

typedef  void (*pSSD)(void); /* function pointer prototype */



/***** #defines and variables used by application  ***************************/
#define LED2        PTB_PTB5
#define LED2_DDR    DDRB_DDRB5 /* Defines I/O pin and data direction bit for LED2 */
                               /* LED2 used to indicate current frequency band */
                               /* and signal reception of a message */

#define LED2_ON      0
#define LED2_OFF     1         /* Defines polarity of LED2 pin */

                               
#define SW2         PTD_PTD0
#define SW2_DDR     DDRD_DDRD0 /* Defines I/O pin and data direction bit for SW2 */
                               /* SW2 used to set frequency band     */
                               

#define LED2_FLASH_RATE  0x7fff   


#define COP_DISABLE  CONFIG1=0x01    
/**************************************************************************/


enum {F315MHz = 0, F433MHz, F868MHz, F916MHz};

unsigned char lastValue = 0; /* Variable to hold  data byte from previous message */

unsigned char frequencyBand; /* Variable to hold currently selected frequency band */


#pragma CONST_SEG FREQUENCYVALUE
const unsigned char  storedFrequencyBand;   /* Variable to hold frequency band value */
                                            /* Note, held in flash memory */



#pragma DATA_SEG DEFAULT

/* subroutine for copy driver from flash to RAM */
void CopyFlash(char *source, char *dest, int size)
{
    int nIndex;
    for (nIndex = 0; nIndex < size; nIndex++)
        *dest++ = *source++;
}


void EraseStoredFrequencyBand(void)
{
    pSSD SSD = (pSSD)SSD_BASE;   /* function pointer assignment */
    CopyFlash((char *)FE_START, (char *)SSD_BASE, FE_SIZE); /* copy FlashErase from flash to RAM */
    STARTADDR = (unsigned int)(&storedFrequencyBand);       /* set erase start address */
    MODESEL = PAGEERASE_1MS;         /* set MODESEL to 1ms page erase */
    SSD();                           /* call FlashErase to perform 1ms page erase*/
}


void ProgramStoredFrequencyBand(unsigned char value)
{
    pSSD SSD = (pSSD)SSD_BASE;   /* function pointer assignment */
    CopyFlash((char *)FP_START, (char *)SSD_BASE, FP_SIZE); /* copy FlashProgram from flash to RAM */
    STARTADDR = (unsigned int)(&storedFrequencyBand);       /* set start address for program */
    ENDADDR = (unsigned int)(&storedFrequencyBand);         /* set end address for program */
    *(char *)(SRCBUF) = value; 
    BUFFER = SRCBUF;               /* set buffer */
    SSD();                         /* call FlashProgram */
}



/* Flash LED 1, duration */
/* Pre : LED2 pin configured as output */
/* Post: LED2 flashed once */ 
void FlashLED2(void)
{
    unsigned int i;
    LED2 = LED2_ON;
    for ( i=0;i < LED2_FLASH_RATE;i++) {}
    LED2 = LED2_OFF;
    for ( i=0;i < LED2_FLASH_RATE;i++) {}
}






void main(void) 
{
  unsigned char i;

  COP_DISABLE;		              /* Disable COP timer on mcu */

  FLBPR = 0xff;

  FLASHCR = (unsigned int)&FLCR;                 /* set flash control register address */
  FLASHPR = (unsigned int)&FLBPR;                /* set flash block protection register address */
  CLOCKSCALAR = NVM_CLOCK_SCALAR; /* set clock scaling factor value */

  if (storedFrequencyBand > F916MHz)        /* if stored Freq value is too big */
  {                                         /* ie, flash blank                 */
       EraseStoredFrequencyBand();
       ProgramStoredFrequencyBand(F315MHz);    /* Set to 315MHz default */ 
  }

  LED2 = LED2_OFF;
  LED2_DDR = 1;

  if( SW2 == 0)
  {
       frequencyBand = F916MHz;
       while (SW2 == 0)      /* Select a new frequency band if SW2 pressed */
        { 
            FlashLED2();
            if( frequencyBand == F916MHz)
            {
                frequencyBand = F315MHz;
            } 
            else
            {
                frequencyBand++;
            }
        }
        EraseStoredFrequencyBand();
        ProgramStoredFrequencyBand(frequencyBand);
  }
  else                     /* Else get frequency setting from flash */
  {
        frequencyBand = storedFrequencyBand;  
        
        for(i = 0; i <= frequencyBand; i++)
        {
            FlashLED2();
        }
  }      


  RomeoInitialise();    /* Initialise Romeo driver with settings in Romeo.h file */

  
  if(frequencyBand == F315MHz)
  {
    RomeoChangeConfig( (ROMEO_CR1_VALUE & 0xBf), ROMEO_ID_VALUE ,ROMEO_CR3_VALUE );   
  }
  else
  {
    RomeoChangeConfig( (ROMEO_CR1_VALUE | 0x40), ROMEO_ID_VALUE ,ROMEO_CR3_VALUE );  
  }
   
  


 
  RomeoEnable();        /* This enables Romeo to receive messages               */
  
  for(;;) 
  {


      switch (RomeoStatus())
      {
        case ROMEO_MSG_READY: 
                             if (romeoReceiveBuffer[1] != lastValue) /* If same message as before, ignore */
                             {
                                if ( (romeoReceiveBuffer[2] == 1) ||  (romeoReceiveBuffer[2] == 0) ) 
                                {
                                    lastValue = romeoReceiveBuffer[1];
                                    LED2 = ~LED2;
                                }
                             }
                             romeoReceiveBuffer[0] = romeoReceiveBuffer[0] & 0x7f; /* Clear buffer full flag     */
                             break;
        case ROMEO_OVERRUN:   
                            romeoReceiveBuffer[0] = romeoReceiveBuffer[0] & 0x7f; 
                            break;
        
        case ROMEO_CHECKSUM_ERROR:
                            romeoReceiveBuffer[0] = romeoReceiveBuffer[0] & 0x7f; /* Clear buffer full flag     */

                            break;
        case ROMEO_DISABLED:
                            break; 
        
        
        case ROMEO_NO_MSG:
                            break;
      
        default:           
                            break;
      }





  } 
}
