/******************************************************************************
*
*       Copyright (C) 2004 Motorola, Inc.
*       All Rights Reserved
*
* Filename:     $RCSfile: romeo.c,v $
* Author:       $Author: r29541 $
* Locker:       $Locker: r29541 $
* State:        $State: Exp $
* Revision:     $Revision: 1.0 $
*
* Functions:    Romeo2 software driver for HC08
*
* History:      
*
*
* Description:   This is C code for Romeo2 software driver for HC08 
*                           
*   
*
* Notes:        
*
******************************************************************************/

#include "MC68HC908AP64.h"              /* include peripheral declarations	            */
#include "Romeo.h"                      /* Include driver header file		            */			

/** Driver Internal States **/
#define ROMEO_READY		1		/* Ready to receive new message                         */
#define ROMEO_GOT_ID	2		/* Have received 1 or more valid ID bytes               */
								/* at start of message (no header byte )                */
#define ROMEO_GET_DATA	3		/* Reading in bytes of data                             */								  
#define ROMEO_LAST_BYTE 4		/* Last byte is extra byte added by Romeo - ignore      */


unsigned char romeoChecksum;

unsigned char romeoDataLength; 	/* Length                                               */

unsigned char romeoDriverState;

unsigned char * romeoDataPtr;	/* pointer used to store data into message buffer       */		

unsigned char romeoInputBuffer[ROMEO_MAX_DATA_SIZE+2];	 /*Input buffer for incoming msg*/
unsigned char romeoReceiveBuffer[ROMEO_MAX_DATA_SIZE+1]; /*Data buffer for complete msg */



tROMEO_STATUS romeoStatus;

#define ROMEO_BUFFER_FULL 0x80              /* Mask for rx buffer full flag             */
                                            /* Buffer has format :-
                                                length + full flag byte
                                                data[0]
                                                ...
                                                ...
                                                data[7]
                                                                                        */
unsigned char cr1, cr2, cr3;	

/* Sets up the Romeo device. Note, Romeo remains in Sleep mode */
void RomeoInitialise(void)
{
	volatile unsigned char temp;
	romeoStatus.Byte = 0;                       /* Reset status                         */
	ROMEO_SPCR  = 0x00;	                        /* Disable SPI (and SPI interrupts)     */
	ROMEO_RESET = 1;
	ROMEO_RESET_DDR  = 1;			            /* Put Romeo in master mode             */
	ROMEO_RESET      = 0;			            /* Then slave mode                      */	
	ROMEO_SPSCR = ROMEO_SPI_BAUD_RATE_DIVISOR;
	
    ROMEO_SPCR = ROMEO_SPCR |0x20;              /* Set mcu to master, Romeo to slave    */
	ROMEO_SPCR = 0x2a;	                        /* Enable SPI                           */ 

	temp = ROMEO_SPSCR;
	temp = ROMEO_SPDR;				            /* Read data reg to clear receive flag) */
	ROMEO_SPDR = ROMEO_CR1_VALUE;		        /* Send first control byte              */

	while( (ROMEO_SPSCR & 0x80) == 0 ) {}	    /* SPSCR_SPRF == 0 Wait until byte gone */
	temp = ROMEO_SPDR;				            /* Read data reg to clear receive flag) */
	ROMEO_SPDR = ROMEO_ID_VALUE;		        /* Send second control byte             */
	
	while( (ROMEO_SPSCR & 0x80) == 0 ) {}	    /* SPSCR_SPRF == 0 Wait until byte gone */
	temp = ROMEO_SPDR;				            /* Read data reg to clear receive flag) */
	ROMEO_SPDR = ROMEO_CR3_VALUE;	            /* Send third control byte              */ 

	while( (ROMEO_SPSCR & 0x80) == 0 ) {}	    /* SPSCR_SPRF == 0 Wait until byte gone */
	temp = ROMEO_SPDR;				            /* Read data reg to clear receive flag) */
	romeoDataPtr = &romeoInputBuffer[0];        /* Point to data buffer                 */
    romeoStatus.Bits.disabled = 1;              /* Driver disabled                      */
}



/* Return status of Romeo driver  */
unsigned char RomeoStatus(void)
{
    unsigned char result;
    asm sei;	
	if (romeoStatus.Bits.disabled == 1)
	    result = ROMEO_DISABLED;                            
	else if ( (romeoStatus.Bits.overrunError == 1)  && ( (romeoReceiveBuffer[0] & ROMEO_BUFFER_FULL) == ROMEO_BUFFER_FULL) )
	    result = ROMEO_OVERRUN;                             
	else if ( (romeoStatus.Bits.checksumError == 1)  && ( (romeoReceiveBuffer[0] & ROMEO_BUFFER_FULL) == ROMEO_BUFFER_FULL) )
	    result = ROMEO_CHECKSUM_ERROR;
	else if (  (romeoReceiveBuffer[0] & ROMEO_BUFFER_FULL) != 0 )
	    result = ROMEO_MSG_READY;
	else  
	    result = ROMEO_NO_MSG;  
    asm cli;
    return result;    
	
}




/* Enable Romeo to send data on SPI */
void RomeoEnable(void)
{
    ROMEO_SPCR = ROMEO_SPCR & 0xdd;         /* clear spe and spmstr                     */
	ROMEO_RESET = 1;			            /* Romeo now master on SPI                  */
	ROMEO_SPCR = ROMEO_SPCR | 0x02;         /* SPCR_SPE = 1                             */
	ROMEO_SPSCR = ROMEO_SPSCR | 0x40;       /* SPSCR_ERRIE = 1                          */		
	ROMEO_SPCR = ROMEO_SPCR | 0x80;         /* SPCR_SPRIE = 1 enable SPI receive ints   */
	romeoDataPtr = &romeoInputBuffer[0];    /* Point to data buffer                     */

#ifdef ROMEO_STROBE                         /* Enable strobe, AGC and LNA if present    */
    ROMEO_STROBE = 1;
    ROMEO_STROBE_DDR = 1;
#endif

#ifdef ROMEO_AGC
   ROMEO_AGC = ROMEO_AGC_VALUE;
   ROMEO_AGC_DDR = 1;
#endif

#ifdef ROMEO_ENABLELNA 
    ROMEO_ENABLELNA = 1;
    ROMEO_ENABLELNA_DDR = 1;
#endif

	romeoDriverState = ROMEO_READY;
    romeoStatus.Byte = 0;                   /* Clear error and disable flags            */
    asm cli;                                /* Enable interrupts                        */
}


/* Disable Romeo from sending data on SPI */
void RomeoDisable(void)
{
	ROMEO_SPCR = ROMEO_SPCR & 0xfd;         /* SPCR_SPE = 0   disable spi               */
	ROMEO_SPCR = ROMEO_SPCR | 0x20;         /* SPCR_SPMSTR = 1, mcu=master,Romeo=slave  */
	ROMEO_SPCR = ROMEO_SPCR & 0x7f;         /* SPCR_SPRIE = 0 SPI receive ints disabled */
	ROMEO_SPCR = ROMEO_SPCR | 0x02;         /* SPCR_SPE = 1 enable module               */

#ifdef ROMEO_STROBE                         /* Disable strobe, AGC and LNA if present   */
    ROMEO_STROBE = 0;
#endif

#ifdef ROMEO_AGC
   ROMEO_AGC = 0;
#endif

#ifdef ROMEO_ENABLELNA 
    ROMEO_ENABLELNA = 0;
#endif

    romeoStatus.Bits.disabled = 1;       /* Set disabled bit, other bit values still    */	
}                                        /* valid for last message                      */



/* Turn on strobe pin */
void RomeoStrobeHigh(void)
{
#ifdef ROMEO_STROBE                 
    ROMEO_STROBE = 1;
    ROMEO_STROBE_DDR = 1;
#endif
}


/* Turn off strobe pin */
void RomeoStrobeLow(void)
{
#ifdef ROMEO_STROBE                 
    ROMEO_STROBE = 0;
    ROMEO_STROBE_DDR = 1;
#endif
}


/* Tristate strobe pin */
void RomeoStrobeTriState(void)
{
#ifdef ROMEO_STROBE                 
    ROMEO_STROBE_DDR = 0;
#endif
}



interrupt void RomeoSPIRxInt(void)
{

volatile unsigned char temp;
unsigned char i;

 temp = ROMEO_SPSCR;		            /* Read control reg with sprf flag set          */
 temp = ROMEO_SPDR;		                /* Read data from SPI                           */
 if (romeoDriverState == ROMEO_READY)
 {
 	romeoChecksum = ROMEO_ID_VALUE;     /* Start checksum calculation                   */	
 	if ( ROMEO_HE_VALUE )				/* if header enabled                            */
 	{	
        RomeoCalcChecksum(temp);
    	romeoDataPtr = &romeoInputBuffer[0]; /* Point to start of data buf for next msg */
		romeoDataLength	= temp +1;			 /* make copy of length (+1 for checksum)   */			
        if  (temp > ROMEO_MAX_DATA_SIZE)    // if length is too big or zero
        {
	  	   romeoReceiveBuffer[0] = romeoInputBuffer[0] | ROMEO_BUFFER_FULL;  
           romeoStatus.Bits.checksumError = 1;             /* Checksum error !!!   */ 
           romeoDriverState = ROMEO_READY;                 /* Wait for next message */
           ROMEO_RESET = 0;
           ROMEO_RESET = 1;
        }           
        else
		{
		  *romeoDataPtr++ = temp ;			 /* store length in buffer                  */
	 	  romeoDriverState = ROMEO_GET_DATA;
        }
	}   
	else								     /* else header not enabled                 */
	{
 		if ( temp == ROMEO_ID_VALUE )	    /* if received byte == ID                   */
 		{
 			romeoDriverState = ROMEO_GOT_ID;
 		}
		else							        /* else if not = ID, ignore             */
		{
		}		
 
	}

  }
  else if (romeoDriverState == ROMEO_GOT_ID)	/* else if GOT_ID                       */
  {
  		if (temp == ROMEO_ID_VALUE)		        /* if byte = ID, then ignore            */
  		                                        /* (its a repeat ID)                    */
  		{
  		}
		else							        /* else its the length byte             */
		{
            RomeoCalcChecksum(temp);
    	    romeoDataPtr = &romeoInputBuffer[0];/*Point to start of data buf for next msg*/
 			romeoDataLength	= temp+1;	        /*make copy of length	(+1 for checksum)*/		
            if (temp > ROMEO_MAX_DATA_SIZE)  // if length is too big
            {
	  	        romeoReceiveBuffer[0] = romeoInputBuffer[0] | ROMEO_BUFFER_FULL;  
                romeoStatus.Bits.checksumError = 1;             /* Checksum error !!!   */ 
                romeoDriverState = ROMEO_READY;                 /* Wait for next message */
                ROMEO_RESET = 0;
                ROMEO_RESET = 1;
            }           
            else
			{   *romeoDataPtr++ = temp ;	        /* store length in buffer               */
			    romeoDriverState = ROMEO_GET_DATA;
		    }
		}
  }
  else if (romeoDriverState == ROMEO_GET_DATA)
  {
        RomeoCalcChecksum(temp);
		*romeoDataPtr++ = temp;				     /* store data in buffer                */
		romeoDataLength--;
		if (romeoDataLength == 0)
		{
			romeoDriverState = ROMEO_LAST_BYTE;
		}
  }
  else if (romeoDriverState == ROMEO_LAST_BYTE)	 /* If last byte, ignore                */
  {												 /* This byte caused by extra bit sent  */
                                                 /* by Tango                            */

		
	  	 if ( (romeoReceiveBuffer[0] & ROMEO_BUFFER_FULL) != 0) /* if buffer 1 full */
	  	 {
	  	    romeoStatus.Bits.overrunError = 1;  /* overrun error, discard msg       */
         }
         else                                   /* Else copy msg to buffer 1        */
         {		  	 
	  	        romeoStatus.Bits.overrunError = 0; /*previous overrun error cleared */
	  	        romeoReceiveBuffer[0] = romeoInputBuffer[0] | ROMEO_BUFFER_FULL;  
                for (i = 1; i <= ROMEO_MAX_DATA_SIZE; i++) 	  	                                                    /* Add buffer full flag */
                    romeoReceiveBuffer[i] = romeoInputBuffer[i];            
	  	 }
         if (romeoChecksum != 0xff) 				 /* If checksum not OK */                      
	     {
             romeoStatus.Bits.checksumError = 1;             /* Checksum error !!!   */ 
	     }
         else
         {
            romeoStatus.Bits.checksumError = 0;         /* Clear any previous checksum errors */
         }
         romeoDriverState = ROMEO_READY;
  }	
}



/* Set values in Romeo registers */
/* Must have called ROmeoDisable before this function */

void RomeoChangeConfig(unsigned char cr1, unsigned char cr2, unsigned char cr3)
{
volatile unsigned char temp;

	ROMEO_SPCR  = 0x00;	                            /* Disable SPI (and SPI interrupts) */
	ROMEO_RESET = 1;
	ROMEO_RESET_DDR  = 1;			                /* Put Romeo in master mode         */
	ROMEO_RESET      = 0;			                /* Then slave mode	                */
    ROMEO_SPCR = ROMEO_SPCR |0x20;                  /* Set mcu to master,Romeo to slave */
	ROMEO_SPCR = 0x2a;	                            /* Enable SPI                       */ 
	temp = ROMEO_SPSCR;
	temp = ROMEO_SPDR;				            /* Read data reg to clear receive flag) */
	ROMEO_SPDR = cr1;		                    /* Send first control byte              */
		
	while( (ROMEO_SPSCR & 0x80) == 0 ) {}	    /* SPSCR_SPRF == 0 Wait until byte gone */
	temp = ROMEO_SPDR;				            /* Read data reg to clear receive flag) */
	ROMEO_SPDR = cr2;		                    /* Send second control byte             */
	
	while( (ROMEO_SPSCR & 0x80) == 0 ) {}	    /* SPSCR_SPRF == 0 Wait until byte gone */
	temp = ROMEO_SPDR;				            /* Read data reg to clear receive flag) */
	ROMEO_SPDR = cr3;	                        /* Send third control byte              */

	while( (ROMEO_SPSCR & 0x80) == 0 ) {}	    /* SPSCR_SPRF == 0 Wait until byte gone */
	temp = ROMEO_SPDR;				            /* Read data reg to clear receive flag) */
}    


/* helper function to calculate checksum */
/* Written in assembler, but can use commented out C if required */
void RomeoCalcChecksum(unsigned char temp)
{
//		romeoChecksum = romeoChecksum + temp;
//		if (romeoChecksum < temp)               /* if carry */
//		    romeoChecksum++;
        asm
        {
            
            LDA romeoChecksum
            ADD temp
            ADC #$00
            STA romeoChecksum
            
        }

}


