/******************************************************************************
*
*       Copyright (C) 2004 Motorola, Inc.
*       All Rights Reserved
*
* Filename:     $RCSfile: Tango.c,v $
* Author:       $Author: r29541 $
* Locker:       $Locker: r29541 $
* State:        $State: Exp $
* Revision:     $Revision: 1.0 $
*
* Functions:    Tango3 software driver for HCS08
*
* History:      
*
*
* Description:   This is C code for Tango3 software driver for HCS08 
*                           
*   
*
* Notes:        
*
******************************************************************************/


#include "tango.h"          /* Include driver header file                               */




unsigned char tangoDriverState;


unsigned char bitCounter;           /* bits in current byte remaining                   */ 
unsigned char byteCounter;			/* number of bytes remaining to send                */
unsigned char data;					/* local data store (so that message buffer contents*/
									/* not corrupted)                                   */
unsigned char enableDelayCounter;	/* Counter used for 2 ms delay when part enabled    */

unsigned char * ptrData;			/* pointer used to retrieve data from message buffer*/			

tTANGO_STATUS status;				/* contains status flags                            */

unsigned char tangoTransmitBuffer[TANGO_MAX_DATA_SIZE+2];	
                                    /*  Data buffer for holding message
                                        Format of buffer is :-

                                        ID byte
                                        Data Length Byte - note this length excludes 
                                                           the ID byte !!
                                        Data MSB
                                        ...	
                                        ...
                                        Data LSB

                                        Format of control/length byte  

                                        Bits 7-4, not used
                                        Bits 3-0, message length
                                    */






/* Send preamble, header, then data, then EOM */
void TangoSendData(void)
{
	volatile unsigned char temp;
		status.Bits.eomFlag = 1;
		status.Bits.busy = 1;			

		TangoCalculateChecksum();				 /* Add checksum to message             */
		ptrData = &tangoTransmitBuffer[1];		 /* Point to 1st databyte in msg buffer */
		byteCounter = tangoTransmitBuffer[1]+3;  /* Add 1 byte for header transfer,     */
		                                         /*  1 for length, 1 for checksum       */

		#if TANGO_MODE_VALUE == TANGO_FSK		/*  If FSK modulation                   */
		//{
			data = TANGO_FSK_HEADER;            /* Schedule 4bit preamble + 4bit header */
			bitCounter = 8;
			tangoDriverState = TANGO_SEND_BYTE;
			TANGO_TPMxCxVH = TANGO_COMH;
			TANGO_TPMxCxVL  = TANGO_COML;		/* Set O/C to 1/2 modulus               */
			TANGO_TPMxCxSC = 0x58;				/* O/C, clear on compare                */
		//} 
		#else						            /* else if OOK modulation               */
		//{
			data = TANGO_OOK_HEADER;			/* First byte to be sent will be header */
			bitCounter = 4;					    /* Header uses 4 bits                   */
			tangoDriverState = TANGO_START;	     
			TANGO_TPMxCxVH = TANGO_MODH;
			TANGO_TPMxCxVL = TANGO_MODL;		/* Set O/C to = modulus                 */
			temp = TANGO_TPMxCxSC;
			TANGO_TPMxCxSC = 0x18;				/* O/C clear on compare                 */
			                                    /* (clears pending interrupt)           */
			TANGO_TPMxCxSC = 0x5c;				/* O/C, set on compare                  */
		//}
		#endif // TANGO_MODE = TANGO_FSK
		TANGO_TPMxSC = TANGO_TPMxSC | TANGO_TIMER_ON;		
        asm cli;		                        /* Enable Interrupts                    */
}	   


/* Send preamble , then ID)  */
void TangoSendPreamble_ID(void)
{
volatile unsigned char temp; 
     	status.Bits.eomFlag = 0;
     	status.Bits.busy = 1;

		#if TANGO_MODE_VALUE == TANGO_FSK		/* If  FSK modulation                   */
		//{
			ptrData = &tangoTransmitBuffer[0];	/* Point to ID byte in message buffer   */
			byteCounter = 2;				    /* One byte for preamble, 1 for ID,     */
			bitCounter= 4;					    /* Preamble uses 4 bits                 */
			data = 0;						    /* Preload data with preamble (4 zeroes)*/
			tangoDriverState = TANGO_SEND_BYTE;
			TANGO_TPMxCxVH = TANGO_COMH;
			TANGO_TPMxCxVL = TANGO_COML;		/* Set O/C to 1/2 modulus               */
			TANGO_TPMxCxSC = 0x58;				/* O/C, clear on compare                */
		//}
		#else							        /* else if OOK modulation               */
		//{
			data = tangoTransmitBuffer[0];  	/* Copy ID to global variable           */
			byteCounter = 1;
			bitCounter = 8;
			tangoDriverState = TANGO_START;	
			TANGO_TPMxCxVH = TANGO_MODH;
			TANGO_TPMxCxVL = TANGO_MODL;		/* Set O/C to = modulus                 */
			temp = TANGO_TPMxCxSC;
			TANGO_TPMxCxSC = 0x18;				/* O/C clear on compare                 */
			                                    /* (clears pending interrupt)           */
			TANGO_TPMxCxSC = 0x5c;				/* O/C, set on compare                  */
    	//}
		#endif

		TANGO_TPMxSC = TANGO_TPMxSC | TANGO_TIMER_ON;	/* Start timer                  */
		                                                /*(if not already running       */	
        asm cli;
}


/* Send message with no header         */
/* Format: Preamble,  ID (x idRepeat), data, EOM  */
void TangoSendMessageNoHeader( unsigned char idRepeat)
{
volatile unsigned char temp;

	status.Bits.eomFlag = 1;
	status.Bits.busy = 1;
	TangoCalculateChecksum();			        /* Add checksum to message              */
	ptrData = &tangoTransmitBuffer[0];	        /* Point to ID byte in message buffer   */
	#if TANGO_MODE_VALUE == TANGO_FSK	        /* If FSK modulation                    */
	//{
		data = TANGO_FSK_HEADER;
		bitCounter = 4;					                    /*  4 bits for preamble     */
		byteCounter = tangoTransmitBuffer[1] + idRepeat+4;	/* Add number of ID repeats */
		                                                    /* +4 for ID, preamble,     */
		                                                    /* length byte, checksum    */
		tangoDriverState = TANGO_SEND_BYTE;
		TANGO_TPMxCxVH = TANGO_COMH;
		TANGO_TPMxCxVL = TANGO_COML;			            /* Set O/C to 1/2 modulus   */
		TANGO_TPMxCxSC = 0x58;					            /* O/C, clear on compare    */
	//}
	#else							                        /* else if OOK modulation   */
	//{
		data = *ptrData++;				                    /* First byte to be sent    */
		                                                    /* will be ID               */
		bitCounter = 8;					                    /* ID byte uses 8 bits      */
		byteCounter = tangoTransmitBuffer[1] + idRepeat+3;	/* Add number of ID repeats */
		                                                    /* +3 for ID, length byte,  */
		                                                    /* checksum                 */
		tangoDriverState = TANGO_START;	
		TANGO_TPMxCxVH = TANGO_MODH;
		TANGO_TPMxCxVL = TANGO_MODL;				        /* Set O/C to = modulus     */
		temp = TANGO_TPMxCxSC;
		TANGO_TPMxCxSC = 0x18;				                /* O/C clear on compare     */
		                                                    /* clears pending interrupt)*/
		TANGO_TPMxCxSC = 0x5c;				                /* O/C, set on compare      */
	//}
	#endif

		TANGO_TPMxSC = TANGO_TPMxSC | TANGO_TIMER_ON;	    /* Start timer              */
		                                                    /* (if not already running) */	
		asm cli;
}


interrupt void TangoTimerInterrupt(void)
{
volatile unsigned char temp;		
	
	temp = TANGO_TPMxCxSC;					                /* Read ch1 flag            */
	switch (tangoDriverState)
	{


		case TANGO_ENABLE_DELAY:	
				
						if (--enableDelayCounter == 0)
						{
							status.Bits.enableDelay = 0;
                    		TANGO_TPMxCxSC = 0x18;			    /* Disable channel int, */
                    		                                    /* o/c clear            */
                            #ifdef TANGO_TIMER_CLK_IN_CHANNEL   /* If using ext clock   */
 	                            TANGO_TPMxMODH = TANGO_MODH;    /* Load modulus with bit*/
 	                                                            /* timing values        */
	                            TANGO_TPMxMODL = TANGO_MODL;	
	                        #endif 
		                    break;
						}
						else
						{
							TANGO_TPMxCxSC = 0x58;				/* O/C clear            */
						    break;
						}	
		case TANGO_START:		
						TANGO_TPMxCxVH = TANGO_COMH;
						TANGO_TPMxCxVL = TANGO_COML;		/* Set O/C to 1/2 modulus   */
						tangoDriverState = TANGO_PREAMBLE_1;	
						TANGO_TPMxCxSC = 0x5c;				/* Clears int flag          */
						break;
		case TANGO_PREAMBLE_1:
						tangoDriverState = TANGO_PREAMBLE_2;	
						TANGO_TPMxCxSC = 0x5c;				/* Clears int flag */
						break;
		case TANGO_PREAMBLE_2: 
						tangoDriverState = TANGO_SEND_BYTE;
						TANGO_TPMxCxSC = 0x64;		        /* PWM , low true pulses    */
						                                    /*( _|-  Manchester output )*/
						break;

		case TANGO_SEND_BYTE:				
						if (bitCounter == 0)	
						{
							byteCounter--;	
							if (byteCounter == 0)			/* If last byte, then add   */
							                                /* extra bit                */
							{	
								tangoDriverState = TANGO_EXTRA_BIT;
								TANGO_TPMxCxSC = 0x64;		/* PWM , low true pulses    */
								                            /*( _|-  Manchester output )*/
								break;
							}
							else						    /* byteCounter != 0         */
							{
							 #if TANGO_MODE_VALUE == TANGO_FSK
							    if (byteCounter > tangoTransmitBuffer[1]+3) /*If ID repeat*/
							 #else
								if (byteCounter > tangoTransmitBuffer[1]+2)  /*If ID repeat*/
							#endif
								{
									data = tangoTransmitBuffer[0];   /* Data = ID       */
								}
								else
								{
									data = *ptrData++;		/* Get next byte to send    */
								}
								bitCounter = 8;
							}		
						}
													    /* if bitCounter != 0           */
						if  ( (data & 0x80) == 0)		/* if MSB = 0                   */
						{															
							TANGO_TPMxCxSC = 0x64;		/* PWM , low true pulses        */
							                            /* ( _|-  Manchester output )   */
						}
						else							/* if MSB = 1                   */
						{
							TANGO_TPMxCxSC = 0x68;		/* PWM, high true pulses        */
							                            /* (-|_  Manchester output)     */
						}
						bitCounter--;
						data = data << 1;				/* Shift data by 1 bit	        */
						break;


		case  TANGO_EXTRA_BIT:	
						if (status.Bits.eomFlag == 1)	/* if require eom               */
						{
							tangoDriverState = TANGO_EOM_1;
						}	
						else
						{
							tangoDriverState = TANGO_END;
						}
						TANGO_TPMxCxSC = 0x58;			/* O/C ,clear on match          */
						TANGO_TPMxCxVH = TANGO_MODH;
						TANGO_TPMxCxVL = TANGO_MODL;	/* Set compare to == modulus    */
						break;
		case   TANGO_EOM_1:	
						tangoDriverState = TANGO_EOM_2;
						TANGO_TPMxCxSC = 0x58;			        /* O/C , clear on match */
						break;
		case   TANGO_EOM_2:
						tangoDriverState = TANGO_END;
						TANGO_TPMxCxSC = 0x58;			        /* O/C , clear on match */
						break;
		case   TANGO_END:		
						status.Bits.eomFlag = 0;	
						status.Bits.busy = 0;
                    	TANGO_TPMxCxSC = 0x18;		  /* Disable channel int, o/c clear */
						#if TANGO_TIMER_DISABLE == 1 
						  TANGO_TPMxSC = TANGO_TPMxSC & TANGO_TIMER_OFF;/*Turn off timer*/
						                                                /* if required  */
						#endif
		default:		break;
	}	
}


/* Initialise the timer channel and tango 		*/
/* Note Tango is not power on by this function  */
/* Use TangoEnable to power up Tango            */

void TangoInitialise(void)
{
/* Setup Tango */
#ifdef TANGO_MODE
	#if TANGO_MODE_VALUE == TANGO_OOK
	   TANGO_MODE = 0;
	#else
	   TANGO_MODE = 1;
	#endif
	
	TANGO_MODE_DDR = 1;					
#endif
	
#ifdef TANGO_BAND
	TANGO_BAND = TANGO_BAND_VALUE;
	TANGO_BAND_DDR = 1;
#endif

#ifdef TANGO_ENABLE
	TANGO_ENABLE = 0;
	TANGO_ENABLE_DDR = 1;			                        /* Tango is not enabled     */
#endif	

#ifdef TANGO_ENABLE_PA
    TANGO_ENABLE_PA_DDR = 1;
    TANGO_ENABLE_PA = 0;            
#endif

	status.Byte = 0;	                                    /* Reset flags              */

#ifdef TANGO_TIMER_CLK_IN_CHANNEL                           /* If using external clock  */
    TANGO_TPMxMODH  = TANGO_2MS_EXT_H;          /* Load modulus with 2ms timeout value  */
    TANGO_TPMxMODL  = TANGO_2MS_EXT_L;
#else                                           /* If using internal clock              */
	TANGO_TPMxMODH = TANGO_MODH;                /* Load modulus with bit timing values  */
	TANGO_TPMxMODL = TANGO_MODL;	 
#endif
}	


/* Powers up Tango and schedules 2 ms startup delay */
void TangoEnable(void)
{
#ifdef TANGO_ENABLE
		TANGO_ENABLE = 1;
#endif

#ifdef TANGO_ENABLE_PA
        TANGO_ENABLE_PA = 1;            /* BUG !! missing semicolon */
#endif
     	status.Bits.enabled = 1;
		status.Bits.enableDelay = 1;

        #ifdef TANGO_TIMER_CLK_IN_CHANNEL           /* If using ext clock               */
            enableDelayCounter = 1;
            TANGO_TPMxCxVH = TANGO_2MS_EXT_H;
            TANGO_TPMxCxVL = TANGO_2MS_EXT_L;       /* Set for 2 ms delay               */
        #else                                       /* If using int clock               */
            enableDelayCounter = TANGO_2MS_DELAY;			
		    TANGO_TPMxCxVH = TANGO_MODH;
		    TANGO_TPMxCxVL = TANGO_MODL;	        /* Set O/C to = modulus             */
        #endif

        #ifdef TANGO_TIMER_CLK_IN_CHANNEL                           /* If using external clock  */
            TANGO_TPMxMODH  = TANGO_2MS_EXT_H;          /* Load modulus with 2ms timeout value  */
            TANGO_TPMxMODL  = TANGO_2MS_EXT_L;
        #else                                           /* If using internal clock              */
	        TANGO_TPMxMODH = TANGO_MODH;                /* Load modulus with bit timing values  */
	        TANGO_TPMxMODL = TANGO_MODL;	 
        #endif

		TANGO_TPMxCxSC = 0x18;				                /* O/C clear on compare     */
		                                                    /* clears pending interrupt)*/
		TANGO_TPMxCxSC = 0x58;			            /* O/C , clear on match             */
		tangoDriverState = TANGO_ENABLE_DELAY;	

		TANGO_TPMxSC = TANGO_TPMxSC | TANGO_TIMER_ON;	/* Start timer                  */
		                                                /* (if not already running)     */	
     	asm cli
}



/* Disables Tango */
void TangoDisable(void)
{

#ifdef TANGO_ENABLE			
		TANGO_ENABLE = 0;
#endif
     	status.Bits.enabled = 0;
   	TANGO_TPMxCxSC = 0x18;			                /* Disable channel int, o/c clear   */

#if  TANGO_TIMER_DISABLE  == 1
		TANGO_TPMxSC = TANGO_TPMxSC & TANGO_TIMER_OFF;  /*Turn off timer if required    */
#endif
}



/* Return current status of the driver  */
/* TANGO_DISABLED   disabled */
/* TANGO_IN_ENABLE_DELAY  - waiting for 2ms delay */
/* TANGO_READY  */
/* TANGO_BUSY - sending message */

unsigned char TangoDriverStatus(void)
{
	if (0 == status.Bits.enabled)		                /* If tango disabled            */
		return TANGO_DISABLED;
	else if (1 == status.Bits.enableDelay)	            /* If in 2ms delay              */
		return TANGO_IN_ENABLE_DELAY;
	else if (0 == status.Bits.busy)		                /* else if not busy             */
		return TANGO_READY;
	else
	    return TANGO_BUSY;
}
			

/* Append a checksum on to message */
void TangoCalculateChecksum(void)
{
	unsigned char temp;
    asm	
    {
    	PSHA
 		PSHX
        LDA *( @tangoTransmitBuffer +1)
        ADD #$02				;Add ID, length
        STA temp
        CLRA
        
        CLC						
        LDHX	@tangoTransmitBuffer
     loop:				;Calculate checksum 
        ADC		,X	
        AIX		#$01
        DEC		temp
        BNE 	loop
        ADC		#0		; Add final carry
        COMA
        STA     ,X		;Append on to message
        PULX
        PULA
        
    }	


}