#ifndef TANGO_H
#define TANGO_H
/******************************************************************************
*
*       Copyright (C) 2004 Motorola, Inc.
*       All Rights Reserved
*
* Filename:     $RCSfile: Tango.h,v $
* Author:       $Author: r29541 $
* Locker:       $Locker: r29541 $
* State:        $State: Exp $
* Revision:     $Revision: 1.0 $
*
* Functions:    Tango3 software driver header file for HCS08
*
* History:      
*
*
* Description:   This is header file for Tango3 software driver for HCS08 
*                           
*   
*
* Notes:        
*
******************************************************************************/


/****************************************************************************************/
/* This section defines some symbols for use below. DO NOT EDIT!                        */
#define TANGO_FSK   1
#define TANGO_OOK   0

#define TANGO_HIGH_BAND  1
#define TANGO_LOW_BAND   0
/****************************************************************************************/



/****************************************************************************************/
/*            THIS SECTION CONTAINS VALUES YOU MUST DEFINE!                             */
/*                                                                                      */
#include "MC9S08RG60.h"                         /* Include peripheral declarations      */

#define TANGO_TIMER_ADDRESS     0x30            /* Location of 1st timer register       */
#define TANGO_TIMER_CHANNEL     1               /* Define which timer channel to use    */
                                                /* Note:timer channels start from 0     */

#define TANGO_MAX_DATA_SIZE 8                   /* Max size of data                     */        

                                                /* Set TANGO Mode                       */
#define  TANGO_MODE_VALUE TANGO_OOK             /* TANGO_OOK or TANGO_FSK               */      

                                                /* Set timer clock speed in Hz          */
#define TANGO_TIMER_CLOCK_SPEED  8000000            

#define TANGO_TIMER_CLOCK_SOURCE    1	        /* Use to set clock source for timer    */
                                                /* 1 = Bus clock                        */
                                                /* 2 = XCLK- note,not all mcus have XCLK*/                            
                                                /* 3 = Ext clock                        */
                                              
#define TANGO_TIMER_PRESCALE    1               /* Specify timer prescaler value        */
 		                                        /* NOTE: If using DATACLK from          */
 		                                        /* Tango ic, prescaler will be forced   */
 		                                        /* to 1                                 */

#define TANGO_TIMER_DISABLE	 1            /* Allows driver to turn off timer after use  */
								          /* Delete this #define if you want timer to   */
								          /* stay on                                    */ 


#define TANGO_CRYSTAL_FREQUENCY  13560000       /* Crystal frequency (in Hz)            */
                                                /* Typical values used                  */
                                                /* RF Output                            */ 
                                                /* 315MHz  - 9843700                    */
                                                /* 434MHz  - 13560000                   */
                                                /* 868MHz  - 13560000                   */



                                                /* Set Tango Band                       */
                                                /* TANGO_HIGH_BAND or TANGO_LOW_BAND    */
#define TANGO_BAND_VALUE   TANGO_HIGH_BAND      /* High band - 315, 434 MHz             */
                                                /* Low band - 868MHz, 928MHz            */

                                                /* Set Tango data rate in Hz (before    */
#define TANGO_DATA_RATE      2400               /* Manchester encoding)                 */


#define TANGO_ENABLE        PTCD_PTCD1              /* Define pin used for enable       */
#define TANGO_ENABLE_DDR    PTCDD_PTCDD1            /* If hardwired,delete #defines     */

/****************************************************************************************/
/* These may be omitted depending on the hardware setup                                 */


#define TANGO_MODE          PTED_PTED0              /* Define pin used for mode select  */
#define TANGO_MODE_DDR      PTEDD_PTEDD0            /* If hardwired,delete #defines     */
 
#define TANGO_BAND          PTAD_PTAD2              /* Define pin for band select       */
#define TANGO_BAND_DDR      PTADD_PTADD2            /* If hardwired,delete #defines     */

//#define TANGO_ENABLE_PA     PTED_PTED1              /* Define pin used for Power amp enable */
//#define TANGO_ENABLE_PA_DDR  PTEDD_PTEDD1           /* If hardwired, delete #defines        */
/****************************************************************************************/

























/****************************************************************************************/
/* This defines default values for  #defines in the Tango.h , or prints errors if                      */
/* missing or incorrect values have been chosen                                         */
/*                        DO NOT EDIT THIS SECTION!!                                     */

#ifndef TANGO_TIMER_ADDRESS
#error "You must #define symbol TANGO_TIMER_ADDRESS in Tango.H header file"
#endif

#ifndef TANGO_TIMER_CHANNEL
#error "You must #define symbol TANGO_TIMER_CHANNEL in Tango.H header file"
#endif

#ifndef TANGO_MAX_DATA_SIZE
#error "You must #define symbol TANGO_MAX_DATA_SIZE in Tango.H header file"
#endif

#if TANGO_MAX_DATA_SIZE > 127
#error "TANGO_MAX_DATA_SIZE in file Tango.h must be in range 0- 127"
#endif


#ifndef TANGO_MODE_VALUE
#error "You must #define symbol TANGO_MODE_VALUE in Tango.H header file"
#endif

#if TANGO_MODE_VALUE ==TANGO_OOK
        //If OK, do nuthin
#else
    #if TANGO_MODE_VALUE ==TANGO_FSK
        //If OK, do nuthin
    #else
        #error "You must set TANGO_MODE_VALUE to TANGO_OOK or TANGO_FSK in Tango.H header file"
    #endif 
#endif 


#ifndef TANGO_TIMER_CLOCK_SPEED
#error  "You must #define symbol TANGO_TIMER_CLOCK_SPEED in Tango.h header file"									
#endif	

#ifndef TANGO_TIMER_CLOCK_SOURCE
#error  "You must #define symbol TANGO_TIMER_CLOCK_SOURCE in Tango.h header file"									
#endif	


#ifndef TANGO_TIMER_PRESCALE
#error "You must #define symbol TANGO_TIMER_PRESCALE in Tango.h header file"									
#endif										


#ifndef TANGO_CRYSTAL_FREQUENCY 
#error "You must #define symbol TANGO_CRYSTAL_FREQUENCY in Tango.h header file"	
#endif



#if TANGO_BAND_VALUE ==TANGO_HIGH_BAND
                                            /* If OK, do nothing */
#else
    #if TANGO_BAND_VALUE ==TANGO_LOW_BAND
                                            /* If OK, do nothing */
    #else
        #error "You must set TANGO_BAND_VALUE to TANGO_HIGH or TANGO_LOW in Tango.H header file"
    #endif 
#endif 


#ifndef TANGO_DATA_RATE
#error "You must #define symbol TANGO_DATA_RATE in Tango.h header file"	
#endif


/****************************************************************************************/
/*  This section defines various values used in the driver                              */
/*                        DO NOT EDIT THIS SECTION!!                                     */


#if TANGO_TIMER_CLOCK_SOURCE == 3
    #define TANGO_TIMER_CLK_IN_CHANNEL  0       /* Timer channel used for clk in        */
                                                /* (usually timer ch 0 on HCS08         */
                                                /* Delete if not using clk input        */
#endif



#ifdef TANGO_TIMER_CLK_IN_CHANNEL               /* If using an external clock source    */
    #define TANGO_TIMER_MODULUS  ((TANGO_CRYSTAL_FREQUENCY/64)/TANGO_DATA_RATE)
    
    #define TANGO_2MS_EXT_H (((TANGO_CRYSTAL_FREQUENCY/500)/256)/64) /* If using ext clock,need these to set 2ms delay*/
    #define TANGO_2MS_EXT_L ((TANGO_CRYSTAL_FREQUENCY/500)/64) 
    

#else                                           /* If using internal clock source       */
    #define TANGO_TIMER_MODULUS  ((TANGO_TIMER_CLOCK_SPEED/TANGO_DATA_RATE)/TANGO_TIMER_PRESCALE)

    #if ( (TANGO_TIMER_CLOCK_SPEED/500)/TANGO_TIMER_MODULUS ) == 0
    #define TANGO_2MS_DELAY 1
    #else
    #define TANGO_2MS_DELAY  ( (TANGO_TIMER_CLOCK_SPEED/500)/TANGO_TIMER_MODULUS )
    #endif

#endif

#define TANGO_HALF_TIMER_MODULUS   (TANGO_TIMER_MODULUS/2)

#define TANGO_MODH  (TANGO_TIMER_MODULUS/256)
#define TANGO_MODL  (TANGO_TIMER_MODULUS) 

#define TANGO_COMH  (TANGO_HALF_TIMER_MODULUS/256)
#define TANGO_COML  (TANGO_HALF_TIMER_MODULUS)






typedef union 
{
	unsigned char Byte;
	struct
	{
		unsigned char enabled	:1;         /* 1 = Tango enabled, 0 = Tango disabled    */
		unsigned char enableDelay :1;	    /* 1 = in 2 ms delay after enabling         */
		unsigned char busy		:1; 	    /* 1 = currently sending a message, 0= idle */
		unsigned char res1		:1;		    /* not used                                 */
		unsigned char eomFlag	:1;		    /* 1 = eom required, 0 = no eom required    */
		unsigned char res2		:3;         /* not used                                 */
	}Bits;
}tTANGO_STATUS;


/*    Driver states					*/
#define TANGO_DISABLED			0
#define TANGO_READY				1
#define TANGO_IN_ENABLE_DELAY  	2
#define TANGO_BUSY				3			

/* Internal state machine states */
#define TANGO_ENABLE_DELAY	0
#define TANGO_START			1
#define TANGO_PREAMBLE_1	2	
#define TANGO_PREAMBLE_2	3
#define TANGO_SEND_BYTE		4	
#define TANGO_EOM_1			5
#define TANGO_EOM_2			6
#define TANGO_END			7
#define TANGO_EXTRA_BIT		8

/*   Constants      */
#define TANGO_OOK_HEADER   0x60		/* Header value = 0110 (4 MSbits)                   */
#define TANGO_FSK_HEADER  0x06		/* FSK preamble (4 0's) and Header (0110)           */ 


/* Timer control reg masks */
#define TANGO_TIMER_ON 	(TANGO_TIMER_CLOCK_SOURCE*8)  /* OR this value to timer control */
                                                      /* reg to enable clock            */
								                      /* NOTE, cannot be used to switch */
								                      /* from clock to clock            */

#define TANGO_TIMER_OFF		0xE7   /* AND this value to timer ctrl reg to disable clock */


/* Timer register offsets  */
/* Register address offsets for normal S08 timer */
#define TANGO_TPMxSC  	*(unsigned char *)(TANGO_TIMER_ADDRESS+0) /* Tmr status/ctrl reg*/
#define TANGO_TPMxCNTH	*(unsigned char *)(TANGO_TIMER_ADDRESS+1) /* Timer counter H	*/
#define TANGO_TPMxCNTL	*(unsigned char *)(TANGO_TIMER_ADDRESS+2) /* Timer counter L	*/
#define TANGO_TPMxMODH	*(unsigned char *)(TANGO_TIMER_ADDRESS+3) /* Timer modulus H	*/
#define TANGO_TPMxMODL	*(unsigned char *)(TANGO_TIMER_ADDRESS+4) /* Timer modulus L	*/

/* Registers for each timer channel */
#define TANGO_TPMxCxSC	*(unsigned char *)(TANGO_TIMER_ADDRESS+5+(3*TANGO_TIMER_CHANNEL)+0)
#define TANGO_TPMxCxVH	*(unsigned char *)(TANGO_TIMER_ADDRESS+5+(3*TANGO_TIMER_CHANNEL)+1)
#define TANGO_TPMxCxVL	*(unsigned char *)(TANGO_TIMER_ADDRESS+5+(3*TANGO_TIMER_CHANNEL)+2)

/* Function prototypes  */
void TangoSendData(void);
void TangoSendPreamble_ID(void);
void TangoSendMessageNoHeader( unsigned char idRepeat);
interrupt void TangoTimerInterrupt(void);
void TangoInitialise(void);
void TangoEnable(void);
void TangoDisable(void);
unsigned char TangoDriverStatus(void);
void TangoCalculateChecksum(void);

#endif //TANGO_H

















